@@ -13,35 +13,32 @@
  */
 
 #include "inputbool.h"
-#include "pagewidget.h"
-#if QT_VERSION >= 300
-#include <qstylefactory.h>
-#else
-#include <qwindowsstyle.h>
-#endif
+//#if QT_VERSION >= 300
+//#include <qstylefactory.h>
+//#else
+//#include <qwindowsstyle.h>
+//#endif
 #include <qlayout.h>
 
-InputBool::InputBool( const QString & text, PageWidget * parent, bool &flag )
-  : /*QCheckBox( text, parent->getLayout() )*/ QWidget(parent->getLayout()), state(flag)
+InputBool::InputBool( const QString & text, QWidget * parent, bool &flag )
+  : QWidget(parent), state(flag)
 {
   QBoxLayout *layout = new QHBoxLayout(this);
   cb = new QCheckBox(text,this);
   layout->addWidget(cb);
   layout->addStretch(10);
 
-#if QT_VERSION >= 300
-  QStyle *winStyle = QStyleFactory::create("windows");
-#else
-  QWindowsStyle *winStyle = new QWindowsStyle();
-#endif
+//#if QT_VERSION >= 300
+//  QStyle *winStyle = QStyleFactory::create("windows");
+//#else
+//  QWindowsStyle *winStyle = new QWindowsStyle();
+//#endif
   cb->setChecked( flag );
-  if (winStyle) cb->setStyle( winStyle );
+//  if (winStyle) cb->setStyle( winStyle );
   cb->setMinimumSize( sizeHint() );
 
   connect( cb, SIGNAL(toggled(bool)), SLOT(setState(bool)) );
 
-  parent->addWidget(this);
-
   layout->activate();
 }
 
