@@ -10,47 +10,123 @@
   translator report only for some languages, pass their codes as arguments
   to the script. In that case, the language.doc will not be generated.
   Example:
-      
+  
     python translator.py en nl cz
   
   Originally, the script was written in Perl and was known as translator.pl.
   The last Perl version was dated 2002/05/21 (plus some later corrections)
 
-  $Id: translator.py,v 1.6 2004/04/13 19:01:17 dimitri Exp $
+  $Id: translator.py,v 1.20 2004/09/28 18:26:42 dimitri Exp $
   
                                          Petr Prikryl (prikrylp@skil.cz)
                                
   History:
   --------
-  2002/05/21
-   - This was the last Perl version. 
-  2003/05/16
-   - If the script is given list of languages, only the translator report
-     is generated and only for those languages.
-  2004/01/24
-   - Total reimplementation just started: classes TrManager, and Transl.
-  2004/02/05
-   - First version that produces translator report. The documentation 
-     in the language.doc is not generated yet.
-  2004/02/10
-   - First fully functional version that generates both the translator
-     report and the documentation. It is a bit slower than the Perl version,
-     but is much less tricky and much more flexible. It also solves some
-     problems that were not solved by the Perl version. The translator report
-     content should be more useful for developers.
+  2002/05/21 - This was the last Perl version. 
+  2003/05/16 - List of language marks can be passed as arguments.
+  2004/01/24 - Total reimplementation started: classes TrManager, and Transl.
+  2004/02/05 - First version that produces translator report. No language.doc yet.
+  2004/02/10 - First fully functional version that generates both the translator
+               report and the documentation. It is a bit slower than the
+               Perl version, but is much less tricky and much more flexible.
+               It also solves some problems that were not solved by the Perl
+               version. The translator report content should be more useful
+               for developers.
   2004/02/11 - Some tuning-up to provide more useful information.
   2004/04/16 - Added new tokens to the tokenizer (to remove some warnings).
+  2004/05/25 - Added from __future__ import generators not to force Python 2.3.
+  2004/06/03 - Removed dependency on textwrap module.
+  2004/07/07 - Fixed the bug in the fill() function.
+  2004/07/21 - Better e-mail mangling for HTML part of language.doc.
+             - Plural not used for reporting a single missing method.
+             - Removal of not used translator adapters is suggested only
+               when the report is not restricted to selected languages
+               explicitly via script arguments.
+  2004/07/26 - Better reporting of not-needed adapters.
+  2004/10/04 - Reporting of not called translator methods added.
+  2004/10/05 - Modified to check only doxygen/src sources for the previous report.
   """                               
 
-import os, re, sys, textwrap
+from __future__ import generators
+import os, re, sys
 
 
 def fill(s):
     """Returns string formated to the wrapped paragraph multiline string.
     
     Replaces whitespaces by one space and then uses he textwrap.fill()."""
+    
+    # Replace all whitespace by spaces, remove whitespaces that are not
+    # necessary, strip the left and right whitespaces, and break the string 
+    # to list of words.
     rexWS = re.compile(r'\s+')
-    return textwrap.fill(rexWS.sub(' ', s))
+    lst = rexWS.sub(' ', s).strip().split()
+    
+    # If the list is not empty, put the words together and form the lines 
+    # of maximum 70 characters. Build the list of lines.
+    lines = []
+    if lst:
+        line = lst.pop(0)   # no separation space in front of the first word
+        for word in lst:
+            if len(line) + len(word) < 70:
+                line += ' ' + word
+            else:
+                lines.append(line)  # another full line formed
+                line = word         # next line started
+        lines.append(line)          # the last line
+    return '\n'.join(lines)
+
+    
+# The following function dedent() is the verbatim copy from the textwrap.py
+# module. The textwrap.py was introduced in Python 2.3. To make this script
+# working also in older Python versions, I have decided to copy it. 
+# Notice that the textwrap.py is copyrighted:
+#
+# Copyright (C) 1999-2001 Gregory P. Ward.
+# Copyright (C) 2002, 2003 Python Software Foundation.
+# Written by Greg Ward <gward@python.net>
+#
+# The explicit permission to use the code here was sent by Guido van Rossum 
+# (4th June, 2004).
+#
+def dedent(text):
+    """dedent(text : string) -> string
+
+    Remove any whitespace than can be uniformly removed from the left
+    of every line in `text`.
+
+    This can be used e.g. to make triple-quoted strings line up with
+    the left edge of screen/whatever, while still presenting it in the
+    source code in indented form.
+
+    For example:
+
+        def test():
+            # end first line with \ to avoid the empty line!
+            s = '''\
+            hello
+              world
+            '''
+            print repr(s)          # prints '    hello\n      world\n    '
+            print repr(dedent(s))  # prints 'hello\n  world\n'
+    """
+    lines = text.expandtabs().split('\n')
+    margin = None
+    for line in lines:
+        content = line.lstrip()
+        if not content:
+            continue
+        indent = len(line) - len(content)
+        if margin is None:
+            margin = indent
+        else:
+            margin = min(margin, indent)
+
+    if margin is not None and margin > 0:
+        for i in range(len(lines)):
+            lines[i] = lines[i][margin:]
+
+    return '\n'.join(lines)
     
 
 class Transl:
@@ -1041,8 +1117,12 @@ class Transl:
         fout.write('\n\n\n')
         fout.write(self.classId + '   (' + self.baseClassId + ')')
         if self.missingMethods:
-            fout.write('  %d' % len(self.missingMethods))
-            fout.write(' methods to implement')
+            num = len(self.missingMethods)
+            fout.write('  %d' % num)
+            fout.write(' method')
+            if num > 1:
+                fout.write('s')
+            fout.write(' to implement')
         fout.write('\n' + '-' * len(self.classId))
         
         # Write the info about the implemented required methods.
@@ -1082,7 +1162,7 @@ class Transl:
 class TrManager:
     """Collects basic info and builds subordinate Transl objects."""
     
-    def __init__(self):                                
+    def __init__(self):
         """Determines paths, creates and initializes structures.
         
         The arguments of the script may explicitly say what languages should 
@@ -1125,7 +1205,7 @@ class TrManager:
         # script, of the translator.h, of the translator_adapter.h (see the 
         # self.__build() for the last two) of all the translator_xx.h files
         # and of the template for generating the documentation. So, this
-        # time can compared with modification time of the generated 
+        # time can be compared with modification time of the generated 
         # documentation to decide, whether the doc should be re-generated.
         self.lastModificationTime = os.path.getmtime(self.script)
         
@@ -1277,7 +1357,82 @@ class TrManager:
             tim = tr.getmtime()
             if tim > self.lastModificationTime:
                 self.lastModificationTime = tim
-                
+        
+        
+    def __getNoTrSourceFilesLst(self):
+        """Returns the list of sources to be checked.
+        
+        All .cpp files and also .h files that do not declare or define
+        the translator methods are included in the list. The file names 
+        are searched in doxygen/src directory.
+        """ 
+        srcdir = os.path.join(self.doxy_path, 'src')
+        files = []
+        for item in os.listdir(srcdir):
+            # Split the bare name to get the extension.
+            name, ext = os.path.splitext(item)
+            ext = ext.lower()
+            
+            # Include only .cpp and .h files (case independent) and exclude
+            # the files where the checked identifiers are defined.
+            if ext == '.cpp' or (ext == '.h' and name.find('translator') == -1):
+                fname = os.path.join(srcdir, item)
+                assert os.path.isfile(fname) # assumes no directory with the ext
+                files.append(fname)          # full name
+        return files
+        
+    
+    def __removeUsedInFiles(self, fname, dic):
+        """Removes items for method identifiers that are found in fname.
+        
+        The method reads the content of the file as one string and searches
+        for all identifiers from dic. The identifiers that were found in
+        the file are removed from the dictionary.
+        
+        Note: If more files is to be checked, the files where most items are
+        probably used should be checked first and the resulting reduced 
+        dictionary should be used for checking the next files (speed up).
+        """
+        lst_in = dic.keys()   # identifiers to be searched for
+        
+        # Read content of the file as one string.
+        assert os.path.isfile(fname)
+        f = file(fname)
+        cont = f.read()
+        f.close()
+        
+        # Remove the items for identifiers that were found in the file.
+        while lst_in:
+            item = lst_in.pop(0)
+            if cont.find(item) != -1:
+                del dic[item]
+
+    
+    def __checkForNotUsedTrMethods(self):
+        """Returns the dictionary of not used translator methods.
+        
+        The method can be called only after self.requiredMethodsDic has been
+        built. The stripped prototypes are the values, the method identifiers
+        are the keys.
+        """
+        # Build the dictionary of the required method prototypes with
+        # method identifiers used as keys.
+        trdic = {}
+        for prototype in self.requiredMethodsDic.keys():
+            ri = prototype.split('(')[0]
+            identifier = ri.split()[1].strip()
+            trdic[identifier] = prototype
+        
+        # Build the list of source files where translator method identifiers
+        # can be used.
+        files = self.__getNoTrSourceFilesLst()
+        
+        # Loop through the files and reduce the dictionary of id -> proto.
+        for fname in files:
+            self.__removeUsedInFiles(fname, trdic)
+        
+        # Return the dictionary of not used translator methods.
+        return trdic
         
         
     def generateTranslatorReport(self):
@@ -1317,7 +1472,7 @@ class TrManager:
                 alphabetically). This means that they derive from the
                 Translator class and they implement all %d of the required
                 methods. Anyway, there still may be some details listed even 
-                for them. Please, see the details for them:'''
+                for them:'''
             s = s % len(self.requiredMethodsDic)    
             f.write('-' * 70 + '\n')
             f.write(fill(s) + '\n\n')
@@ -1346,7 +1501,10 @@ class TrManager:
                 obj = self.__translDic[x]
                 f.write('  %-30s' % obj.classId)
                 f.write('  %-6s' % obj.readableStatus)
-                f.write('\t%2d methods to implement' % len(obj.missingMethods))
+                numimpl = len(obj.missingMethods)
+                pluralS = ''
+                if numimpl > 1: pluralS = 's'
+                f.write('\t%2d method%s to implement' % (numimpl, pluralS))
                 if obj.note:
                     f.write('\n\tNote: ' + obj.note + '\n')
                 f.write('\n')
@@ -1356,11 +1514,28 @@ class TrManager:
                     adaptMinVersion = obj.status
                 
             # Set the note if some old translator adapters are not needed 
-            # any more.
-            for version, adaptClassId in self.adaptMethodsDic.values():
-                if version < adaptMinVersion:
-                    f.write('\nNote: The %s class ' % adaptClassId)
-                    f.write('is not used and can be removed.\n')
+            # any more. Do it only when the script is called without arguments,
+            # i.e. all languages were checked against the needed translator 
+            # adapters. 
+            if not self.script_argLst:
+                to_remove = {}
+                for version, adaptClassId in self.adaptMethodsDic.values():
+                    if version < adaptMinVersion:
+                        to_remove[adaptClassId] = True
+                
+                if to_remove:
+                    lst = to_remove.keys()
+                    lst.sort()
+                    plural = len(lst) > 1
+                    note = 'Note: The adapter class'
+                    if plural: note += 'es'
+                    note += ' ' + ', '.join(lst)    
+                    if not plural: 
+                        note += ' is'
+                    else:
+                        note += ' are'
+                    note += ' not used and can be removed.'
+                    f.write('\n' + fill(note) + '\n')
                 
         # Write the list of the English-based classes.
         if self.EnBasedIdLst:
@@ -1380,6 +1555,27 @@ class TrManager:
                     f.write(' -- ' + obj.note)
                 f.write('\n')
             
+        # Check for not used translator methods and generate warning if found.
+        # The check is rather time consuming, so it is not done when report
+        # is restricted to explicitly given language identifiers.
+        if not self.script_argLst:
+            dic = self.__checkForNotUsedTrMethods()
+            if dic:
+                s = '''WARNING: The following translator methods are declared
+                    in the Translator class but their identifiers do not appear 
+                    in source files. The situation should be checked. The .cpp 
+                    files and .h files excluding the '*translator*' files 
+                    in doxygen/src directory were simply searched for occurence 
+                    of the method identifiers:'''
+                f.write('\n' + '=' * 70 + '\n')
+                f.write(fill(s) + '\n\n')
+                
+                keys = dic.keys()
+                keys.sort()
+                for key in keys:
+                    f.write('  ' + dic[key] + '\n')
+                f.write('\n')
+        
         # Write the details for the translators.
         f.write('\n' + '=' * 70)
         f.write('\nDetails for translators (classes sorted alphabetically):\n')
@@ -1396,8 +1592,6 @@ class TrManager:
         f.close()
         
             
-
-
     def __loadMaintainers(self):
         """Load and process the file with the maintainers.
         
@@ -1447,7 +1641,8 @@ class TrManager:
                     assert(len(lst) == 2)
                     t = (lst[0].strip(), lst[1].strip())
                     self.__maintainersDic[classId].append(t)
-        f.close()            
+        f.close()
+        
                     
     def generateLanguageDoc(self):
         """Checks the modtime of files and generates language.doc."""
@@ -1509,7 +1704,7 @@ class TrManager:
               <td ><b><font size=+1 color="#ffffff"> Language </font></b></td>
               <td ><b><font size=+1 color="#ffffff"> Maintainer </font></b></td>
               <td ><b><font size=+1 color="#ffffff"> Contact address </font>
-                      <font size=-2 color="#ffffff">(remove the NOSPAM.)</font></b></td>
+                      <font size=-2 color="#ffffff">(replace the at and dot)</font></b></td>
               <td ><b><font size=+1 color="#ffffff"> Status </font></b></td>
               </tr>
               <!-- table content begin -->
@@ -1521,7 +1716,7 @@ class TrManager:
             </table>
             \\endhtmlonly
             '''
-        htmlTableTpl = textwrap.dedent(htmlTableTpl)    
+        htmlTableTpl = dedent(htmlTableTpl)    
         htmlTrTpl = '\n  <tr bgcolor="#ffffff">%s\n  </tr>'
         htmlTdTpl = '\n    <td>%s</td>'
 
@@ -1554,11 +1749,21 @@ class TrManager:
                 ee = '<br>'.join(le)
             
             # Mangle the e-mail and replace the entity references.
-            if ee:
-                ee = ee.replace('@', '@NOSPAM.')
+            if ee and ee != '&nbsp;':
+                # More than one maintainer address separated by <br> can be used.
+                emails = ee.split('<br>')
+                mangled_list = []
+                for email in emails:
+                    name, domain = email.split('@')
+                    domain = domain.replace('.', ' dot ')
+                    mangled_list.append(name + ' at ' + domain)
+                ee = '<br>'.join(mangled_list)
+                
             if mm:
                 mm = mm.replace('&ccaron;', '&#x010d;')
                 mm = mm.replace('&rcaron;', '&#x0159;')
+                mm = mm.replace('&scaron;', '&#x0161;')
+                mm = mm.replace('&zcaron;', '&#x017e;')
             
             # Append the maintainer and e-mail elements.
             lst.append(htmlTdTpl % mm)
@@ -1585,7 +1790,7 @@ class TrManager:
             \end{tabular}
             \endlatexonly
             '''
-        latexTableTpl = textwrap.dedent(latexTableTpl)    
+        latexTableTpl = dedent(latexTableTpl)    
         latexLineTpl = '\n' + r'  %s & %s & {\tt\tiny %s} & %s \\'
 
         # Loop through transl objects in the order of sorted readable names
@@ -1643,6 +1848,8 @@ class TrManager:
         latexTable = latexTable.replace('&oslash;', '\\o{}')
         latexTable = latexTable.replace('&ccaron;', '\\v{c}')
         latexTable = latexTable.replace('&rcaron;', '\\v{r}')
+        latexTable = latexTable.replace('&scaron;', '\\v{s}')
+        latexTable = latexTable.replace('&zcaron;', '\\v{z}')
         latexTable = latexTable.replace('_',        '\\_')
         
         # Put the HTML and LaTeX parts together and define the dic item.
