@@ -86,6 +86,7 @@ ClassDef::ClassDef(
   m_innerClasses = new ClassSDict(17);
   m_subGrouping=Config_getBool("SUBGROUPING");
   m_templateInstances = 0;
+  m_variableInstances = 0;
   m_templateMaster =0;
   m_templBaseClassNames = 0;
   m_artificial = FALSE;
@@ -123,6 +124,7 @@ ClassDef::~ClassDef()
   delete memberGroupSDict;
   delete m_innerClasses;
   delete m_templateInstances;
+  delete m_variableInstances;
   delete m_templBaseClassNames;
   delete m_tempArgs;
 }
@@ -934,31 +936,108 @@ void ClassDef::writeDetailedDescription(OutputList &ol, const QCString &pageType
   }
 }
     
+void ClassDef::showUsedFiles(OutputList &ol)
+{
+  if (Config_getBool("SHOW_USED_FILES"))
+  {
+    ol.writeRuler();
+    ol.parseText(theTranslator->trGeneratedFromFiles(
+          m_isObjC && m_compType==Interface ? Class : m_compType,
+          m_files.count()==1));
+
+    bool first=TRUE;
+    const char *file = m_files.first();
+    while (file)
+    {
+      bool ambig;
+      FileDef *fd=findFileDef(Doxygen::inputNameDict,file,ambig);
+      if (fd)
+      {
+        if (first)
+        {
+          first=FALSE;   
+          ol.startItemList();
+        }
+
+        ol.writeListItem();
+        QCString path=fd->getPath().copy();
+        if (Config_getBool("FULL_PATH_NAMES"))
+        {
+          ol.docify(stripFromPath(path));
+        }
+
+        QCString fname = fd->name();
+        if (!fd->getVersion().isEmpty()) // append version if available
+        {
+          fname += " (" + fd->getVersion() + ")";
+        }
+
+        // for HTML 
+        ol.pushGeneratorState();
+        ol.disableAllBut(OutputGenerator::Html);
+        if (fd->generateSourceFile())
+        {
+          ol.writeObjectLink(0,fd->getSourceFileBase(),0,fname);
+        }
+        else if (fd->isLinkable())
+        {
+          ol.writeObjectLink(fd->getReference(),fd->getOutputFileBase(),0,
+              fname);
+        }
+        else
+        {
+          ol.docify(fname);
+        }
+        ol.popGeneratorState();
+
+        // for other output formats
+        ol.pushGeneratorState();
+        ol.disable(OutputGenerator::Html);
+        if (fd->isLinkable())
+        {
+          ol.writeObjectLink(fd->getReference(),fd->getOutputFileBase(),0,
+              fname);
+        }
+        else
+        {
+          ol.docify(fname);
+        }
+
+        ol.popGeneratorState();
+
+        
+      }
+      file=m_files.next();
+    }
+    if (!first) ol.endItemList();
+  }
+}
+
+
 // write all documentation for this class
 void ClassDef::writeDocumentation(OutputList &ol)
 {
-  // write title
-  QCString pageTitle=displayName().copy();
-  QCString pageType;
-  QCString cType=compoundTypeString();
-  //printf("ClassDef::writeDocumentation() cType=%s\n",cType.data());
-  toupper(cType.at(0));
-  pageType+=" ";
-  pageType+=cType;
-  pageTitle+=pageType+" Reference";
-  if (m_tempArgs) pageTitle.prepend(" Template");
-  startFile(ol,getOutputFileBase(),name(),pageTitle);
+  QCString pageType = " ";
+  pageType += compoundTypeString();
+  toupper(pageType.at(1));
+  QCString pageTitle = theTranslator->trCompoundReference(displayName(),
+              m_compType == Interface && m_isObjC ? Class : m_compType,
+              m_tempArgs != 0);
+  
+  startFile(ol,getOutputFileBase(),name(),pageTitle);  
+  if (getOuterScope()!=Doxygen::globalScope)
+  {
+    writeNavigationPath(ol);
+  }
   startTitle(ol,getOutputFileBase());
-  ol.parseText(theTranslator->trCompoundReference(displayName(),
-               m_isObjC && m_compType==Interface ? Class : m_compType,
-               m_tempArgs!=0));
+  ol.parseText(pageTitle);
   addGroupListToTitle(ol,this);
   endTitle(ol,getOutputFileBase(),name());
 
   if (Config_getBool("SEARCHENGINE"))
   {
     Doxygen::searchIndex->setCurrentDoc(pageTitle,getOutputFileBase());
-    Doxygen::searchIndex->addWord(localName().lower());
+    Doxygen::searchIndex->addWord(localName(),TRUE);
   }
 
   ol.startTextBlock();
@@ -1346,6 +1425,10 @@ void ClassDef::writeDocumentation(OutputList &ol)
                   theTranslator->trRelatedFunctions(),
                   theTranslator->trRelatedSubscript()
                  ); 
+
+  // nested classes
+  m_innerClasses->writeDeclaration(ol,0,0,TRUE);
+  
   ol.endMemberSections();
     
   // write detailed description
@@ -1384,73 +1467,7 @@ void ClassDef::writeDocumentation(OutputList &ol)
   ol.pushGeneratorState();
   ol.disable(OutputGenerator::Man);
 
-  if (Config_getBool("SHOW_USED_FILES"))
-  {
-    ol.writeRuler();
-    ol.parseText(theTranslator->trGeneratedFromFiles(
-          m_isObjC && m_compType==Interface ? Class : m_compType,
-          m_files.count()==1));
-
-    bool first=TRUE;
-    const char *file = m_files.first();
-    while (file)
-    {
-      bool ambig;
-      FileDef *fd=findFileDef(Doxygen::inputNameDict,file,ambig);
-      if (fd)
-      {
-        if (first)
-        {
-          first=FALSE;   
-          ol.startItemList();
-        }
-
-        ol.writeListItem();
-        QCString path=fd->getPath().copy();
-        if (Config_getBool("FULL_PATH_NAMES"))
-        {
-          ol.docify(stripFromPath(path));
-        }
-
-        // for HTML 
-        ol.pushGeneratorState();
-        ol.disableAllBut(OutputGenerator::Html);
-        if (fd->generateSourceFile())
-        {
-          ol.writeObjectLink(0,fd->getSourceFileBase(),0,fd->name());
-        }
-        else if (fd->isLinkable())
-        {
-          ol.writeObjectLink(fd->getReference(),fd->getOutputFileBase(),0,
-              fd->name());
-        }
-        else
-        {
-          ol.docify(fd->name());
-        }
-        ol.popGeneratorState();
-
-        // for other output formats
-        ol.pushGeneratorState();
-        ol.disable(OutputGenerator::Html);
-        if (fd->isLinkable())
-        {
-          ol.writeObjectLink(fd->getReference(),fd->getOutputFileBase(),0,
-              fd->name());
-        }
-        else
-        {
-          ol.docify(fd->name());
-        }
-
-        ol.popGeneratorState();
-
-        
-      }
-      file=m_files.next();
-    }
-    if (!first) ol.endItemList();
-  }
+  showUsedFiles(ol);
 
   // write Author section (Man only)
   ol.enable(OutputGenerator::Man);
@@ -2492,8 +2509,8 @@ QCString ClassDef::compoundTypeString() const
     case Protocol:  return "protocol";
     case Category:  return "category";
     case Exception: return "exception";
+    default:        return "unknown";
   }
-  return "unknown";
 }
 
 QCString ClassDef::getOutputFileBase() const 
@@ -2642,6 +2659,26 @@ ClassDef *ClassDef::insertTemplateInstance(const QCString &fileName,
   return templateClass;
 }
 
+ClassDef *ClassDef::getVariableInstance(const char *templSpec)
+{
+  if (m_variableInstances==0) 
+  {
+    m_variableInstances = new QDict<ClassDef>(17);
+    m_variableInstances->setAutoDelete(TRUE);
+  }
+  ClassDef *templateClass=m_variableInstances->find(templSpec);
+  if (templateClass==0)
+  {
+    Debug::print(Debug::Classes,0,"      New template variable instance class `%s'`%s'\n",name().data(),templSpec);
+    templateClass = new ClassDef("<code>",1,name()+templSpec,
+                        ClassDef::Class,0,0,FALSE);
+    templateClass->addMembersToTemplateInstance( this, templSpec );
+    templateClass->setTemplateMaster(this);
+    m_variableInstances->insert(templSpec,templateClass);
+  }
+  return templateClass;
+}
+
 void ClassDef::setTemplateBaseClassNames(QDict<int> *templateNames)
 {
   if (templateNames==0) return;
@@ -2806,6 +2843,8 @@ QCString ClassDef::className() const
 
 void ClassDef::addListReferences()
 {
+  if (!isLinkableInProject()) return;
+  //printf("ClassDef(%s)::addListReferences()\n",name().data());
   addRefItem(xrefListItems(),
              theTranslator->trClass(TRUE,TRUE),
              getOutputFileBase(),displayName()
