@@ -75,6 +75,7 @@ class ClassDef : public Definition
     QCString getReference() const;
     bool isReference() const;
     bool isLocal() const { return m_isLocal; }
+    bool isArtificial() const { return m_artificial; }
 
     bool hasDocumentation() const;
 
@@ -160,6 +161,8 @@ class ClassDef : public Definition
      */
     ClassDef *templateMaster() const { return m_templateMaster; } 
 
+    bool isTemplate() const { return m_tempArgs!=0; }
+
     IncludeInfo *includeInfo() const { return m_incInfo; }
     
     UsesClassDict *usedImplementationClasses() const 
@@ -290,6 +293,7 @@ class ClassDef : public Definition
     //QCString getTemplateArgumentMapping(const char *formal) const;
     ClassDef *insertTemplateInstance(const QCString &fileName,int startLine,
                                 const QCString &templSpec,bool &freshInstance);
+    ClassDef *getVariableInstance(const char *templSpec);
     void setTemplateBaseClassNames(QDict<int> *templateNames);
     QDict<int> *getTemplateBaseClassNames() const;
     void setTemplateMaster(ClassDef *tm) { m_templateMaster=tm; }
@@ -329,6 +333,7 @@ class ClassDef : public Definition
     void addUsedInterfaceClasses(MemberDef *md,const char *typeStr);
     bool hasExamples();
     bool hasNonReferenceSuperClass();
+    void showUsedFiles(OutputList &ol);
 
     /*! \} Interal API */
 
@@ -416,6 +421,12 @@ class ClassDef : public Definition
      */ 
     QDict<ClassDef> *m_templateInstances;
 
+    /*! Template instances that exists of this class, as defined by variables.
+     *  We do NOT want to document these individually. The key in the
+     *  dictionary is the template argument list.
+     */ 
+    QDict<ClassDef> *m_variableInstances;
+
     QDict<int> *m_templBaseClassNames;
 
     /*! The class this class is an instance of. */
