@@ -164,7 +164,9 @@ void Definition::writeDocAnchorsToTagFile()
       {
         //printf("write an entry!\n");
         if (definitionType()==TypeMember) Doxygen::tagFile << "  ";
-        Doxygen::tagFile << "    <docanchor>" << si->label << "</docanchor>" << endl;
+        Doxygen::tagFile << "    <docanchor file=\"" 
+                         << si->fileName << "\">" << si->label 
+                         << "</docanchor>" << endl;
       }
     }
   }
@@ -246,7 +248,7 @@ static bool readCodeFragment(const char *fileName,
 {
   //printf("readCodeFragment(%s,%d,%d)\n",fileName,startLine,endLine);
   if (fileName==0 || fileName[0]==0) return FALSE; // not a valid file name
-  QCString cmd=Config_getString("INPUT_FILTER")+" \""+fileName+"\"";
+  QCString cmd=getFileFilter(fileName)+" \""+fileName+"\"";
   FILE *f = Config_getBool("FILTER_SOURCE_FILES") ? popen(cmd,"r") : fopen(fileName,"r");
   bool found=FALSE;
   if (f)
@@ -355,10 +357,6 @@ void Definition::writeSourceDef(OutputList &ol,const char *)
   //printf("Definition::writeSourceRef %d %p\n",bodyLine,bodyDef);
   if (Config_getBool("SOURCE_BROWSER") && m_startBodyLine!=-1 && m_bodyDef)
   {
-    ol.disable(OutputGenerator::RTF);
-    ol.newParagraph();
-    ol.enableAll();
-
     QCString refText = theTranslator->trDefinedAtLineInSourceFile();
     int lineMarkerPos = refText.find("@0");
     int fileMarkerPos = refText.find("@1");
@@ -367,6 +365,7 @@ void Definition::writeSourceDef(OutputList &ol,const char *)
       QCString lineStr,anchorStr;
       lineStr.sprintf("%d",m_startBodyLine);
       anchorStr.sprintf("l%05d",m_startBodyLine);
+      ol.newParagraph();
       if (lineMarkerPos<fileMarkerPos) // line marker before file marker
       {
         // write text left from linePos marker
@@ -436,10 +435,6 @@ void Definition::writeSourceDef(OutputList &ol,const char *)
     {
       err("Error: translation error: invalid markers in trDefinedInSourceFile()\n");
     }
-
-    ol.disableAllBut(OutputGenerator::RTF);
-    ol.newParagraph();
-    ol.enableAll();
   }
   ol.popGeneratorState();
 }
@@ -462,11 +457,11 @@ void Definition::writeInlineCode(OutputList &ol,const char *scopeName)
       initParseCodeContext();
       //printf("Read:\n`%s'\n\n",codeFragment.data());
       if (definitionType()==TypeMember) setParameterList((MemberDef *)this);
-      ol.newParagraph();
       ol.startCodeFragment();
       parseCode(ol,scopeName,codeFragment,FALSE,0,
           m_bodyDef,actualStart,actualEnd,TRUE);
       ol.endCodeFragment();
+      ol.newParagraph();
     }
   }
   ol.popGeneratorState();
@@ -568,12 +563,18 @@ void Definition::writeSourceRefList(OutputList &ol,const char *scopeName,
 
 void Definition::writeSourceReffedBy(OutputList &ol,const char *scopeName)
 {
-  writeSourceRefList(ol,scopeName,theTranslator->trReferencedBy(),m_sourceRefByDict,FALSE);
+  if (Config_getBool("REFERENCED_BY_RELATION"))
+  {
+    writeSourceRefList(ol,scopeName,theTranslator->trReferencedBy(),m_sourceRefByDict,FALSE);
+  }
 }
 
 void Definition::writeSourceRefs(OutputList &ol,const char *scopeName)
 {
-  writeSourceRefList(ol,scopeName,theTranslator->trReferences(),m_sourceRefsDict,TRUE);
+  if (Config_getBool("REFERENCES_RELATION"))
+  {
+    writeSourceRefList(ol,scopeName,theTranslator->trReferences(),m_sourceRefsDict,TRUE);
+  }
 }
 
 bool Definition::hasDocumentation() const
@@ -758,3 +759,51 @@ QCString Definition::convertNameToFile(const char *name,bool allowDots) const
   }
 }
 
+void Definition::writePathFragment(OutputList &ol) const
+{
+  if (m_outerScope && m_outerScope!=Doxygen::globalScope)
+  {
+    m_outerScope->writePathFragment(ol);
+    if (m_outerScope->definitionType()==Definition::TypeClass ||
+        m_outerScope->definitionType()==Definition::TypeNamespace)
+    {
+      if (Config_getBool("OPTIMIZE_OUTPUT_JAVA"))
+      {
+        ol.writeString(".");
+      }
+      else
+      {
+        ol.writeString("::");
+      }
+    }
+    else
+    {
+      ol.writeString("&nbsp;");
+      ol.writeString("/");
+      ol.writeString("&nbsp;");
+    }
+  }
+  if (isLinkable())
+  {
+    ol.writeObjectLink(getReference(),getOutputFileBase(),0,m_localName);
+  }
+  else
+  {
+    ol.startBold();
+    ol.docify(m_localName);
+    ol.endBold();
+  }
+}
+
+void Definition::writeNavigationPath(OutputList &ol) const
+{
+  ol.pushGeneratorState();
+  ol.disableAllBut(OutputGenerator::Html);
+
+  ol.writeString("<div class=\"nav\">\n");
+  writePathFragment(ol);
+  ol.writeString("</div>\n");
+
+  ol.popGeneratorState();
+}
+
