@@ -48,7 +48,7 @@ class Definition
     enum DefType 
     { 
       TypeClass, TypeMember, TypeFile, TypeGroup, 
-      TypeNamespace, TypePackage, TypePage
+      TypeNamespace, TypePackage, TypePage, TypeDir
     };
     /*! Use this for dynamic inspection of the type of the derived class */
     virtual DefType definitionType() = 0;
@@ -193,7 +193,12 @@ class Definition
     GroupList *partOfGroups() const { return m_partOfGroups; }
     QCString convertNameToFile(const char *name,bool allowDots=FALSE) const;
 
+    void writePathFragment(OutputList &ol) const;
+    void writeNavigationPath(OutputList &ol) const;
+
   protected:
+    void setLocalName(const QCString name) { m_localName=name; }
+    
     int      m_startBodyLine;   // line number of the start of the definition
     int      m_endBodyLine;     // line number of the end of the definition
     FileDef *m_bodyDef;         // file definition containing the function body
