@@ -69,7 +69,7 @@ class DocRef;
 class DocFormula;
 class DocSecRefItem;
 class DocSecRefList;
-class DocLanguage;
+//class DocLanguage;
 class DocLinkedWord;
 class DocParamSect;
 class DocParamList;
@@ -163,8 +163,8 @@ class DocVisitor
     virtual void visitPost(DocSecRefItem *) = 0;
     virtual void visitPre(DocSecRefList *) = 0;
     virtual void visitPost(DocSecRefList *) = 0;
-    virtual void visitPre(DocLanguage *) = 0;
-    virtual void visitPost(DocLanguage *) = 0;
+    //virtual void visitPre(DocLanguage *) = 0;
+    //virtual void visitPost(DocLanguage *) = 0;
     virtual void visitPre(DocParamSect *) = 0;
     virtual void visitPost(DocParamSect *) = 0;
     virtual void visitPre(DocParamList *) = 0;
