@@ -30,6 +30,10 @@ class QTextStream;
 class DotNodeList;
 class ClassSDict;
 class MemberDef;
+class Definition;
+class DirDef;
+class GroupDef;
+class DotGroupCollaboration;
 
 enum GraphOutputFormat { BITMAP , EPS };
 
@@ -64,8 +68,9 @@ class DotNode
     void deleteNode(DotNodeList &deletedList,SDict<DotNode> *skipNodes=0);
     void removeChild(DotNode *n);
     void removeParent(DotNode *n);
+    int findParent( DotNode *n );
     void write(QTextStream &t,GraphType gt,GraphOutputFormat f,
-               bool topDown,bool toChildren,int maxDistance,bool backArrows);
+               bool topDown,bool toChildren,int maxDistance,bool backArrows,bool reNumber);
     int  m_subgraphId;
     void clearWriteFlag();
     void writeXML(QTextStream &t,bool isClassGraph);
@@ -76,9 +81,9 @@ class DotNode
   private:
     void colorConnectedNodes(int curColor);
     void writeBox(QTextStream &t,GraphType gt,GraphOutputFormat f,
-                  bool hasNonReachableChildren);
+                  bool hasNonReachableChildren, bool reNumber=FALSE);
     void writeArrow(QTextStream &t,GraphType gt,GraphOutputFormat f,DotNode *cn,
-                    EdgeInfo *ei,bool topDown, bool pointBack=TRUE);
+                    EdgeInfo *ei,bool topDown, bool pointBack=TRUE, bool reNumber=FALSE);
     const DotNode   *findDocNode() const; // only works for acyclic graphs!
     int              m_number;
     QCString         m_label;     //!< label text
@@ -98,11 +103,13 @@ class DotNode
     friend class DotInclDepGraph;
     friend class DotNodeList;
     friend class DotCallGraph;
+    friend class DotGroupCollaboration;
+
     friend void writeDotGraph(
                       DotNode *root, GraphType gt,
                       GraphOutputFormat f, const QCString &baseName,
                       bool lrRank, bool renderParents,
-                      int distance, bool backArrows
+                      int distance, bool backArrows, bool reNumber
                      );
     friend QCString computeMd5Signature(
                       DotNode *root, GraphType gt,
@@ -111,6 +118,13 @@ class DotNode
                       int distance, bool backArrows
                      );
 };
+inline
+int DotNode::findParent( DotNode *n )
+{
+    if( !m_parents )
+        return -1;
+    return m_parents->find(n);
+}
 
 class DotGfxHierarchyTable
 {
@@ -197,12 +211,108 @@ class DotCallGraph
     int             m_maxDistance;
     int             m_recDepth;
     QCString        m_diskName;
+    Definition *    m_scope;
 };
 
+class DotDirDeps
+{
+  public:
+    DotDirDeps(DirDef *dir);
+   ~DotDirDeps();
+    bool isTrivial() const;
+    QCString writeGraph(QTextStream &out,
+                        GraphOutputFormat format,
+                        const char *path,
+                        const char *relPath,
+                        bool writeImageMap=TRUE);
+  private:
+    DirDef *m_dir;
+};
+
+class DotGroupCollaboration
+{
+  public :
+    enum EdgeType 
+    {  tmember = 0,
+       tclass,
+       tnamespace,
+       tfile,
+       tpages,
+       tdir,
+       thierarchy 
+    };
+
+    class Link
+    {
+      public:
+        Link(const QCString lab,const QCString &u) : label(lab), url(u) {}
+        QCString label;
+        QCString url;
+    };
+
+    class Edge
+    {
+      public :
+        Edge(DotNode *start,DotNode *end,EdgeType type) 
+          : pNStart(start), pNEnd(end), eType(type)
+        { links.setAutoDelete(TRUE); }
+
+        DotNode* pNStart;
+        DotNode* pNEnd;
+        EdgeType eType;
+
+        QList<Link> links;
+        void write( QTextStream &t, int& curNodeId );
+    };
+
+    DotGroupCollaboration(GroupDef* gd);
+    ~DotGroupCollaboration();
+    QCString writeGraph(QTextStream &t, GraphOutputFormat format,
+                    const char *path,const char *relPath,
+                    bool writeImageMap=TRUE);
+    void buildGraph(GroupDef* gd,int distance);
+    bool isTrivial() const;
+  private :
+    void addCollaborationMember( Definition* def, QCString& url, EdgeType eType );
+    void addMemberList( class MemberList* ml );
+    void writeGraphHeader(QTextStream &t);
+    Edge* addEdge( DotNode* _pNStart, DotNode* _pNEnd, EdgeType _eType,
+                   const QCString& _label, const QCString& _url );
+
+    DotNode        *m_rootNode;
+    int             m_curNodeId;
+    QDict<DotNode> *m_usedNodes;
+    QCString        m_diskName;
+    QList<Edge>     m_edges;
+};
+
+/** @brief Helper class to run dot from doxygen.
+ */
+class DotRunner
+{
+  public:
+    /** Creates a runner for a dot \a file. */
+    DotRunner(const char *file);
+
+    /** Adds an additional job to the run.
+     *  Performing multiple jobs one file can be faster.
+     */
+    void addJob(const char *format,const char *output);
+
+    /** Runs dot for all jobs added. */
+    bool run();
+  private:
+    QList<QCString> m_jobs;
+    QCString m_file;
+};
+
+
+
 void generateGraphLegend(const char *path);
 void writeDotGraphFromFile(const char *inFile,const char *outDir,
                            const char *outFile,GraphOutputFormat format);
-QString getDotImageMapFromFile(const QString& inFile, const QString& outDir);
+QString getDotImageMapFromFile(const QString& inFile, const QString& outDir,
+                               const QCString& relPath);
 
 
 #endif
