@@ -230,17 +230,20 @@ class Entry
       USINGDECL_SEC    = 0x14000000,
       PACKAGE_SEC      = 0x15000000,
       PACKAGEDOC_SEC   = 0x16000000,
-      OBJCIMPL_SEC     = 0x17000000
+      OBJCIMPL_SEC     = 0x17000000,
+      DIRDOC_SEC       = 0x18000000,
     };
     enum MemberSpecifier
     {
-      Inline    = 0x01,
-      Explicit  = 0x02,
-      Mutable   = 0x04,
-      Settable  = 0x08,
-      Gettable  = 0x10,
-      Readable  = 0x20,
-      Writable  = 0x40
+      Inline    = 0x0001,
+      Explicit  = 0x0002,
+      Mutable   = 0x0004,
+      Settable  = 0x0008,
+      Gettable  = 0x0010,
+      Readable  = 0x0020,
+      Writable  = 0x0040,
+      Final     = 0x0080,
+      Abstract  = 0x0100,
     };
 
     Entry();
@@ -289,6 +292,8 @@ class Entry
     QCString     inbodyFile;  //!< file in which the body doc was found
     QCString     relates;     //!< related class (doc block)
     bool         relatesDup;  //!< keep duplicate doc in original file also
+    QCString     read;        //!< property read accessor
+    QCString     write;       //!< property write accessor
     QCString     inside;      //!< name of the class in which documents are found
     QCString     exception;   //!< throw specification
     int          bodyLine;    //!< line number of the definition in the source
