@@ -34,6 +34,11 @@
 #include "searchindex.h"
 //#include "xml.h"
 
+#if defined(_MSC_VER) || defined(__BORLANDC__)
+#define popen _popen
+#define pclose _pclose
+#endif
+
 class DevNullCodeDocInterface : public BaseCodeDocInterface
 {
   public:
@@ -84,12 +89,14 @@ FileDef::FileDef(const char *p,const char *nm,
   package = 0;
   isSource = FALSE; 
   docname = nm;
+  dir = 0;
   if (Config_getBool("FULL_PATH_NAMES"))
   {
     docname.prepend(stripFromPath(path.copy()));
   }
   memberGroupSDict = new MemberGroupSDict;
   memberGroupSDict->setAutoDelete(TRUE);
+  acquireFileVersion();
 }
 
 /*! destroy the file definition */
@@ -211,18 +218,50 @@ void FileDef::writeDocumentation(OutputList &ol)
 
   //printf("WriteDocumentation diskname=%s\n",diskname.data());
   
-  QCString pageTitle=name()+" File Reference";
+  QCString versionTitle;
+  if (!fileVersion.isEmpty())
+  {
+    versionTitle=("("+fileVersion+")");
+  }
+  QCString title = docname+versionTitle;
+  QCString pageTitle=theTranslator->trFileReference(docname);
   startFile(ol,getOutputFileBase(),name(),pageTitle);
-  startTitle(ol,getOutputFileBase());
-  ol.parseText(theTranslator->trFileReference(docname));
-  addGroupListToTitle(ol,this);
-  endTitle(ol,getOutputFileBase(),docName());
-  //ol.newParagraph();
+
+  if (Config_getBool("SHOW_DIRECTORIES") && getDirDef())
+  {
+    getDirDef()->writeNavigationPath(ol);
+    QCString pageTitleShort=theTranslator->trFileReference(name());
+    startTitle(ol,getOutputFileBase());
+    ol.pushGeneratorState();
+      ol.disableAllBut(OutputGenerator::Html);
+      ol.parseText(pageTitleShort); // Html only
+      ol.enableAll();
+      ol.disable(OutputGenerator::Html);
+      ol.parseText(pageTitle); // other output formats
+    ol.popGeneratorState();
+    addGroupListToTitle(ol,this);
+    endTitle(ol,getOutputFileBase(),title);
+  }
+  else
+  {
+    startTitle(ol,getOutputFileBase());
+    ol.parseText(pageTitle);
+    addGroupListToTitle(ol,this);
+    endTitle(ol,getOutputFileBase(),title);
+  }
+  if (!fileVersion.isEmpty())
+  {
+    ol.disableAllBut(OutputGenerator::Html);
+    ol.startProjectNumber();
+    ol.docify(versionTitle);
+    ol.endProjectNumber();
+    ol.enableAll();
+  }
   
   if (Config_getBool("SEARCHENGINE"))
   {
     Doxygen::searchIndex->setCurrentDoc(pageTitle,getOutputFileBase());
-    Doxygen::searchIndex->addWord(localName().lower());
+    Doxygen::searchIndex->addWord(localName(),TRUE);
   }
   
   if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
@@ -235,28 +274,37 @@ void FileDef::writeDocumentation(OutputList &ol)
                      << "</filename>" << endl;
   }
   
-  ol.startTextBlock();
   if (Config_getBool("DETAILS_AT_TOP"))
   {
+    ol.startTextBlock(); 
     writeDetailedDocumentation(ol);
+    ol.endTextBlock();
+
+    ol.pushGeneratorState();
+    ol.disable(OutputGenerator::Man);
+    ol.disable(OutputGenerator::RTF);
     ol.newParagraph();
+    ol.popGeneratorState();
   }
-  else if (briefDescription()) 
+  else if (!briefDescription().isEmpty()) 
   {
     ol.parseDoc(briefFile(),briefLine(),this,0,briefDescription(),TRUE,FALSE);
-    ol.writeString(" \n");
+    //ol.writeString(" \n");
     ol.disableAllBut(OutputGenerator::Html);
     ol.startTextLink(0,"_details");
     ol.parseText(theTranslator->trMore());
     ol.endTextLink();
     ol.enableAll();
+
+    ol.pushGeneratorState();
     ol.disable(OutputGenerator::Man);
+    ol.disable(OutputGenerator::RTF);
     ol.newParagraph();
-    ol.enable(OutputGenerator::Man);
+    ol.popGeneratorState();
   }
   ol.writeSynopsis();
  
-  if (Config_getBool("SHOW_INCLUDE_FILES"))
+  if (Config_getBool("SHOW_INCLUDE_FILES") && includeList->count()>0)
   {
     ol.startTextBlock(TRUE);
     QListIterator<IncludeInfo> ili(*includeList);
@@ -272,11 +320,15 @@ void FileDef::writeDocumentation(OutputList &ol)
                       fd->name().right(5)==".java";
       }
       ol.startTypewriter();
-      if (isIDLorJava)
+      if (isIDLorJava) // IDL/Java include
       {
         ol.docify("import ");
       }
-      else
+      else if (ii->imported) // Objective-C include
+      {
+        ol.docify("#import ");
+      }
+      else // C/C++ include
       {
         ol.docify("#include ");
       }
@@ -299,12 +351,13 @@ void FileDef::writeDocumentation(OutputList &ol)
             0,ii->includeName);
         if (!Config_getString("GENERATE_TAGFILE").isEmpty() && !fd->isReference()) 
         {
-          const char *locStr = (ii->local || isIDLorJava) ? "yes" : "no";
+          const char *locStr = (ii->local    || isIDLorJava) ? "yes" : "no";
+          const char *impStr = (ii->imported || isIDLorJava) ? "yes" : "no";
           Doxygen::tagFile << "    <includes id=\"" 
-                           << convertToXML(fd->getOutputFileBase()) 
-                           << "\" name=\"" 
-                           << convertToXML(fd->name())
-                           << "\" local=\"" << locStr << "\">" 
+                           << convertToXML(fd->getOutputFileBase()) << "\" "
+                           << "name=\"" << convertToXML(fd->name()) << "\" "
+                           << "local=\"" << locStr << "\" "
+                           << "imported=\"" << impStr << "\">"
                            << convertToXML(ii->includeName)
                            << "</includes>" 
                            << endl;
@@ -323,12 +376,7 @@ void FileDef::writeDocumentation(OutputList &ol)
       if (isIDLorJava) 
         ol.docify(";");
       ol.endTypewriter();
-      ol.disable(OutputGenerator::RTF);
       ol.lineBreak();
-      ol.enableAll();
-      ol.disableAllBut(OutputGenerator::RTF);
-      ol.newParagraph();
-      ol.enableAll();
     }
     ol.endTextBlock();
   }
@@ -339,12 +387,14 @@ void FileDef::writeDocumentation(OutputList &ol)
     DotInclDepGraph incDepGraph(this,Config_getInt("MAX_DOT_GRAPH_DEPTH"),FALSE);
     if (!incDepGraph.isTrivial())
     {
+      ol.startTextBlock(); 
       ol.disable(OutputGenerator::Man);
       ol.newParagraph();
       ol.startInclDepGraph();
       ol.parseText(theTranslator->trInclDepGraph(name()));
       ol.endInclDepGraph(incDepGraph);
       ol.enableAll();
+      ol.endTextBlock(TRUE);
     }
     //incDepGraph.writeGraph(Config_getString("HTML_OUTPUT"),fd->getOutputFileBase());
   }
@@ -355,12 +405,14 @@ void FileDef::writeDocumentation(OutputList &ol)
     DotInclDepGraph incDepGraph(this,Config_getInt("MAX_DOT_GRAPH_DEPTH"),TRUE);
     if (!incDepGraph.isTrivial())
     {
+      ol.startTextBlock(); 
       ol.disable(OutputGenerator::Man);
       ol.newParagraph();
       ol.startInclDepGraph();
       ol.parseText(theTranslator->trInclByDepGraph());
       ol.endInclDepGraph(incDepGraph);
       ol.enableAll();
+      ol.endTextBlock(TRUE);
     }
     //incDepGraph.writeGraph(Config_getString("HTML_OUTPUT"),fd->getOutputFileBase());
   }
@@ -376,8 +428,6 @@ void FileDef::writeDocumentation(OutputList &ol)
     ol.enableAll();
   }
   
-  ol.endTextBlock();
-  
   ol.startMemberSections();
 
   if (namespaceSDict->count()>0)
@@ -489,11 +539,28 @@ void FileDef::writeDocumentation(OutputList &ol)
 /*! Write a source listing of this file to the output */
 void FileDef::writeSource(OutputList &ol)
 {
+  QCString title = docname;
+  if (!fileVersion.isEmpty())
+  {
+    title+=(" ("+fileVersion+")");
+  }
+  QCString pageTitle = theTranslator->trSourceFile(title);
   ol.disableAllBut(OutputGenerator::Html);
-  startFile(ol,getSourceFileBase(),0,docname+" Source File");
-  startTitle(ol,0);
-  ol.parseText(docname);
-  endTitle(ol,0,0);
+  startFile(ol,getSourceFileBase(),0,pageTitle);
+
+  if (Config_getBool("SHOW_DIRECTORIES") && getDirDef())
+  {
+    getDirDef()->writeNavigationPath(ol);
+    startTitle(ol,getOutputFileBase());
+    ol.parseText(name());
+    endTitle(ol,getOutputFileBase(),title);
+  }
+  else
+  {
+    startTitle(ol,0);
+    ol.parseText(title);
+    endTitle(ol,0,0);
+  }
 
   if (isLinkable())
   {
@@ -543,66 +610,30 @@ void FileDef::insertMember(MemberDef *md)
   {
     case MemberDef::Variable:     
     case MemberDef::Property:     
-      if (sortBriefDocs)
-        decVarMembers.inSort(md);
-      else
-        decVarMembers.append(md);
-      if (sortMemberDocs)
-        docVarMembers.inSort(md); 
-      else
-        docVarMembers.append(md);
+      if (sortBriefDocs)  decVarMembers.inSort(md); else decVarMembers.append(md);
+      if (sortMemberDocs) docVarMembers.inSort(md); else docVarMembers.append(md);
       break;
     case MemberDef::Function: 
-      if (sortBriefDocs)
-        decFuncMembers.inSort(md);
-      else
-        decFuncMembers.append(md);
-      if (sortMemberDocs)    
-        docFuncMembers.inSort(md); 
-      else
-        docFuncMembers.append(md);
+      if (sortBriefDocs)  decFuncMembers.inSort(md); else decFuncMembers.append(md);
+      if (sortMemberDocs) docFuncMembers.inSort(md); else docFuncMembers.append(md);
       break;
     case MemberDef::Typedef:      
-      if (sortBriefDocs)
-        decTypedefMembers.inSort(md);
-      else
-        decTypedefMembers.append(md);
-      if (sortMemberDocs)
-        docTypedefMembers.inSort(md); 
-      else
-        docTypedefMembers.append(md);
+      if (sortBriefDocs)  decTypedefMembers.inSort(md); else decTypedefMembers.append(md);
+      if (sortMemberDocs) docTypedefMembers.inSort(md); else docTypedefMembers.append(md);
       break;
     case MemberDef::Enumeration:  
-      if (sortBriefDocs)
-        decEnumMembers.inSort(md);
-      else
-        decEnumMembers.append(md);
-      if (sortMemberDocs)
-        docEnumMembers.inSort(md); 
-      else
-        docEnumMembers.append(md);
+      if (sortBriefDocs)  decEnumMembers.inSort(md); else decEnumMembers.append(md);
+      if (sortMemberDocs) docEnumMembers.inSort(md); else docEnumMembers.append(md);
       break;
     case MemberDef::EnumValue:    // enum values are shown inside their enums
       break;
     case MemberDef::Prototype:    
-      if (sortBriefDocs)
-        decProtoMembers.inSort(md);
-      else
-        decProtoMembers.append(md);
-      if (sortMemberDocs)
-        docProtoMembers.inSort(md); 
-      else
-        docProtoMembers.append(md);
+      if (sortBriefDocs)  decProtoMembers.inSort(md); else decProtoMembers.append(md);
+      if (sortMemberDocs) docProtoMembers.inSort(md); else docProtoMembers.append(md);
       break;
     case MemberDef::Define:       
-      if (sortBriefDocs)
-        decDefineMembers.inSort(md);
-      else
-        decDefineMembers.append(md);
-      if (sortMemberDocs)
-        docDefineMembers.inSort(md); 
-      else
-        docDefineMembers.append(md);
+      if (sortBriefDocs)  decDefineMembers.inSort(md); else decDefineMembers.append(md);
+      if (sortMemberDocs) docDefineMembers.inSort(md); else docDefineMembers.append(md);
       break;
     default:
        err("FileDef::insertMembers(): "
@@ -693,7 +724,8 @@ void FileDef::addUsingDeclaration(Definition *d)
   }
 }
 
-void FileDef::addIncludeDependency(FileDef *fd,const char *incName,bool local)
+void FileDef::addIncludeDependency(FileDef *fd,const char *incName,bool local,
+                                   bool imported)
 {
   //printf("FileDef::addIncludeDependency(%p,%s,%d)\n",fd,incName,local);
   QCString iName = fd ? fd->absFilePath().data() : incName;
@@ -703,6 +735,7 @@ void FileDef::addIncludeDependency(FileDef *fd,const char *incName,bool local)
     ii->fileDef     = fd;
     ii->includeName = incName;
     ii->local       = local;
+    ii->imported    = imported;
     includeList->append(ii);
     includeDict->insert(iName,ii);
   }
@@ -759,7 +792,8 @@ void FileDef::addIncludedUsingDirectives()
 }
 
 
-void FileDef::addIncludedByDependency(FileDef *fd,const char *incName,bool local)
+void FileDef::addIncludedByDependency(FileDef *fd,const char *incName,
+                                      bool local,bool imported)
 {
   //printf("FileDef::addIncludedByDependency(%p,%s,%d)\n",fd,incName,local);
   QCString iName = fd ? fd->absFilePath().data() : incName;
@@ -769,6 +803,7 @@ void FileDef::addIncludedByDependency(FileDef *fd,const char *incName,bool local
     ii->fileDef     = fd;
     ii->includeName = incName;
     ii->local       = local;
+    ii->imported    = imported;
     includedByList->append(ii);
     includedByDict->insert(iName,ii);
   }
@@ -925,6 +960,7 @@ static void mergeFileDef(Directory *root,FileDef *fd)
   dirNode->addChild(e);
 }
 
+#if 0
 static void generateIndent(QTextStream &t,DirEntry *de,int level)
 {
   if (de->parent())
@@ -970,7 +1006,6 @@ static void generateIndent(QTextStream &t,DirEntry *de,int level)
   }
 }
 
-
 static void writeDirTreeNode(QTextStream &t,Directory *root,int level)
 {
   QCString indent;
@@ -1001,12 +1036,44 @@ static void writeDirTreeNode(QTextStream &t,Directory *root,int level)
     }
   }
 }
+#endif
 
-void generateFileTree(QTextStream &t)
+static void addDirsAsGroups(Directory *root,GroupDef *parent,int level)
+{
+  GroupDef *gd=0;
+  if (root->kind()==DirEntry::Dir)
+  {
+    gd = new GroupDef("<generated>",
+                      1,
+                      root->path(), // name
+                      root->name()  // title
+                     );
+    if (parent) 
+    {
+      parent->addGroup(gd);
+      gd->makePartOfGroup(parent);
+    }
+    else
+    {
+      Doxygen::groupSDict.append(root->path(),gd);
+    }
+  }
+  QListIterator<DirEntry> dli(root->children());
+  DirEntry *de;
+  for (dli.toFirst();(de=dli.current());++dli)
+  {
+    if (de->kind()==DirEntry::Dir)
+    {
+      addDirsAsGroups((Directory *)de,gd,level+1);
+    }
+  }
+}
+
+void generateFileTree()
 {
   FTVHelp::generateTreeViewImages();
   
-  Directory *root=new Directory(0,"");
+  Directory *root=new Directory(0,"root");
   root->setLast(TRUE);
   FileNameListIterator fnli(Doxygen::inputNameList); 
   FileName *fn;
@@ -1019,12 +1086,15 @@ void generateFileTree(QTextStream &t)
       mergeFileDef(root,fd);
     }
   }
-  t << "<div class=\"directory\">\n";
-  writeDirTreeNode(t,root,0);
-  t << "</div>\n";
+  //t << "<div class=\"directory\">\n";
+  //writeDirTreeNode(t,root,0);
+  //t << "</div>\n";
+  addDirsAsGroups(root,0,0);
   delete root;
 }
 
+//-------------------------------------------------------------------
+
 void FileDef::combineUsingRelations()
 {
   if (visited) return; // already done
@@ -1065,4 +1135,39 @@ void FileDef::combineUsingRelations()
   }
 }
 
+bool FileDef::isDocumentationFile() const
+{
+  return name().right(4)==".doc" ||
+         name().right(4)==".txt" ||
+         name().right(4)==".dox";
+}
+
+void FileDef::acquireFileVersion()
+{
+  QCString vercmd = Config_getString("FILE_VERSION_FILTER");
+  if (!vercmd.isEmpty()) 
+  {
+    msg("Version of %s : ",filepath.data());
+    FILE *f=popen(vercmd+" "+filepath,"r");
+    if (!f)
+    {
+      err("Error: could not execute %s\n",vercmd.data());
+      return;
+    }
+    const int bufSize=1024;
+    char buf[bufSize];
+    int numRead = fread(buf,1,bufSize,f);
+    pclose(f);
+    if (numRead > 0) 
+    {
+      fileVersion = QCString(buf,numRead).stripWhiteSpace();
+      msg("%s\n",fileVersion.data());
+    }
+    else 
+    {
+      msg("no version available\n");
+    }
+  }
+}
+
 
