@@ -2,7 +2,7 @@
  *
  * $Id: groupdef.cpp,v 1.29 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2002 by Dimitri van Heesch.
+ * Copyright (C) 1997-2004 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -16,13 +16,13 @@
  */
 
 #include <ctype.h>
+#include <qregexp.h>
 #include "qtbc.h"
 #include "groupdef.h"
 #include "classdef.h"
 #include "filedef.h"
 #include "classlist.h"
 #include "outputlist.h"
-#include "doc.h"
 #include "namespacedef.h"
 #include "language.h"
 #include "util.h"
@@ -30,20 +30,31 @@
 #include "message.h"
 #include "membergroup.h"
 #include "doxygen.h"
-#include "page.h"
+#include "pagedef.h"
+#include "docparser.h"
+#include "searchindex.h"
+#include "dot.h"
 
-GroupDef::GroupDef(const char *df,int dl,const char *na,const char *t) : 
-   Definition(df,dl,na)
+GroupDef::GroupDef(const char *df,int dl,const char *na,const char *t,
+                   const char *refFileName) : Definition(df,dl,na)
 {
   fileList = new FileList;
-  classSDict = new ClassSDict(257);
+  classSDict = new ClassSDict(17);
   groupList = new GroupList;
-  namespaceList = new NamespaceList;
-  pageDict = new PageSDict(257);
-  exampleDict = new PageSDict(257);
+  namespaceSDict = new NamespaceSDict(17);
+  pageDict = new PageSDict(17);
+  exampleDict = new PageSDict(17);
+  dirList = new DirList;
   allMemberList = new MemberList;
   allMemberNameInfoSDict = new MemberNameInfoSDict(17);
-  fileName = (QCString)"group_"+na;
+  if (refFileName)
+  {
+    fileName=stripExtension(refFileName);
+  }
+  else
+  {
+    fileName = (QCString)"group_"+na;
+  }
   setGroupTitle( t );
   memberGroupSDict = new MemberGroupSDict;
   memberGroupSDict->setAutoDelete(TRUE);
@@ -71,12 +82,13 @@ GroupDef::~GroupDef()
   delete fileList;
   delete classSDict;
   delete groupList;
-  delete namespaceList;
+  delete namespaceSDict;
   delete pageDict;
   delete exampleDict;
   delete allMemberList;
   delete allMemberNameInfoSDict;
   delete memberGroupSDict;
+  delete dirList;
 }
 
 void GroupDef::setGroupTitle( const char *t )
@@ -105,9 +117,26 @@ void GroupDef::distributeMemberGroupDocumentation()
   }
 }
 
+void GroupDef::findSectionsInDocumentation()
+{
+  docFindSections(documentation(),this,0,docFile());
+  MemberGroupSDict::Iterator mgli(*memberGroupSDict);
+  MemberGroup *mg;
+  for (;(mg=mgli.current());++mgli)
+  {
+    mg->findSectionsInDocumentation();
+  }
+  decDefineMembers.findSectionsInDocumentation();
+  decProtoMembers.findSectionsInDocumentation();
+  decTypedefMembers.findSectionsInDocumentation();
+  decEnumMembers.findSectionsInDocumentation();
+  decFuncMembers.findSectionsInDocumentation();
+  decVarMembers.findSectionsInDocumentation();
+}
+
 void GroupDef::addFile(const FileDef *def)
 {
-  if (Config_getBool("SORT_MEMBER_DOCS"))
+  if (Config_getBool("SORT_BRIEF_DOCS"))
     fileList->inSort(def);
   else
     fileList->append(def);
@@ -115,7 +144,7 @@ void GroupDef::addFile(const FileDef *def)
 
 void GroupDef::addClass(const ClassDef *cd)
 {
-  if (Config_getBool("SORT_MEMBER_DOCS"))
+  if (Config_getBool("SORT_BRIEF_DOCS"))
     classSDict->inSort(cd->name(),cd);
   else
     classSDict->append(cd->name(),cd);
@@ -123,34 +152,42 @@ void GroupDef::addClass(const ClassDef *cd)
 
 void GroupDef::addNamespace(const NamespaceDef *def)
 {
-  if (Config_getBool("SORT_MEMBER_DOCS"))
-    namespaceList->inSort(def);  
+  if (Config_getBool("SORT_BRIEF_DOCS"))
+    namespaceSDict->inSort(def->name(),def);  
   else
-    namespaceList->append(def);
+    namespaceSDict->append(def->name(),def);
 }
 
-void GroupDef::addPage(PageInfo *def)
+void GroupDef::addDir(const DirDef *def)
+{
+  if (Config_getBool("SORT_BRIEF_DOCS"))
+    dirList->inSort(def);  
+  else
+    dirList->append(def);
+}
+
+void GroupDef::addPage(PageDef *def)
 {
   //printf("Making page %s part of a group\n",def->name.data());
-  pageDict->append(def->name,def);
+  pageDict->append(def->name(),def);
   def->makePartOfGroup(this);
 }
 
-void GroupDef::addExample(const PageInfo *def)
+void GroupDef::addExample(const PageDef *def)
 {
-  exampleDict->append(def->name,def);
+  exampleDict->append(def->name(),def);
 }
 
 
 void GroupDef::addMembersToMemberGroup()
 {
-  ::addMembersToMemberGroup(&decDefineMembers,memberGroupSDict);
-  ::addMembersToMemberGroup(&decProtoMembers,memberGroupSDict);
-  ::addMembersToMemberGroup(&decTypedefMembers,memberGroupSDict);
-  ::addMembersToMemberGroup(&decEnumMembers,memberGroupSDict);
-  ::addMembersToMemberGroup(&decEnumValMembers,memberGroupSDict);
-  ::addMembersToMemberGroup(&decFuncMembers,memberGroupSDict);
-  ::addMembersToMemberGroup(&decVarMembers,memberGroupSDict);
+  ::addMembersToMemberGroup(&decDefineMembers,memberGroupSDict,this);
+  ::addMembersToMemberGroup(&decProtoMembers,memberGroupSDict,this);
+  ::addMembersToMemberGroup(&decTypedefMembers,memberGroupSDict,this);
+  ::addMembersToMemberGroup(&decEnumMembers,memberGroupSDict,this);
+  ::addMembersToMemberGroup(&decEnumValMembers,memberGroupSDict,this);
+  ::addMembersToMemberGroup(&decFuncMembers,memberGroupSDict,this);
+  ::addMembersToMemberGroup(&decVarMembers,memberGroupSDict,this);
 
   //printf("GroupDef::addMembersToMemberGroup() memberGroupList=%d\n",memberGroupList->count());
   MemberGroupSDict::Iterator mgli(*memberGroupSDict);
@@ -173,17 +210,27 @@ bool GroupDef::insertMember(MemberDef *md,bool docOnly)
     for ( ; (srcMi=srcMnii.current()) ; ++srcMnii )
     {
       MemberDef *srcMd = srcMi->memberDef;
+      if (srcMd==md) return FALSE; // already added before!
 
       bool sameScope = srcMd->getOuterScope()==md->getOuterScope() || // same class or namespace
           // both inside a file => definition and declaration do not have to be in the same file
            (srcMd->getOuterScope()->definitionType()==Definition::TypeFile &&
             md->getOuterScope()->definitionType()==Definition::TypeFile); 
       
-      if (matchArguments(srcMd->argumentList(),md->argumentList()) &&
+      if (srcMd->isFunction() && md->isFunction() && 
+          matchArguments(srcMd->argumentList(),md->argumentList()) &&
           sameScope
          )
       {
-        return FALSE; // member already added
+        if (srcMd->getGroupAlias()==0) 
+        {
+          md->setGroupAlias(srcMd); 
+        }
+        else
+        {
+          md->setGroupAlias(srcMd->getGroupAlias()); 
+        }
+        return FALSE; // member is the same as one that is already added
       }
     }
     mni->append(new MemberInfo(md,md->protection(),md->virtualness(),FALSE));
@@ -199,28 +246,52 @@ bool GroupDef::insertMember(MemberDef *md,bool docOnly)
   switch(md->memberType())
   {
     case MemberDef::Variable:     
-      if (!docOnly) decVarMembers.append(md); 
+      if (!docOnly)
+      {
+        if (Config_getBool("SORT_BRIEF_DOCS"))
+          decVarMembers.inSort(md);
+        else
+          decVarMembers.append(md);
+      }
       if (Config_getBool("SORT_MEMBER_DOCS"))
         docVarMembers.inSort(md); 
       else
         docVarMembers.append(md);
       break;
     case MemberDef::Function: 
-      if (!docOnly) decFuncMembers.append(md);
+      if (!docOnly)
+      {
+        if (Config_getBool("SORT_BRIEF_DOCS"))
+          decFuncMembers.inSort(md);
+        else
+          decFuncMembers.append(md);
+      }
       if (Config_getBool("SORT_MEMBER_DOCS"))    
         docFuncMembers.inSort(md); 
       else
         docFuncMembers.append(md);
       break;
     case MemberDef::Typedef:      
-      if (!docOnly) decTypedefMembers.append(md);
+      if (!docOnly)
+      {
+        if (Config_getBool("SORT_BRIEF_DOCS"))
+          decTypedefMembers.inSort(md);
+        else
+          decTypedefMembers.append(md);
+      }
       if (Config_getBool("SORT_MEMBER_DOCS"))
         docTypedefMembers.inSort(md); 
       else
         docTypedefMembers.append(md);
       break;
     case MemberDef::Enumeration:  
-      if (!docOnly) decEnumMembers.append(md);
+      if (!docOnly)
+      {
+        if (Config_getBool("SORT_BRIEF_DOCS"))
+          decEnumMembers.inSort(md);
+        else
+          decEnumMembers.append(md);
+      }
       if (Config_getBool("SORT_MEMBER_DOCS"))
         docEnumMembers.inSort(md); 
       else
@@ -229,14 +300,26 @@ bool GroupDef::insertMember(MemberDef *md,bool docOnly)
     case MemberDef::EnumValue:    
       break;
     case MemberDef::Prototype:    
-      if (!docOnly) decProtoMembers.append(md);
+      if (!docOnly)
+      {
+        if (Config_getBool("SORT_BRIEF_DOCS"))
+          decProtoMembers.inSort(md);
+        else
+          decProtoMembers.append(md);
+      }
       if (Config_getBool("SORT_MEMBER_DOCS"))
         docProtoMembers.inSort(md); 
       else
         docProtoMembers.append(md);
       break;
     case MemberDef::Define:       
-      if (!docOnly) decDefineMembers.append(md);
+      if (!docOnly)
+      {
+        if (Config_getBool("SORT_BRIEF_DOCS"))
+          decDefineMembers.inSort(md);
+        else
+          decDefineMembers.append(md);
+      }
       if (Config_getBool("SORT_MEMBER_DOCS"))
         docDefineMembers.inSort(md); 
       else
@@ -332,16 +415,17 @@ int GroupDef::countMembers() const
 {
   return fileList->count()+
          classSDict->count()+
-         namespaceList->count()+
+         namespaceSDict->count()+
          groupList->count()+
          allMemberList->count()+
          pageDict->count()+
          exampleDict->count();
 }
 
-/*! Compute the HTML anchor names for all members in the class */ 
+/*! Compute the HTML anchor names for all members in the group */ 
 void GroupDef::computeAnchors()
 {
+  //printf("GroupDef::computeAnchors()\n");
   setAnchors(0,'a',allMemberList);
 }
 
@@ -359,13 +443,13 @@ void GroupDef::writeDetailedDocumentation(OutputList &ol)
       ol.writeAnchor(0,"_details");
       ol.popGeneratorState();
       ol.startGroupHeader();
-      parseText(ol,theTranslator->trDetailedDescription());
+      ol.parseText(theTranslator->trDetailedDescription());
       ol.endGroupHeader();
 
       // repeat brief description
       if (!briefDescription().isEmpty() && Config_getBool("REPEAT_BRIEF"))
       {
-        parseDoc(ol,briefFile(),briefLine(),name(),0,briefDescription());
+        ol.parseDoc(briefFile(),briefLine(),this,0,briefDescription(),FALSE,FALSE);
         ol.newParagraph();
       }
     }
@@ -373,7 +457,7 @@ void GroupDef::writeDetailedDocumentation(OutputList &ol)
     // write documentation
     if (!documentation().isEmpty())
     {
-      parseDoc(ol,docFile(),docLine(),name(),0,documentation()+"\n");
+      ol.parseDoc(docFile(),docLine(),this,0,documentation()+"\n",TRUE,FALSE);
     }
   }
 }
@@ -382,28 +466,60 @@ void GroupDef::writeDetailedDocumentation(OutputList &ol)
 void GroupDef::writeDocumentation(OutputList &ol)
 {
   ol.pushGeneratorState();
-  //ol.disable(OutputGenerator::Man);
   startFile(ol,getOutputFileBase(),name(),title);
   startTitle(ol,getOutputFileBase());
-  ol.docify(title);
+  ol.parseText(title);
   addGroupListToTitle(ol,this);
   endTitle(ol,getOutputFileBase(),title);
 
+  if (Config_getBool("SEARCHENGINE"))
+  {
+    Doxygen::searchIndex->setCurrentDoc(title,getOutputFileBase());
+    static QRegExp we("[a-zA-Z_][a-zA-Z_0-9]*");
+    int i=0,p=0,l=0;
+    while ((i=we.match(title,p,&l))!=-1) // foreach word in the title
+    {
+      Doxygen::searchIndex->addWord(title.mid(i,l),TRUE);
+      p=i+l;
+    }
+  }
+
+  if (Config_getBool("HAVE_DOT") && Config_getBool("GROUP_GRAPHS") )
+  {
+    DotGroupCollaboration graph(this);
+    if (!graph.isTrivial())
+    {
+      msg("Generating dependency graph for group %s\n",qualifiedName().data());
+      ol.pushGeneratorState();
+      ol.disable(OutputGenerator::Man);
+      ol.newParagraph();
+      ol.startGroupCollaboration();
+      ol.parseText(theTranslator->trCollaborationDiagram(title));
+      ol.endGroupCollaboration(graph);
+      ol.popGeneratorState();
+    }
+  }
+
+
   if (Config_getBool("DETAILS_AT_TOP"))
   {
     writeDetailedDocumentation(ol);
+    ol.newParagraph();
   }
   else if (!briefDescription().isEmpty())
   {
-    parseDoc(ol,briefFile(),briefLine(),name(),0,briefDescription());
+    ol.parseDoc(briefFile(),briefLine(),this,0,briefDescription(),TRUE,FALSE);
     ol.writeString(" \n");
     ol.pushGeneratorState();
     ol.disable(OutputGenerator::Latex);
     ol.disable(OutputGenerator::RTF);
+    ol.disable(OutputGenerator::Man);
     ol.startTextLink(0,"_details");
-    parseText(ol,theTranslator->trMore());
+    ol.parseText(theTranslator->trMore());
     ol.endTextLink();
-    //ol.enable(OutputGenerator::Latex);
+    ol.enableAll();
+    ol.disableAllBut(OutputGenerator::Man);
+    ol.newParagraph();
     ol.popGeneratorState();
   }
 
@@ -421,25 +537,25 @@ void GroupDef::writeDocumentation(OutputList &ol)
   if (fileList->count()>0)
   {
     ol.startMemberHeader();
-    parseText(ol,theTranslator->trFile(TRUE,FALSE));
+    ol.parseText(theTranslator->trFile(TRUE,FALSE));
     ol.endMemberHeader();
     ol.startMemberList();
     FileDef *fd=fileList->first();
     while (fd)
     {
       ol.startMemberItem(0);
-      ol.docify("file ");
+      ol.docify(theTranslator->trFile(FALSE,TRUE)+" ");
       ol.insertMemberAlign();
       ol.writeObjectLink(fd->getReference(),fd->getOutputFileBase(),0,fd->name());
       if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
       {
         Doxygen::tagFile << "    <file>" << convertToXML(fd->name()) << "</file>" << endl;
       }
-      ol.endMemberItem(FALSE);
+      ol.endMemberItem();
       if (!fd->briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
       {
         ol.startMemberDescription();
-        parseDoc(ol,briefFile(),briefLine(),0,0,fd->briefDescription());
+        ol.parseDoc(briefFile(),briefLine(),fd,0,fd->briefDescription(),FALSE,FALSE);
         ol.endMemberDescription();
         ol.newParagraph();
       }
@@ -449,58 +565,32 @@ void GroupDef::writeDocumentation(OutputList &ol)
   }
 
   // write list of namespaces
-  if (namespaceList->count()>0)
-  {
-    ol.startMemberHeader();
-    parseText(ol,theTranslator->trNamespaces());
-    ol.endMemberHeader();
-    ol.startMemberList();
-    NamespaceDef *nd=namespaceList->first();
-    while (nd)
-    {
-      ol.startMemberItem(0);
-      ol.docify("namespace ");
-      ol.insertMemberAlign();
-      ol.writeObjectLink(nd->getReference(),nd->getOutputFileBase(),0,nd->name());
-      if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
-      {
-        Doxygen::tagFile << "    <namespace>" << convertToXML(nd->name()) << "</namespace>" << endl;
-      }
-      ol.endMemberItem(FALSE);
-      if (!nd->briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
-      {
-        ol.startMemberDescription();
-        parseDoc(ol,briefFile(),briefLine(),0,0,nd->briefDescription());
-        ol.endMemberDescription();
-        ol.newParagraph();
-      }
-      nd=namespaceList->next();
-    }
-    ol.endMemberList();
-  }
+  namespaceSDict->writeDeclaration(ol);
 
   // write list of groups
   if (groupList->count()>0)
   {
     ol.startMemberHeader();
-    parseText(ol,theTranslator->trModules());
+    ol.parseText(theTranslator->trModules());
     ol.endMemberHeader();
     ol.startMemberList();
     GroupDef *gd=groupList->first();
     while (gd)
     {
       ol.startMemberItem(0);
-      //ol.insertMemberAlign();
+      //ol.docify(theTranslator->trGroup(FALSE,TRUE));
+      //ol.docify(" ");
+      ol.insertMemberAlign();
       ol.writeObjectLink(gd->getReference(),gd->getOutputFileBase(),0,gd->groupTitle());
       if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
       {
         Doxygen::tagFile << "    <subgroup>" << convertToXML(gd->name()) << "</subgroup>" << endl;
       }
-      ol.endMemberItem(FALSE);
+      ol.endMemberItem();
       if (!gd->briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
       {
         ol.startMemberDescription();
-        parseDoc(ol,briefFile(),briefLine(),0,0,gd->briefDescription());
+        ol.parseDoc(briefFile(),briefLine(),gd,0,gd->briefDescription(),FALSE,FALSE);
         ol.endMemberDescription();
         ol.newParagraph();
       }
@@ -509,6 +599,38 @@ void GroupDef::writeDocumentation(OutputList &ol)
     ol.endMemberList();
   }
 
+  // write list of directories
+  if (dirList->count()>0)
+  {
+    ol.startMemberHeader();
+    ol.parseText(theTranslator->trDirectories());
+    ol.endMemberHeader();
+    ol.startMemberList();
+    DirDef *dd=dirList->first();
+    while (dd)
+    {
+      ol.startMemberItem(0);
+      ol.parseText(theTranslator->trDir(FALSE,TRUE));
+      ol.insertMemberAlign();
+      ol.writeObjectLink(dd->getReference(),dd->getOutputFileBase(),0,dd->shortName());
+      ol.endMemberItem();
+      if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
+      {
+        Doxygen::tagFile << "    <dir>" << convertToXML(dd->displayName()) << "</dir>" << endl;
+      }
+      if (!dd->briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
+      {
+        ol.startMemberDescription();
+        ol.parseDoc(briefFile(),briefLine(),dd,0,dd->briefDescription(),FALSE,FALSE);
+        ol.endMemberDescription();
+        ol.newParagraph();
+      }
+      dd=dirList->next();
+    }
+
+    ol.endMemberList();
+  }
+  
   // write list of classes
   classSDict->writeDeclaration(ol);
 
@@ -538,13 +660,13 @@ void GroupDef::writeDocumentation(OutputList &ol)
     writeDetailedDocumentation(ol);
   }
 
-  PageInfo *pi=0;
+  PageDef *pd=0;
   PageSDict::Iterator pdi(*pageDict);
-  for (pdi.toFirst();(pi=pdi.current());++pdi)
+  for (pdi.toFirst();(pd=pdi.current());++pdi)
   {
-    if (!pi->isReference())
+    if (!pd->isReference())
     {
-      QCString pageName = pi->getOutputFileBase();
+      QCString pageName = pd->getOutputFileBase();
 
       if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
       {
@@ -552,15 +674,15 @@ void GroupDef::writeDocumentation(OutputList &ol)
       }
 
       SectionInfo *si=0;
-      if (!pi->title.isEmpty() && !pi->name.isEmpty() &&
-          (si=Doxygen::sectionDict[pi->name])!=0)
+      if (!pd->title().isEmpty() && !pd->name().isEmpty() &&
+          (si=Doxygen::sectionDict[pd->name()])!=0)
       {
         ol.startSection(si->label,si->title,SectionInfo::Subsection);
         ol.docify(si->title);
         ol.endSection(si->label,SectionInfo::Subsection);
       }
       ol.startTextBlock();
-      parseDoc(ol,pi->defFileName,pi->defLine,0,0,pi->doc);
+      ol.parseDoc(pd->docFile(),pd->docLine(),pd,0,pd->documentation(),TRUE,FALSE);
       ol.endTextBlock();
     }
   }
@@ -629,6 +751,24 @@ void addNamespaceToGroups(Entry *root,NamespaceDef *nd)
   }
 }
 
+void addDirToGroups(Entry *root,DirDef *dd)
+{
+  //printf("*** root->groups->count()=%d\n",root->groups->count());
+  QListIterator<Grouping> gli(*root->groups);
+  Grouping *g;
+  for (;(g=gli.current());++gli)
+  {
+    GroupDef *gd=0;
+    //printf("group `%s'\n",g->groupname.data());
+    if (!g->groupname.isEmpty() && (gd=Doxygen::groupSDict[g->groupname]))
+    {
+      gd->addDir(dd);
+      dd->makePartOfGroup(gd);
+      //printf("Dir %s: in group %s\n",dd->name().data(),g->groupname.data());
+    }
+  }
+}
+
 void addGroupToGroups(Entry *root,GroupDef *subGroup)
 {
   QListIterator<Grouping> gli(*root->groups);
@@ -648,7 +788,8 @@ void addGroupToGroups(Entry *root,GroupDef *subGroup)
 /*! Add a member to the group with the highest priority */
 void addMemberToGroups(Entry *root,MemberDef *md)
 {
-  //printf("  Root %p = %s, md %p=%s groups=%d\n", root, root->name.data(), md, md->name().data(), root->groups->count() );
+  //printf("addMemberToGroups:  Root %p = %s, md %p=%s groups=%d\n", 
+  //    root, root->name.data(), md, md->name().data(), root->groups->count() );
   QListIterator<Grouping> gli(*root->groups);
   Grouping *g;
 
@@ -723,6 +864,7 @@ void addMemberToGroups(Entry *root,MemberDef *md)
 
       if (moveit)
       {
+        //printf("removeMember\n");
         mgd->removeMember(md);
         insertit = TRUE;
       }
@@ -730,11 +872,13 @@ void addMemberToGroups(Entry *root,MemberDef *md)
 
     if (insertit)
     {
-      //printf("insertMember\n");
+      //printf("insertMember found at %s line %d\n",md->getDefFileName().data(),md->getDefLine());
       bool success = fgd->insertMember(md);
       if (success)
       {
-        md->setGroupDef(fgd,pri,root->fileName,root->startLine,root->doc.length() != 0);
+        //printf("insertMember successful\n");
+        md->setGroupDef(fgd,pri,root->fileName,root->startLine,
+                        !root->doc.isEmpty());
         ClassDef *cd = md->getClassDefOfAnonymousType();
         if (cd) cd->setGroupDefForAllMembers(fgd,pri,root->fileName,root->startLine,root->doc.length() != 0);
       }
@@ -743,7 +887,7 @@ void addMemberToGroups(Entry *root,MemberDef *md)
 }
 
 
-void addExampleToGroups(Entry *root,PageInfo *eg)
+void addExampleToGroups(Entry *root,PageDef *eg)
 {
   QListIterator<Grouping> gli(*root->groups);
   Grouping *g;
@@ -761,12 +905,19 @@ void addExampleToGroups(Entry *root,PageInfo *eg)
 
 QCString GroupDef::getOutputFileBase() const 
 { 
-  return convertNameToFile(fileName); 
+  if (isReference())
+  {
+    return fileName;
+  }
+  else
+  {
+    return convertNameToFile(fileName); 
+  }
 }
 
 void GroupDef::addListReferences()
 {
-  addRefItem(specialListItems(),
+  addRefItem(xrefListItems(),
              theTranslator->trGroup(TRUE,TRUE),
              getOutputFileBase(),name()
             );
