@@ -26,6 +26,12 @@
 #include "dot.h"
 #include "message.h"
 #include "config.h"
+#include "htmlgen.h"
+
+
+static const int NUM_HTML_LIST_TYPES = 4;
+static const char types[][NUM_HTML_LIST_TYPES] = {"1", "a", "i", "A"};
+
 
 static QString htmlAttribsToString(const HtmlAttribList &attribs)
 {
@@ -189,14 +195,14 @@ void HtmlDocVisitor::visit(DocVerbatim *s)
   switch(s->type())
   {
     case DocVerbatim::Code: // fall though
-      m_t << "<pre><div class=\"fragment\">"; 
+      m_t << PREFRAG_START;
       parseCode(m_ci,s->context(),s->text().latin1(),s->isExample(),s->exampleFile());
-      m_t << "</div></pre>"; 
+      m_t << PREFRAG_END;
       break;
     case DocVerbatim::Verbatim: 
-      m_t << "<pre><div class=\"fragment\">";
+      m_t << PREFRAG_START;
       filter(s->text());
-      m_t << "</div></pre>"; 
+      m_t << PREFRAG_END;
       break;
     case DocVerbatim::HtmlOnly: 
       m_t << s->text(); 
@@ -225,7 +231,7 @@ void HtmlDocVisitor::visit(DocVerbatim *s)
         file.close();
 
         m_t << "<div align=\"center\">" << endl;
-        writeDotFile(fileName);
+        writeDotFile(fileName,s->relPath());
         m_t << "</div>" << endl;
 
         file.remove();
@@ -246,28 +252,28 @@ void HtmlDocVisitor::visit(DocInclude *inc)
   switch(inc->type())
   {
     case DocInclude::Include: 
-      m_t << "<pre><div class=\"fragment\">";
+      m_t << PREFRAG_START;
       parseCode(m_ci,inc->context(),inc->text().latin1(),inc->isExample(),inc->exampleFile());
-      m_t << "</div></pre>"; 
+      m_t << PREFRAG_END;
+      break;
     case DocInclude::IncWithLines:
       { 
-         m_t << "<pre><div class=\"fragment\">";
+         m_t << PREFRAG_START;
          QFileInfo cfi( inc->file() );
          FileDef fd( cfi.dirPath(), cfi.fileName() );
          parseCode(m_ci,inc->context(),inc->text().latin1(),inc->isExample(),inc->exampleFile(), &fd);
-         m_t << "</div></pre>"; 
+         m_t << PREFRAG_END;
       }
       break;
-      break;
     case DocInclude::DontInclude: 
       break;
     case DocInclude::HtmlInclude: 
       m_t << inc->text(); 
       break;
     case DocInclude::VerbInclude: 
-      m_t << "<pre><div class=\"fragment\">";
+      m_t << PREFRAG_START;
       filter(inc->text());
-      m_t << "</div></pre>"; 
+      m_t << PREFRAG_END;
       break;
   }
 }
@@ -278,7 +284,7 @@ void HtmlDocVisitor::visit(DocIncOperator *op)
   //    op->type(),op->isFirst(),op->isLast(),op->text().data());
   if (op->isFirst()) 
   {
-    if (!m_hide) m_t << "<pre><div class=\"fragment\">";
+    if (!m_hide) m_t << PREFRAG_START;
     pushEnabled();
     m_hide=TRUE;
   }
@@ -292,7 +298,7 @@ void HtmlDocVisitor::visit(DocIncOperator *op)
   if (op->isLast())  
   {
     popEnabled();
-    if (!m_hide) m_t << "</div></pre>"; 
+    if (!m_hide) m_t << PREFRAG_END;
   }
   else
   {
@@ -305,13 +311,14 @@ void HtmlDocVisitor::visit(DocFormula *f)
   if (m_hide) return;
   bool bDisplay = f->text().at(0)=='\\';
   if (bDisplay) m_t << "<p class=\"formulaDsp\">" << endl;
-  m_t << "<img class=\"formula" << (bDisplay ? "Dsp" : "Inl");
+  m_t << "<img class=\"formula" 
+      << (bDisplay ? "Dsp" : "Inl");
   m_t << "\" alt=\"";
   filterQuotedCdataAttr(f->text());
   m_t << "\"";
   /// @todo cache image dimensions on formula generation and give height/width
   /// for faster preloading and better rendering of the page
-  m_t << " src=\"" << f->name() << ".png\">";
+  m_t << " src=\"" << f->relPath() << f->name() << ".png\">";
   if (bDisplay)
     m_t << endl << "<p>" << endl;
 }
@@ -324,12 +331,21 @@ void HtmlDocVisitor::visit(DocIndexEntry *)
 // visitor functions for compound nodes
 //--------------------------------------
 
+
 void HtmlDocVisitor::visitPre(DocAutoList *l)
 {
   if (m_hide) return;
   if (l->isEnumList())
   {
-    m_t << "<ol>";
+    //
+    // Do list type based on depth:
+    // 1.
+    //   a.
+    //     i.
+    //       A. 
+    //         1. (repeat)...
+    //
+    m_t << "<ol type=" << types[l->depth() % NUM_HTML_LIST_TYPES] << ">";
   }
   else
   {
@@ -705,7 +721,7 @@ void HtmlDocVisitor::visitPre(DocImage *img)
       baseName=baseName.right(baseName.length()-i-1);
     }
     m_t << "<div align=\"center\">" << endl;
-    m_t << "<img src=\"" << img->name() << "\" alt=\"" 
+    m_t << "<img src=\"" << img->relPath() << img->name() << "\" alt=\"" 
       << baseName << "\"" << htmlAttribsToString(img->attribs()) << ">" << endl;
     if (img->hasCaption())
     {
@@ -739,7 +755,7 @@ void HtmlDocVisitor::visitPost(DocImage *img)
 void HtmlDocVisitor::visitPre(DocDotFile *df)
 {
   if (m_hide) return;
-  writeDotFile(df->file());
+  writeDotFile(df->file(),df->relPath());
   m_t << "<div align=\"center\">" << endl;
   if (df->hasCaption())
   { 
@@ -819,24 +835,24 @@ void HtmlDocVisitor::visitPost(DocSecRefList *)
   m_t << "</multicol>" << endl;
 }
 
-void HtmlDocVisitor::visitPre(DocLanguage *l)
-{
-  QString langId = Config_getEnum("OUTPUT_LANGUAGE");
-  if (l->id().lower()!=langId.lower())
-  {
-    pushEnabled();
-    m_hide = TRUE;
-  }
-}
-
-void HtmlDocVisitor::visitPost(DocLanguage *l) 
-{
-  QString langId = Config_getEnum("OUTPUT_LANGUAGE");
-  if (l->id().lower()!=langId.lower())
-  {
-    popEnabled();
-  }
-}
+//void HtmlDocVisitor::visitPre(DocLanguage *l)
+//{
+//  QString langId = Config_getEnum("OUTPUT_LANGUAGE");
+//  if (l->id().lower()!=langId.lower())
+//  {
+//    pushEnabled();
+//    m_hide = TRUE;
+//  }
+//}
+//
+//void HtmlDocVisitor::visitPost(DocLanguage *l) 
+//{
+//  QString langId = Config_getEnum("OUTPUT_LANGUAGE");
+//  if (l->id().lower()!=langId.lower())
+//  {
+//    popEnabled();
+//  }
+//}
 
 void HtmlDocVisitor::visitPre(DocParamSect *s)
 {
@@ -868,7 +884,7 @@ void HtmlDocVisitor::visitPost(DocParamSect *)
 void HtmlDocVisitor::visitPre(DocParamList *pl)
 {
   if (m_hide) return;
-  m_t << "    <tr><td>";
+  m_t << "    <tr><td valign=\"top\">";
   if (pl->direction()!=DocParamSect::Unspecified)
   {
     m_t << "<tt>[";
@@ -886,7 +902,7 @@ void HtmlDocVisitor::visitPre(DocParamList *pl)
     }
     m_t << "]</tt>&nbsp;";
   }
-  m_t << "</td><td valign=top><em>";
+  m_t << "</td><td valign=\"top\"><em>";
   QStrListIterator li(pl->parameters());
   const char *s;
   bool first=TRUE;
@@ -907,10 +923,21 @@ void HtmlDocVisitor::visitPost(DocParamList *)
 void HtmlDocVisitor::visitPre(DocXRefItem *x)
 {
   if (m_hide) return;
-  m_t << "<dl compact><dt><b><a class=\"el\" href=\"" 
-    << x->file() << Doxygen::htmlFileExtension << "#" << x->anchor() << "\">";
+  bool anonymousEnum = x->file()=="@";
+  if (!anonymousEnum)
+  {
+    m_t << "<dl compact><dt><b><a class=\"el\" href=\"" 
+        << x->relPath() << x->file() << Doxygen::htmlFileExtension 
+        << "#" << x->anchor() << "\">";
+  }
+  else 
+  {
+    m_t << "<dl compact><dt><b>";
+  }
   filter(x->title());
-  m_t << ":</a></b></dt><dd>";
+  m_t << ":";
+  if (!anonymousEnum) m_t << "</a>";
+  m_t << "</b></dt><dd>";
 }
 
 void HtmlDocVisitor::visitPost(DocXRefItem *)
@@ -1050,7 +1077,7 @@ void HtmlDocVisitor::popEnabled()
   delete v;
 }
 
-void HtmlDocVisitor::writeDotFile(const QString &fileName)
+void HtmlDocVisitor::writeDotFile(const QString &fileName,const QString &relPath)
 {
   QString baseName=fileName;
   int i;
@@ -1062,10 +1089,10 @@ void HtmlDocVisitor::writeDotFile(const QString &fileName)
   writeDotGraphFromFile(fileName,outDir,baseName,BITMAP);
   QString mapName = baseName+".map";
   QString mapFile = fileName+".map";
-  m_t << "<img src=\"" << baseName << "." 
+  m_t << "<img src=\"" << relPath << baseName << "." 
     << Config_getEnum("DOT_IMAGE_FORMAT") << "\" alt=\""
     << baseName << "\" border=\"0\" usemap=\"#" << mapName << "\">" << endl;
-  QString imap = getDotImageMapFromFile(fileName,outDir);
+  QString imap = getDotImageMapFromFile(fileName,outDir,relPath.data());
   m_t << "<map name=\"" << mapName << "\">" << imap << "</map>" << endl;
 }
 
