@@ -21,6 +21,9 @@
 #include "qtbc.h"
 #include "outputgen.h"
 
+#define PREFRAG_START "<div class=\"fragment\"><pre class=\"fragment\">"
+#define PREFRAG_END   "</pre></div>"
+
 class QFile;
 
 class HtmlGenerator : public OutputGenerator
@@ -97,6 +100,8 @@ class HtmlGenerator : public OutputGenerator
     void endAnonTypeScope(int) {}
     void startMemberItem(int);
     void endMemberItem();
+    void startMemberTemplateParams();
+    void endMemberTemplateParams();
 
     void startMemberGroupHeader(bool);
     void endMemberGroupHeader();
@@ -105,15 +110,15 @@ class HtmlGenerator : public OutputGenerator
     void startMemberGroup();
     void endMemberGroup(bool);
 
-    void insertMemberAlign();
+    void insertMemberAlign(bool);
     void startMemberDescription();
     void endMemberDescription();
 
     void writeRuler()    { t << "<hr>"; }
     void writeAnchor(const char *,const char *name) 
                          { t << "<a name=\"" << name <<"\"></a>"; }
-    void startCodeFragment() { t << "<pre class=\"fragment\"><div>"; }
-    void endCodeFragment()   { t << "</div></pre>"; } 
+    void startCodeFragment() { t << PREFRAG_START; }
+    void endCodeFragment()   { t << PREFRAG_END; } 
     void writeLineNumber(const char *,const char *,const char *,int);
     void startCodeLine() { col=0; }
     void endCodeLine()   { codify("\n"); }
@@ -169,11 +174,11 @@ class HtmlGenerator : public OutputGenerator
     void writeNonBreakableSpace(int);
     
     void startDescTable()
-    { t << "<table border=0 cellspacing=2 cellpadding=0>" << endl; }
+    { t << "<table border=\"0\" cellspacing=\"2\" cellpadding=\"0\">" << endl; }
     void endDescTable()
     { t << "</table>" << endl; }
     void startDescTableTitle()
-    { t << "<tr><td valign=top><em>"; }
+    { t << "<tr><td valign=\"top\"><em>"; }
     void endDescTableTitle()
     { t << "</em>&nbsp;</td>"; }
     void startDescTableData()
@@ -185,12 +190,16 @@ class HtmlGenerator : public OutputGenerator
     void endDotGraph(DotClassGraph &g);
     void startInclDepGraph();
     void endInclDepGraph(DotInclDepGraph &g);
+    void startGroupCollaboration();
+    void endGroupCollaboration(DotGroupCollaboration &g);
     void startCallGraph();
     void endCallGraph(DotCallGraph &g);
+    void startDirDepGraph();
+    void endDirDepGraph(DotDirDeps &g);
     void writeGraphicalHierarchy(DotGfxHierarchyTable &g);
 
     void startTextBlock(bool) {}
-    void endTextBlock() {}
+    void endTextBlock(bool) {}
     void lastIndexPage() {}
 
     void startMemberDocPrefixItem();
