@@ -27,3 +27,5 @@
 #define LANG_TW
 #define LANG_SR
 #define LANG_CA
+#define LANG_LT
+#define LANG_ZA
