@@ -112,6 +112,12 @@
 //#ifdef LANG_JS
 //#include "translator_js.h"
 //#endif
+#ifdef LANG_LT
+#include "translator_lt.h"
+#endif
+#ifdef LANG_ZA
+#include "translator_za.h"
+#endif
 #endif
 
 #define L_EQUAL(a) !stricmp(langName,a)
@@ -307,6 +313,12 @@ bool setTranslator(const char *langName)
     theTranslator=new TranslatorCatalan;
   }
 #endif
+#ifdef LANG_LT
+  else if (L_EQUAL("lithuanian"))
+  {
+    theTranslator=new TranslatorLithuanian;
+  }
+#endif
 #endif // ENGLISH_ONLY
   else // use the default language (i.e. english)
   {
