@@ -79,8 +79,10 @@ QString LatexDocVisitor::escapeMakeIndexChars(const char *s)
 }
 
 
-LatexDocVisitor::LatexDocVisitor(QTextStream &t,BaseCodeDocInterface &ci) 
-  : DocVisitor(DocVisitor_Latex), m_t(t), m_ci(ci), m_insidePre(FALSE), m_insideItem(FALSE), m_hide(FALSE) 
+LatexDocVisitor::LatexDocVisitor(QTextStream &t,BaseCodeDocInterface &ci,
+                                 bool insideTabbing) 
+  : DocVisitor(DocVisitor_Latex), m_t(t), m_ci(ci), m_insidePre(FALSE), 
+    m_insideItem(FALSE), m_hide(FALSE), m_insideTabbing(insideTabbing) 
 {
 }
 
@@ -839,24 +841,24 @@ void LatexDocVisitor::visitPost(DocSecRefList *)
   m_t << "\\normalsize" << endl;
 }
 
-void LatexDocVisitor::visitPre(DocLanguage *l)
-{
-  QString langId = Config_getEnum("OUTPUT_LANGUAGE");
-  if (l->id().lower()!=langId.lower())
-  {
-    pushEnabled();
-    m_hide = TRUE;
-  }
-}
-
-void LatexDocVisitor::visitPost(DocLanguage *l) 
-{
-  QString langId = Config_getEnum("OUTPUT_LANGUAGE");
-  if (l->id().lower()!=langId.lower())
-  {
-    popEnabled();
-  }
-}
+//void LatexDocVisitor::visitPre(DocLanguage *l)
+//{
+//  QString langId = Config_getEnum("OUTPUT_LANGUAGE");
+//  if (l->id().lower()!=langId.lower())
+//  {
+//    pushEnabled();
+//    m_hide = TRUE;
+//  }
+//}
+//
+//void LatexDocVisitor::visitPost(DocLanguage *l) 
+//{
+//  QString langId = Config_getEnum("OUTPUT_LANGUAGE");
+//  if (l->id().lower()!=langId.lower())
+//  {
+//    popEnabled();
+//  }
+//}
 
 void LatexDocVisitor::visitPre(DocParamSect *s)
 {
@@ -928,8 +930,9 @@ void LatexDocVisitor::visitPre(DocXRefItem *x)
 {
   if (m_hide) return;
   m_t << "\\begin{Desc}" << endl;
+  bool anonymousEnum = x->file()=="@";
   m_t << "\\item[";
-  if (Config_getBool("PDF_HYPERLINKS"))
+  if (Config_getBool("PDF_HYPERLINKS") && !anonymousEnum)
   {
     m_t << "\\hyperlink{" << stripPath(x->file()) << "_" << x->anchor() << "}{";
   }
@@ -979,7 +982,7 @@ void LatexDocVisitor::visitPost(DocText *)
 
 void LatexDocVisitor::filter(const char *str)
 { 
-  filterLatexString(m_t,str,FALSE,m_insidePre,m_insideItem);
+  filterLatexString(m_t,str,m_insideTabbing,m_insidePre,m_insideItem);
 }
 
 void LatexDocVisitor::startLink(const QString &ref,const QString &file,const QString &anchor)
