@@ -93,7 +93,7 @@ class ManGenerator : public OutputGenerator
     void endMemberSections() {}
     void startMemberHeader();
     void endMemberHeader();
-    void insertMemberAlign() {}
+    void insertMemberAlign(bool) {}
     void startMemberSubtitle() {}
     void endMemberSubtitle() {}
     void writeListItem();
@@ -103,6 +103,8 @@ class ManGenerator : public OutputGenerator
     void endAnonTypeScope(int);
     void startMemberItem(int);
     void endMemberItem();
+    void startMemberTemplateParams() {}
+    void endMemberTemplateParams() {}
 
     void startMemberGroupHeader(bool);
     void endMemberGroupHeader();
@@ -227,12 +229,16 @@ class ManGenerator : public OutputGenerator
     void endDotGraph(DotClassGraph &) {}
     void startInclDepGraph() {}
     void endInclDepGraph(DotInclDepGraph &) {}
+    void startGroupCollaboration() {}
+    void endGroupCollaboration(DotGroupCollaboration &) {}
     void startCallGraph() {}
     void endCallGraph(DotCallGraph &) {}
+    void startDirDepGraph() {} 
+    void endDirDepGraph(DotDirDeps &) {}
     void writeGraphicalHierarchy(DotGfxHierarchyTable &) {}
 
     void startTextBlock(bool) {}
-    void endTextBlock() {}
+    void endTextBlock(bool) {}
     void lastIndexPage() {}
 
     void startMemberDocPrefixItem() {}
