@@ -133,16 +133,26 @@ static bool writeDefArgumentList(OutputList &ol,ClassDef *cd,
   while (a)
   {
     if (md->isDefine() || first) ol.startParameterType(first,md->isObjCMethod()?"dummy":0);
-    QRegExp re(")(");
-    int vp;
+    QRegExp re(")("),res("(.*\\*");
+    int vp=a->type.find(re);
+    int wp=a->type.find(res);
+
+    // use the following to put the function pointer type before the name
+    bool hasFuncPtrType=FALSE; 
+
+    // or use the following to put the function pointer as it appears in
+    // the prototype.
+    // bool hasFuncPtrType=vp!=-1 && wp!=-1 && wp<vp; 
+
     if (!a->attrib.isEmpty() && !md->isObjCMethod()) // argument has an IDL attribute
     {
       ol.docify(a->attrib+" ");
     }
-    if ((vp=a->type.find(re))!=-1) // argument type is a function pointer
+    if (hasFuncPtrType) // argument type is a function pointer
     {
       //printf("a->type=`%s' a->name=`%s'\n",a->type.data(),a->name.data());
       QCString n=a->type.left(vp);
+      if (hasFuncPtrType) n=a->type.left(wp);
       if (md->isObjCMethod()) { n.prepend("("); n.append(")"); }
       if (!cName.isEmpty()) n=addTemplateNames(n,cd->name(),cName);
       linkifyText(TextGeneratorOLImpl(ol),cd,md->getBodyDef(),md->name(),n);
@@ -162,9 +172,16 @@ static bool writeDefArgumentList(OutputList &ol,ClassDef *cd,
       ol.endParameterType();
       ol.startParameterName(defArgList->count()<2);
     }
+    if (hasFuncPtrType)
+    {
+      ol.docify(a->type.mid(wp,vp-wp)); 
+    }
     if (!a->name.isEmpty() || (a->name.isEmpty() && a->type=="...")) // argument has a name
     { 
-      ol.docify(" ");
+      if (!hasFuncPtrType)
+      {
+        ol.docify(" ");
+      }
       ol.disable(OutputGenerator::Man);
       ol.startEmphasis();
       ol.enable(OutputGenerator::Man);
@@ -177,8 +194,8 @@ static bool writeDefArgumentList(OutputList &ol,ClassDef *cd,
     {
       ol.docify(a->array);
     }
-    if (vp!=-1) // write the part of the argument type 
-                // that comes after the name
+    if (hasFuncPtrType) // write the part of the argument type 
+                        // that comes after the name
     {
       linkifyText(TextGeneratorOLImpl(ol),cd,md->getBodyDef(),
                   md->name(),a->type.right(a->type.length()-vp));
@@ -201,7 +218,7 @@ static bool writeDefArgumentList(OutputList &ol,ClassDef *cd,
       if (!md->isDefine()) 
       {
         QCString key;
-        if (md->isObjCMethod() && a->attrib.length()>2)
+        if (md->isObjCMethod() && a->attrib.length()>=2)
         {
           //printf("Found parameter keyword %s\n",a->attrib.data());
           // strip [ and ]
@@ -343,6 +360,7 @@ MemberDef::MemberDef(const char *df,int dl,
   section=0;
   groupAlias=0;
   explExt=FALSE;
+  tspec=FALSE;
   cachedAnonymousType=0;
   maxInitLines=Config_getInt("MAX_INITIALIZER_LINES");
   userInitLines=-1;
@@ -404,6 +422,10 @@ MemberDef::MemberDef(const char *df,int dl,
   m_cachedTypedefValue = 0;
   m_inbodyLine = -1;
   m_implOnly=FALSE;
+  groupMember = 0;
+  m_hasDocumentedParams = FALSE;
+  m_hasDocumentedReturnType = FALSE;
+  m_docProvider = 0;
 }
 
 /*! Destroys the member definition. */
@@ -542,7 +564,17 @@ QCString MemberDef::anchor() const
   if (groupAlias)       return groupAlias->anchor();
   if (m_templateMaster) return m_templateMaster->anchor();
   if (enumScope) result.prepend(enumScope->anchor());
-  if (group) result.prepend("g");
+  if (group) 
+  {
+    if (groupMember)
+    {
+      result=groupMember->anchor();
+    }
+    else
+    {
+      result.prepend("g");
+    }
+  }
   return result;
 }
 
@@ -573,15 +605,15 @@ bool MemberDef::isLinkableInProject() const
     //printf("in a class but class not linkable!\n");
     return FALSE; // in class but class not linkable
   }
-  if (!group && nspace && !nspace->isLinkableInProject()) 
+  if (!group && nspace && !related && !nspace->isLinkableInProject()) 
   {
     //printf("in a namespace but namespace not linkable!\n");
     return FALSE; // in namespace but namespace not linkable
   }
-  if (!group && fileDef && !fileDef->isLinkableInProject()) 
+  if (!group && !nspace && !related && fileDef && !fileDef->isLinkableInProject()) 
   {
     //printf("in a file but file not linkable!\n");
-    return FALSE; // in file but file not linkable
+    return FALSE; // in file (and not in namespace) but file not linkable
   }
   if (prot==Private && !Config_getBool("EXTRACT_PRIVATE") && mtype!=Friend) 
   {
@@ -647,7 +679,7 @@ ClassDef *MemberDef::getClassDefOfAnonymousType()
   }
   QCString ltype(type);
   // strip `static' keyword from ltype
-  if (ltype.left(7)=="static ") ltype=ltype.right(ltype.length()-7);
+  //if (ltype.left(7)=="static ") ltype=ltype.right(ltype.length()-7);
   // strip `friend' keyword from ltype
   if (ltype.left(7)=="friend ") ltype=ltype.right(ltype.length()-7);
   static QRegExp r("@[0-9]+");
@@ -834,8 +866,8 @@ void MemberDef::writeDeclaration(OutputList &ol,
   if (Config_getBool("SEARCHENGINE"))
   {
     Doxygen::searchIndex->setCurrentDoc(qualifiedName(),getOutputFileBase(),anchor());
-    Doxygen::searchIndex->addWord(localName().lower());
-    Doxygen::searchIndex->addWord(qualifiedName().lower());
+    Doxygen::searchIndex->addWord(localName(),TRUE);
+    Doxygen::searchIndex->addWord(qualifiedName(),FALSE);
   }
 
   Definition *d=0;
@@ -857,8 +889,9 @@ void MemberDef::writeDeclaration(OutputList &ol,
   ClassDef *annoClassDef=getClassDefOfAnonymousType();
 
   // start a new member declaration
+  bool isAnonymous = annoClassDef || annMemb || annEnumType;
   ///printf("startMemberItem for %s\n",name().data());
-  ol.startMemberItem((annoClassDef || annMemb || annEnumType) ? 1 : 0);
+  ol.startMemberItem( isAnonymous ? 1 : tArgList ? 3 : 0);
 
   // If there is no detailed description we need to write the anchor here.
   bool detailsVisible = isDetailedSectionLinkable();
@@ -886,14 +919,15 @@ void MemberDef::writeDeclaration(OutputList &ol,
 
   if (tArgList)
   {
+    if (!isAnonymous) ol.startMemberTemplateParams();
     writeTemplatePrefix(ol,tArgList);
-    //ol.lineBreak();
+    if (!isAnonymous) ol.endMemberTemplateParams();
   }
 
   QCString ltype(type);
   if (mtype==Typedef) ltype.prepend("typedef ");
   // strip `static' keyword from ltype
-  if (ltype.left(7)=="static ") ltype=ltype.right(ltype.length()-7);
+  //if (ltype.left(7)=="static ") ltype=ltype.right(ltype.length()-7);
   // strip `friend' keyword from ltype
   if (ltype.left(7)=="friend ") ltype=ltype.right(ltype.length()-7);
   static QRegExp r("@[0-9]+");
@@ -972,7 +1006,7 @@ void MemberDef::writeDeclaration(OutputList &ol,
   }
   else
   {
-    ol.insertMemberAlign();
+    ol.insertMemberAlign(tArgList!=0);
   }
 
   // write name
@@ -1183,12 +1217,18 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
   //    name().data(),hasDocs,container->definitionType(),inGroup);
   if ( !hasDocs ) return;
   QCString scopeName = scName;
+  QCString memAnchor = anchor();
   if (container->definitionType()==TypeGroup)
   {
     if (getClassDef())          scopeName=getClassDef()->name();
     else if (getNamespaceDef()) scopeName=getNamespaceDef()->name();
     else if (getFileDef())      scopeName=getFileDef()->name();
   }
+  else if (container->definitionType()==TypeFile && getNamespaceDef())
+  { // member is in a namespace, but is written as part of the file documentation
+    // as well, so we need to make sure its label is unique.
+    memAnchor.prepend("file_");
+  }
 
   QCString cname  = container->name();
   QCString cfname = getOutputFileBase();  
@@ -1199,7 +1239,7 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
   if (Config_getBool("GENERATE_HTML") && Config_getBool("GENERATE_HTMLHELP"))
   {
     HtmlHelp *htmlHelp = HtmlHelp::getInstance();
-    htmlHelp->addIndexItem(cname,name(),cfname,anchor());
+    htmlHelp->addIndexItem(cname,name(),cfname,memAnchor);
   }
 
   // get member name
@@ -1241,14 +1281,13 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
     {
       if (vmd->isEnumerate() && ldef.mid(i,l)==vmd->name())
       {
-        ol.startDoxyAnchor(cfname,cname,anchor(),doxyName);
-        ol.startMemberDoc(cname,name(),anchor(),name());
+        ol.startDoxyAnchor(cfname,cname,memAnchor,doxyName);
+        ol.startMemberDoc(cname,name(),memAnchor,name());
         if (hasHtmlHelp)
         {
-          htmlHelp->addIndexItem(cname,name(),cfname,anchor());
+          htmlHelp->addIndexItem(cname,name(),cfname,memAnchor);
         }
         linkifyText(TextGeneratorOLImpl(ol),container,getBodyDef(),name(),ldef.left(i));
-        //ol+=*vmd->enumDecl();
         vmd->writeEnumDeclaration(ol,getClassDef(),getNamespaceDef(),getFileDef(),getGroupDef());
         linkifyText(TextGeneratorOLImpl(ol),container,getBodyDef(),name(),ldef.right(ldef.length()-i-l));
 
@@ -1258,11 +1297,11 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
     if (!found) // anonymous compound
     {
       //printf("Anonymous compound `%s'\n",cname.data());
-      ol.startDoxyAnchor(cfname,cname,anchor(),doxyName);
-      ol.startMemberDoc(cname,name(),anchor(),name());
+      ol.startDoxyAnchor(cfname,cname,memAnchor,doxyName);
+      ol.startMemberDoc(cname,name(),memAnchor,name());
       if (hasHtmlHelp)
       {
-        htmlHelp->addIndexItem(cname,name(),cfname,anchor());
+        htmlHelp->addIndexItem(cname,name(),cfname,memAnchor);
       }
       // strip anonymous compound names from definition
       int si=ldef.find(' '),pi,ei=i+l;
@@ -1280,11 +1319,11 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
   }
   else // not an enum value
   {
-    ol.startDoxyAnchor(cfname,cname,anchor(),doxyName);
-    ol.startMemberDoc(cname,name(),anchor(),name());
+    ol.startDoxyAnchor(cfname,cname,memAnchor,doxyName);
+    ol.startMemberDoc(cname,name(),memAnchor,name());
     if (hasHtmlHelp)
     {
-      htmlHelp->addIndexItem(cname,name(),cfname,anchor());
+      htmlHelp->addIndexItem(cname,name(),cfname,memAnchor);
     }
 
     ClassDef *cd=getClassDef();
@@ -1310,7 +1349,7 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
       else // definition gets it template parameters from its class
         // (since no definition was found)
       {
-        if (cd)
+        if (cd && !isTemplateSpecialization())
         {
           QList<ArgumentList> tempParamLists;
           cd->getTemplateParameterLists(tempParamLists);
@@ -1399,7 +1438,8 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
        isMutable() || (isInline() && Config_getBool("INLINE_INFO")) ||
        isSignal() || isSlot() ||
        isStatic() || (classDef && classDef!=container) ||
-       isSettable() || isGettable() || isReadable() || isWritable()
+       isSettable() || isGettable() || isReadable() || isWritable() ||
+       isFinal() || isAbstract()
       )
      )
   {
@@ -1421,6 +1461,8 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
       if      (isSettable())            sl.append("set");
       if      (isReadable())            sl.append("read");
       if      (isWritable())            sl.append("write");
+      if      (isFinal())               sl.append("final");
+      if      (isAbstract())            sl.append("abstract");
       if      (protection()==Protected) sl.append("protected");
       else if (protection()==Private)   sl.append("private");
       else if (protection()==Package)   sl.append("package");
@@ -1457,7 +1499,7 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
     ol.endMemberDocName();
     ol.endMemberDoc(FALSE);
   }
-  ol.endDoxyAnchor(cfname,anchor());
+  ol.endDoxyAnchor(cfname,memAnchor);
   ol.startIndent();
 
   ol.pushGeneratorState();
@@ -1507,17 +1549,13 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
   if (!detailed.isEmpty())
   { 
     ol.parseDoc(docFile(),docLine(),getOuterScope()?getOuterScope():container,this,detailed+"\n",TRUE,FALSE);
-    ol.pushGeneratorState();
     if (!m_inbodyDocs.isEmpty())
     {
       ol.newParagraph();
       ol.parseDoc(inbodyFile(),inbodyLine(),getOuterScope()?getOuterScope():container,this,m_inbodyDocs+"\n",TRUE,FALSE);
     }
-    ol.disableAllBut(OutputGenerator::RTF);
-    ol.newParagraph();
-    ol.popGeneratorState();
   }
-  else if(!brief.isEmpty() && (Config_getBool("REPEAT_BRIEF") ||
+  else if (!brief.isEmpty() && (Config_getBool("REPEAT_BRIEF") ||
         !Config_getBool("BRIEF_MEMBER_DESC")))
   {
     if (!m_inbodyDocs.isEmpty())
@@ -1525,10 +1563,6 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
       ol.newParagraph();
       ol.parseDoc(inbodyFile(),inbodyLine(),getOuterScope()?getOuterScope():container,this,m_inbodyDocs+"\n",TRUE,FALSE);
     }
-    ol.pushGeneratorState();
-    ol.disableAllBut(OutputGenerator::RTF);
-    ol.newParagraph();
-    ol.popGeneratorState();
   }
 
 
@@ -1551,7 +1585,13 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
         ol.docify(a->name);
         ol.endDescTableTitle();
         ol.startDescTableData();
-        ol.parseDoc(docFile(),docLine(),getOuterScope()?getOuterScope():container,this,a->docs+"\n",TRUE,FALSE);
+        ol.parseDoc(docFile(),docLine(),
+                    getOuterScope()?getOuterScope():container,
+                    this,         // memberDef
+                    a->docs+"\n", // docStr
+                    TRUE,         // indexWords
+                    FALSE         // isExample
+                   );
         ol.endDescTableData();
       }
     }
@@ -1678,9 +1718,6 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
         ol.parseText(reimplFromLine.right(
               reimplFromLine.length()-markerPos-2)); // text right from marker
 
-        ol.disableAllBut(OutputGenerator::RTF);
-        ol.newParagraph();
-        ol.enableAll();
       }
       else
       {
@@ -1761,9 +1798,6 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
         index=newIndex+matchLen;
       } 
       ol.parseText(reimplInLine.right(reimplInLine.length()-index));
-      ol.disableAllBut(OutputGenerator::RTF);
-      ol.newParagraph();
-      ol.enableAll();
     }
   }
   // write the list of examples that use this member
@@ -1781,9 +1815,7 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
   writeSourceReffedBy(ol,cname);
   writeInlineCode(ol,cname);
 
-  ol.disableAllBut(OutputGenerator::RTF);
-  ol.newParagraph();
-  ol.enableAll();
+  ol.endIndent();
 
   if ((m_hasCallGraph || Config_getBool("CALL_GRAPH")) 
       && isFunction() && Config_getBool("HAVE_DOT")
@@ -1802,11 +1834,28 @@ void MemberDef::writeDocumentation(MemberList *ml,OutputList &ol,
     }
   }
 
-  ol.endIndent();
   // enable LaTeX again
   //if (Config_getBool("EXTRACT_ALL") && !hasDocs) ol.enable(OutputGenerator::Latex); 
   ol.popGeneratorState();
 
+  if (!Config_getBool("EXTRACT_ALL") &&
+      Config_getBool("WARN_IF_UNDOCUMENTED") &&
+      Config_getBool("WARN_NO_PARAMDOC"))
+  {
+    if (!hasDocumentedParams())
+    {
+      warn_doc_error(docFile(),docLine(),
+          "Warning: parameters of member %s are not (all) documented",
+          qualifiedName().data());
+    }
+    if (!hasDocumentedReturnType())
+    {
+      warn_doc_error(docFile(),docLine(),
+          "Warning: return type of member %s is not documented",
+          qualifiedName().data());
+    }
+  }
+
 }
 
 void MemberDef::warnIfUndocumented()
@@ -1890,7 +1939,9 @@ void MemberDef::setAnchor(const char *a)
   anc=a;
 }
 
-void MemberDef::setGroupDef(GroupDef *gd,Grouping::GroupPri_t pri,const QCString &fileName,int startLine,bool hasDocs)
+void MemberDef::setGroupDef(GroupDef *gd,Grouping::GroupPri_t pri,
+                            const QCString &fileName,int startLine,
+                            bool hasDocs,MemberDef *member)
 {
   //printf("%s MemberDef::setGroupDef(%s)\n",name().data(),gd->name().data());
   group=gd;
@@ -1898,6 +1949,7 @@ void MemberDef::setGroupDef(GroupDef *gd,Grouping::GroupPri_t pri,const QCString
   groupFileName=fileName;
   groupStartLine=startLine;
   groupHasDocs=hasDocs;
+  groupMember=member;
 }
 
 void MemberDef::setEnumScope(MemberDef *md) 
@@ -1975,6 +2027,8 @@ bool MemberDef::hasOneLineInitializer() const
 
 bool MemberDef::hasMultiLineInitializer() const
 {
+  //printf("initLines=%d userInitLines=%d maxInitLines=%d\n",
+  //    initLines,userInitLines,maxInitLines);
   return initLines>0 && 
          ((initLines<maxInitLines && userInitLines==-1) // implicitly enabled
           || initLines<userInitLines // explicitly enabled
@@ -1983,6 +2037,7 @@ bool MemberDef::hasMultiLineInitializer() const
 
 void MemberDef::setInitializer(const char *initializer)    
 { 
+  //printf("setInitializer(%s)\n",initializer);
   init=initializer; 
   int p=init.length()-1;
   while (p>=0 && isspace((uchar)init.at(p))) p--;
@@ -2019,9 +2074,14 @@ void MemberDef::addListReference(Definition *)
       }
     }
   }
-  //printf("*** addListReference %s todo=%d test=%d bug=%d\n",name().data(),todoId(),testId(),bugId());
-  addRefItem(xrefListItems(),memLabel,
-      getOutputFileBase()+"#"+anchor(),memName,argsString());
+  if (xrefListItems())
+  {
+    addRefItem(xrefListItems(),memLabel,
+        getOutputFileBase()+"#"+anchor(),memName,argsString());
+  }
+  else 
+  {
+  }
 }
 
 MemberList *MemberDef::getSectionList(Definition *d) const 
