@@ -71,11 +71,13 @@ class MemberDef : public Definition
               bool related,MemberType t,const ArgumentList *tal,
               const ArgumentList *al);
    ~MemberDef(); 
-    DefType definitionType() { return TypeMember; }
+    DefType definitionType()              { return TypeMember; }
     
+    // link id
     QCString getOutputFileBase() const;
     QCString getReference() const;
     QCString anchor() const;
+
     const char *declaration() const       { return decl; }
     const char *definition() const        { return def; }
     const char *typeString() const        { return type; }
@@ -93,6 +95,10 @@ class MemberDef : public Definition
     NamespaceDef* getNamespaceDef() const { return nspace; }
     //Definition *getCompoundDef() const;
 
+    // grabbing the property read/write accessor names
+    const char *getReadAccessor() const      { return read; }
+    const char *getWriteAccessor() const     { return write; }
+    
     // querying the grouping definition
     GroupDef *getGroupDef() const            { return group; }
     Grouping::GroupPri_t getGroupPri() const { return grouppri; }
@@ -106,7 +112,7 @@ class MemberDef : public Definition
     Specifier virtualness() const;
     MemberType memberType() const         { return mtype; }
 
-    // convenience methods
+    // getter methods
     bool isSignal() const                 { return mtype==Signal;      }
     bool isSlot() const                   { return mtype==Slot;        }
     bool isVariable() const               { return mtype==Variable;    }
@@ -128,8 +134,13 @@ class MemberDef : public Definition
     bool isSettable() const               { return (memSpec&Entry::Settable)!=0; }
     bool isReadable() const               { return (memSpec&Entry::Readable)!=0; }
     bool isWritable() const               { return (memSpec&Entry::Writable)!=0; }
+    bool isFinal() const                  { return (memSpec&Entry::Final)!=0; }
+    bool isAbstract() const               { return (memSpec&Entry::Abstract)!=0; }
     bool isImplementation() const         { return m_implOnly; }
     bool isExternal() const               { return explExt; }
+    bool isTemplateSpecialization() const { return tspec; }
+    bool hasDocumentedParams() const      { return m_hasDocumentedParams; }
+    bool hasDocumentedReturnType() const  { return m_hasDocumentedReturnType; }
     bool isObjCMethod() const;
     bool isConstructor() const;
     bool isDestructor() const;
@@ -147,24 +158,32 @@ class MemberDef : public Definition
     bool isDocumentedFriendClass() const;
 
     // set functions
-    void setMemberType(MemberType t)      { mtype=t; }
-    void setDefinition(const char *d)     { def=d; }
-    void setFileDef(FileDef *fd)          { fileDef=fd; }
+    void setMemberType(MemberType t)        { mtype=t; }
+    void setDefinition(const char *d)       { def=d; }
+    void setFileDef(FileDef *fd)            { fileDef=fd; }
     void setAnchor(const char *a);
-    void setProtection(Protection p)      { prot=p; }
-    void setMemberSpecifiers(int s)       { memSpec=s; }
-    void mergeMemberSpecifiers(int s)     { memSpec|=s; }
+    void setProtection(Protection p)        { prot=p; }
+    void setMemberSpecifiers(int s)         { memSpec=s; }
+    void mergeMemberSpecifiers(int s)       { memSpec|=s; }
     void setInitializer(const char *i);
-    void setBitfields(const char *s)      { bitfields = s; }
-    void setMaxInitLines(int lines)       { userInitLines=lines; }
+    void setBitfields(const char *s)        { bitfields = s; }
+    void setMaxInitLines(int lines)         { userInitLines=lines; }
     void setMemberClass(ClassDef *cd);
     void setSectionList(Definition *d,MemberList *sl);
-    void setGroupDef(GroupDef *gd,Grouping::GroupPri_t pri,const QCString &fileName,int startLine,bool hasDocs);
-    void setExplicitExternal(bool b)      { explExt=b; }
+    void setGroupDef(GroupDef *gd,Grouping::GroupPri_t pri,
+                     const QCString &fileName,int startLine,bool hasDocs,
+                     MemberDef *member=0);
+    void setExplicitExternal(bool b)        { explExt=b; }
+    void setReadAccessor(const char *r)     { read=r; }
+    void setWriteAccessor(const char *w)    { write=w; }
+    void setTemplateSpecialization(bool b)  { tspec=b; }
     
-    void makeRelated()                    { related=TRUE; } 
+    void makeRelated()                      { related=TRUE; } 
+    void setHasDocumentedParams(bool b)     { m_hasDocumentedParams = b; }
+    void setHasDocumentedReturnType(bool b) { m_hasDocumentedReturnType = b; }
+    void setInheritsDocsFrom(MemberDef *md) { m_docProvider = md; }
 
-    // output generatation
+    // output generation
     void writeLink(OutputList &ol,
                    ClassDef *cd,NamespaceDef *nd,FileDef *fd,GroupDef *gd);
     void writeDeclaration(OutputList &ol,
@@ -194,11 +213,8 @@ class MemberDef : public Definition
     // enumeration specific members
     void insertEnumField(MemberDef *md);
     void setEnumScope(MemberDef *md);
+    void setEnumClassScope(ClassDef *cd)     { classDef = cd; }
     MemberDef *getEnumScope() const          { return enumScope; }
-    //void setEnumUsed()                       { eUsed=TRUE; }
-    //bool enumUsed() const                    { return eUsed; }
-    //void setEnumDecl(OutputList &ed);
-    //OutputList *enumDecl() const             { return enumDeclList; }
     MemberList *enumFieldList() const        { return enumFields; }
     void setDocumentedEnumValues(bool value) { docEnumValues=value; }
     bool hasDocumentedEnumValues() const     { return docEnumValues; }
@@ -258,6 +274,8 @@ class MemberDef : public Definition
     void setTemplateMaster(MemberDef *mt) { m_templateMaster=mt; }
     void addListReference(Definition *d);
 
+    MemberDef *inheritsDocsFrom() const { return m_docProvider; }
+
     //QCString getBodyAnchor() const 
     //{ 
     //  return bodyMemb ? bodyMemb->anchor() : anchor(); 
@@ -270,7 +288,10 @@ class MemberDef : public Definition
     // cached typedef functions
     bool isTypedefValCached() const { return m_isTypedefValCached; }
     ClassDef *getCachedTypedefVal() const { return m_cachedTypedefValue; }
-    void cacheTypedefVal(ClassDef *val) { m_isTypedefValCached=TRUE; m_cachedTypedefValue=val; }
+    QCString getCachedTypedefTemplSpec() const { return m_cachedTypedefTemplSpec; }
+    void cacheTypedefVal(ClassDef *val,const QCString &templSpec) 
+    { m_isTypedefValCached=TRUE; m_cachedTypedefValue=val; m_cachedTypedefTemplSpec=templSpec; }
+    void invalidateTypedefValCache() { m_isTypedefValCached=FALSE; }
     
     // declaration <-> definition relation
     void setMemberDefinition(MemberDef *md) { memDef=md; }
@@ -304,6 +325,8 @@ class MemberDef : public Definition
     QCString type;            // return type
     QCString args;            // function arguments/variable array specifiers
     QCString bitfields;       // struct member bitfields
+    QCString read;            // property read accessor
+    QCString write;           // property write accessor
     QCString exception;       // exceptions that can be thrown
     QCString init;            // initializer
     int initLines;            // number of lines in the initializer
@@ -313,18 +336,17 @@ class MemberDef : public Definition
     MemberDef *groupAlias;    // Member containing the definition
     Specifier virt;           // normal/virtual/pure virtual
     Protection prot;          // protection type [Public/Protected/Private]
-    bool    related;          // is this a member that is only related to a class
-    bool    stat;             // is it a static function?
-    int     memSpec;          // The specifiers present for this member
+    int  memSpec;             // The specifiers present for this member
     MemberType mtype;         // returns the kind of member
+    bool related;             // is this a member that is only related to a class
+    bool stat;                // is it a static function?
     bool proto;               // is it a prototype;
     bool docEnumValues;       // is an enum with documented enum values.
     bool annScope;            // member is part of an annoymous scope
     bool annUsed;             
     bool annShown;           
     bool m_hasCallGraph;
-    //int  indDepth;            // indentation depth for this member if inside an annonymous scope
-    int  maxInitLines;        // when the initializer will be displayed 
+    int maxInitLines;         // when the initializer will be displayed 
     int userInitLines;        // result of explicit \hideinitializer or \showinitializer
     MemberList *section;      // declation list containing this member 
     MemberDef  *annMemb;
@@ -337,6 +359,7 @@ class MemberDef : public Definition
 
     GroupDef *group;          // group in which this member is in
     bool explExt;             // member was explicitly declared external
+    bool tspec;               // member is a template specialization
 
     ClassDef *cachedAnonymousType; // if the member has an anonymous compound
                                    // as its type then this is computed by
@@ -346,6 +369,7 @@ class MemberDef : public Definition
     QCString groupFileName;   // file where this grouping was defined
     int groupStartLine;       // line  "      "      "     "     "
     bool groupHasDocs;        // true if the entry that caused the grouping was documented
+    MemberDef *groupMember;
     MemberDef *m_templateMaster;
     SDict<MemberList> *classSectionSDict;
     bool docsForDefinition;   // TRUE => documentation block is put before
@@ -360,6 +384,7 @@ class MemberDef : public Definition
 
     bool m_isTypedefValCached;
     ClassDef *m_cachedTypedefValue;
+    QCString m_cachedTypedefTemplSpec;
     
     // inbody documentation
     int m_inbodyLine;
@@ -369,6 +394,12 @@ class MemberDef : public Definition
     // objective-c
     bool m_implOnly; // function found in implementation but not 
                      // in the interface
+
+    bool m_hasDocumentedParams;
+    bool m_hasDocumentedReturnType;
+
+    // documentation inheritance
+    MemberDef  *m_docProvider;
 };
 
 #endif
