@@ -81,7 +81,9 @@ void MemberGroup::insertMember(MemberDef *md)
   GroupDef *gd;
   if (firstMd && (gd=firstMd->getGroupDef()))
   {
-    md->setGroupDef(gd, firstMd->getGroupPri(), firstMd->getGroupFileName(), firstMd->getGroupStartLine(), firstMd->getGroupHasDocs());
+    md->setGroupDef(gd, firstMd->getGroupPri(), 
+                    firstMd->getGroupFileName(), firstMd->getGroupStartLine(), 
+                    firstMd->getGroupHasDocs());
     gd->insertMember(md);
   }
 }
