@@ -76,7 +76,8 @@ void MemberList::countDecMembers()
                                        m_funcCnt++,m_numDecMembers++; 
                                      break;
         case MemberDef::Enumeration: m_enumCnt++,m_numDecMembers++; break;
-        case MemberDef::EnumValue:   m_enumValCnt++,m_numDecMembers++; break;
+        case MemberDef::EnumValue:   //m_enumValCnt++,m_numDecMembers++; 
+                                     break;
         case MemberDef::Typedef:     m_typeCnt++,m_numDecMembers++; break;
         case MemberDef::Prototype:   m_protoCnt++,m_numDecMembers++; break;
         case MemberDef::Define:      if (Config_getBool("EXTRACT_ALL") || 
@@ -92,7 +93,7 @@ void MemberList::countDecMembers()
       }
     }
   }
-  if (memberGroupList /*&& countSubGroups*/)
+  if (memberGroupList)
   {
     MemberGroupListIterator mgli(*memberGroupList);
     MemberGroup *mg;
@@ -227,7 +228,6 @@ void MemberList::writePlainDeclarations(OutputList &ol,
               ol.startMemberItem(0);
               ol.writeString("enum ");
               ol.insertMemberAlign();
-              //ol+=typeDecl; // append the enum values.
               md->writeEnumDeclaration(ol,cd,nd,fd,gd);
               ol.endMemberItem();
               if (!md->briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
@@ -286,14 +286,14 @@ void MemberList::writePlainDeclarations(OutputList &ol,
     {
       if (md->fromAnonymousScope() && !md->anonymousDeclShown())
       {
+        md->setFromAnonymousScope(FALSE);
         //printf("anonymous compound members\n");
         if (md->isBriefSectionVisible())
         {
           if (first) ol.startMemberList(),first=FALSE;
-          md->setFromAnonymousScope(FALSE);
           md->writeDeclaration(ol,cd,nd,fd,gd,m_inGroup);
-          md->setFromAnonymousScope(TRUE);
         }
+        md->setFromAnonymousScope(TRUE);
       }
     }
   }
@@ -309,10 +309,10 @@ void MemberList::writeDeclarations(OutputList &ol,
              const char *title,const char *subtitle
              /*, bool inGroup,bool countSubGroups*/)
 {
-  //printf("MemberList::writeDeclaration(title=`%s',subtitle=`%s')\n",title,subtitle);
   //printf("----- writeDeclaration() ----\n");
   countDecMembers(); // count member not in group
   if (numDecMembers()==0) return;
+  //printf("MemberList::writeDeclaration(title=`%s',subtitle=`%s')=%d\n",title,subtitle,numDecMembers());
   if (title) 
   {
     ol.startMemberHeader();
