@@ -29,19 +29,28 @@
 #include "searchindex.h"
 
 NamespaceDef::NamespaceDef(const char *df,int dl,
-                           const char *name,const char *lref) : 
+                           const char *name,const char *lref,
+                           const char *fName) : 
    Definition(df,dl,name)
 {
-  fileName="namespace";
-  fileName+=name;
+  if (fName)
+  {
+    fileName = stripExtension(fName);
+  }
+  else
+  {
+    fileName="namespace";
+    fileName+=name;
+  }
   classSDict = new ClassSDict(17);
   namespaceSDict = new NamespaceSDict(17);
-  m_innerCompounds = new SDict<Definition>(257);
+  m_innerCompounds = new SDict<Definition>(17);
   usingDirList = 0;
   usingDeclList = 0;
   setReference(lref);
   memberGroupSDict = new MemberGroupSDict;
   memberGroupSDict->setAutoDelete(TRUE);
+  visited=FALSE;
 }
 
 NamespaceDef::~NamespaceDef()
@@ -264,25 +273,29 @@ void NamespaceDef::writeDetailedDocumentation(OutputList &ol)
   
 void NamespaceDef::writeDocumentation(OutputList &ol)
 {
-  QCString pageTitle=displayName()+" Namespace Reference";
-  startFile(ol,getOutputFileBase(),name(),pageTitle);
-  startTitle(ol,getOutputFileBase());
-  //ol.docify(pageTitle);
+  QCString pageTitle;
   if (Config_getBool("OPTIMIZE_OUTPUT_JAVA"))
   {
-    ol.parseText(theTranslator->trPackage(displayName()));
+    pageTitle = theTranslator->trPackage(displayName());
   }
   else
   {
-    ol.parseText(theTranslator->trNamespaceReference(displayName()));
+    pageTitle = theTranslator->trNamespaceReference(displayName());
   }
+  startFile(ol,getOutputFileBase(),name(),pageTitle);
+  if (getOuterScope()!=Doxygen::globalScope)
+  {
+    writeNavigationPath(ol);
+  }
+  startTitle(ol,getOutputFileBase());
+  ol.parseText(pageTitle);
   addGroupListToTitle(ol,this);
   endTitle(ol,getOutputFileBase(),displayName());
   
   if (Config_getBool("SEARCHENGINE"))
   {
     Doxygen::searchIndex->setCurrentDoc(pageTitle,getOutputFileBase());
-    Doxygen::searchIndex->addWord(localName().lower());
+    Doxygen::searchIndex->addWord(localName(),TRUE);
   }
 
   if (!Config_getString("GENERATE_TAGFILE").isEmpty())
@@ -321,7 +334,9 @@ void NamespaceDef::writeDocumentation(OutputList &ol)
   ol.endTextBlock();
   
   ol.startMemberSections();
-  classSDict->writeDeclaration(ol);
+  classSDict->writeDeclaration(ol,0,0,TRUE);
+
+  namespaceSDict->writeDeclaration(ol,TRUE);
 
   /* write user defined member groups */
   MemberGroupSDict::Iterator mgli(*memberGroupSDict);
@@ -413,7 +428,14 @@ void NamespaceDef::addUsingDeclaration(Definition *d)
 
 QCString NamespaceDef::getOutputFileBase() const 
 { 
-  return convertNameToFile(fileName); 
+  if (isReference())
+  {
+    return fileName;
+  }
+  else
+  {
+    return convertNameToFile(fileName); 
+  }
 }
 
 Definition *NamespaceDef::findInnerCompound(const char *n)
@@ -492,3 +514,59 @@ void NamespaceDef::combineUsingRelations()
   }
 }
 
+void NamespaceSDict::writeDeclaration(OutputList &ol,bool localName)
+{
+  if (count()==0) return;
+  // write list of namespaces
+  ol.startMemberHeader();
+  bool javaOpt = Config_getBool("OPTIMIZE_OUTPUT_JAVA");
+  if (javaOpt)
+  {
+    ol.parseText(theTranslator->trPackages());
+  }
+  else
+  {
+    ol.parseText(theTranslator->trNamespaces());
+  }
+  ol.endMemberHeader();
+  ol.startMemberList();
+  SDict<NamespaceDef>::Iterator ni(*this);
+  NamespaceDef *nd;
+  for (ni.toFirst();(nd=ni.current());++ni)
+  {
+    ol.startMemberItem(0);
+    if (javaOpt)
+    {
+      ol.docify("package ");
+    }
+    else
+    {
+      ol.docify("namespace ");
+    }
+    ol.insertMemberAlign();
+    QCString name;
+    if (localName)
+    {
+      name = nd->localName();
+    }
+    else
+    {
+      name = nd->displayName();
+    }
+    ol.writeObjectLink(nd->getReference(),nd->getOutputFileBase(),0,name);
+    if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
+    {
+      Doxygen::tagFile << "    <namespace>" << convertToXML(nd->name()) << "</namespace>" << endl;
+    }
+    ol.endMemberItem();
+    if (!nd->briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
+    {
+      ol.startMemberDescription();
+      ol.parseDoc(nd->briefFile(),nd->briefLine(),nd,0,nd->briefDescription(),FALSE,FALSE);
+      ol.endMemberDescription();
+      ol.newParagraph();
+    }
+  }
+  ol.endMemberList();
+}
+
