@@ -34,9 +34,11 @@
   
 class ClassDiagram;
 class DotClassGraph;
+class DotDirDeps;
 class DotInclDepGraph;
 class DotGfxHierarchyTable;
 class SectionDict;
+class DotGroupCollaboration;
 
 class OutputList : public OutputDocInterface
 {
@@ -62,7 +64,8 @@ class OutputList : public OutputDocInterface
 
     void parseDoc(const char *fileName,int startLine,
                   Definition *ctx,MemberDef *md,const QCString &docStr,
-                  bool indexWords,bool isExample,const char *exampleName=0);
+                  bool indexWords,bool isExample,const char *exampleName=0,
+                  bool singleLine=FALSE,bool linkFromIndex=FALSE);
     void parseText(const QCString &textStr);
     
 
@@ -169,6 +172,10 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::startMemberItem,i1); }
     void endMemberItem() 
     { forall(&OutputGenerator::endMemberItem); }
+    void startMemberTemplateParams() 
+    { forall(&OutputGenerator::startMemberTemplateParams); }
+    void endMemberTemplateParams() 
+    { forall(&OutputGenerator::endMemberTemplateParams); }
     void startMemberGroupHeader(bool b) 
     { forall(&OutputGenerator::startMemberGroupHeader,b); }
     void endMemberGroupHeader()
@@ -181,8 +188,8 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::startMemberGroup); }
     void endMemberGroup(bool last)
     { forall(&OutputGenerator::endMemberGroup,last); }
-    void insertMemberAlign() 
-    { forall(&OutputGenerator::insertMemberAlign); }
+    void insertMemberAlign(bool templ=FALSE) 
+    { forall(&OutputGenerator::insertMemberAlign,templ); }
     void writeRuler() 
     { forall(&OutputGenerator::writeRuler); }
     void writeAnchor(const char *fileName,const char *name)
@@ -317,12 +324,20 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::startCallGraph); }
     void endCallGraph(DotCallGraph &g)
     { forall(&OutputGenerator::endCallGraph,g); }
+    void startDirDepGraph()
+    { forall(&OutputGenerator::startDirDepGraph); }
+    void endDirDepGraph(DotDirDeps &g)
+    { forall(&OutputGenerator::endDirDepGraph,g); }
+    void startGroupCollaboration()
+    { forall(&OutputGenerator::startGroupCollaboration); }
+    void endGroupCollaboration(DotGroupCollaboration &g)
+    { forall(&OutputGenerator::endGroupCollaboration,g); }
     void writeGraphicalHierarchy(DotGfxHierarchyTable &g)
     { forall(&OutputGenerator::writeGraphicalHierarchy,g); }
     void startTextBlock(bool dense=FALSE)
     { forall(&OutputGenerator::startTextBlock,dense); }
-    void endTextBlock()
-    { forall(&OutputGenerator::endTextBlock); }
+    void endTextBlock(bool paraBreak=FALSE)
+    { forall(&OutputGenerator::endTextBlock,paraBreak); }
     void lastIndexPage()
     { forall(&OutputGenerator::lastIndexPage); }
     void startMemberDocPrefixItem()
@@ -382,13 +397,14 @@ class OutputList : public OutputDocInterface
     FORALLPROTO1(DotClassGraph &);
     FORALLPROTO1(DotInclDepGraph &);
     FORALLPROTO1(DotCallGraph &);
+    FORALLPROTO1(DotGroupCollaboration &);
+    FORALLPROTO1(DotDirDeps &);
     FORALLPROTO1(DotGfxHierarchyTable &);
     FORALLPROTO1(SectionTypes);
 #if defined(HAS_BOOL_TYPE) || defined(Q_HAS_BOOL_TYPE)
     FORALLPROTO1(bool);
     FORALLPROTO2(bool,int);
     FORALLPROTO2(bool,bool);
-    FORALLPROTO3(bool,bool,bool);
     FORALLPROTO4(const char *,const char *,const char *,int);
 #endif
     FORALLPROTO2(int,bool);
@@ -398,6 +414,7 @@ class OutputList : public OutputDocInterface
     FORALLPROTO2(const char *,const char *);
     FORALLPROTO2(const char *,bool);
     FORALLPROTO2(const char *,SectionInfo::SectionType);
+    FORALLPROTO3(bool,bool,bool);
     FORALLPROTO3(const char *,const char *,bool);
     FORALLPROTO3(const char *,const char *,SectionInfo::SectionType);
     FORALLPROTO3(uchar,uchar,uchar);
