@@ -3,7 +3,7 @@
  * $Id: section.h,v 1.7 2001/03/19 19:27:41 root Exp $
  *
  *
- * Copyright (C) 1997-2002 by Dimitri van Heesch.
+ * Copyright (C) 1997-2004 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -25,20 +25,30 @@
 #include "sortdict.h"
 
 class Definition;
-class PageInfo;
 
 struct SectionInfo
 {
-  enum SectionType { Page, Section, Subsection, Subsubsection, Paragraph, Anchor };
-  SectionInfo(const char *l,const char *t,SectionType st,const char *r=0)
-    { label=l; title=t; type=st; ref=r; definition=0; pageRef=0; generated=FALSE; }
+  enum SectionType { Page, Section, Subsection, 
+                     Subsubsection, Paragraph, Anchor 
+                   };
+  SectionInfo(const char *f,const char *l,const char *t,
+              SectionType st,const char *r=0) :
+    label(l), title(t), type(st), ref(r), definition(0), 
+    fileName(f), generated(FALSE)
+  { 
+  }
+  SectionInfo(const SectionInfo &s)
+  {
+    label=s.label.copy(); title=s.title.copy(); ref=s.ref.copy();
+    type =s.type; definition=s.definition;
+    fileName=s.fileName.copy(); generated=s.generated;
+  }
  ~SectionInfo() {}
   QCString label; 
   QCString title;
-  QCString ref;
   SectionType type;
+  QCString ref;
   Definition *definition;
-  PageInfo *pageRef;
   QCString fileName;
   bool generated;
 };
