@@ -35,6 +35,22 @@
 #include "defargs.h"
 //#include "reflist.h"
 
+/*! Information about an linkable anchor */
+class TagAnchorInfo
+{
+  public:
+    TagAnchorInfo(const QString &f,const QString &l) : label(l), fileName(f) {}
+    QString label;
+    QString fileName;
+};
+
+class TagAnchorInfoList : public QList<TagAnchorInfo>
+{
+  public: 
+    TagAnchorInfoList() : QList<TagAnchorInfo>() { setAutoDelete(TRUE); }
+    virtual ~TagAnchorInfoList() {}
+};
+
 /*! Container for member specific info that can be read from a tagfile */
 class TagMemberInfo
 {
@@ -45,7 +61,7 @@ class TagMemberInfo
     QString anchor;
     QString arglist;
     QString kind;
-    QStrList docAnchors;
+    TagAnchorInfoList docAnchors;
     Protection prot;
     Specifier virt;
     bool isStatic; 
@@ -60,7 +76,7 @@ class TagClassInfo
    ~TagClassInfo() { delete bases; delete templateArguments; }
     QString name;
     QString filename;
-    QStrList docAnchors;
+    TagAnchorInfoList docAnchors;
     QList<BaseInfo> *bases;
     QList<TagMemberInfo> members;
     QList<QString> *templateArguments;
@@ -75,7 +91,7 @@ class TagNamespaceInfo
     TagNamespaceInfo() { members.setAutoDelete(TRUE); }
     QString name;
     QString filename;
-    QStrList docAnchors;
+    TagAnchorInfoList docAnchors;
     QList<TagMemberInfo> members;
     QStringList classList;
 };
@@ -87,7 +103,7 @@ class TagPackageInfo
     TagPackageInfo() { members.setAutoDelete(TRUE); }
     QString name;
     QString filename;
-    QStrList docAnchors;
+    TagAnchorInfoList docAnchors;
     QList<TagMemberInfo> members;
     QStringList classList;
 };
@@ -99,6 +115,7 @@ class TagIncludeInfo
     QString name;
     QString text;
     bool isLocal;
+    bool isImported;
 };
 
 /*! Container for file specific info that can be read from a tagfile */
@@ -109,7 +126,7 @@ class TagFileInfo
     QString name;
     QString path;
     QString filename;
-    QStrList docAnchors;
+    TagAnchorInfoList docAnchors;
     QList<TagMemberInfo> members;
     QStringList classList;
     QStringList namespaceList;
@@ -124,13 +141,14 @@ class TagGroupInfo
     QString name;
     QString title;
     QString filename;
-    QStrList docAnchors;
+    TagAnchorInfoList docAnchors;
     QList<TagMemberInfo> members;
     QStringList subgroupList;
     QStringList classList;
     QStringList namespaceList;
     QStringList fileList;
     QStringList pageList;
+    QStringList dirList;
 };
 
 /*! Container for page specific info that can be read from a tagfile */
@@ -140,9 +158,20 @@ class TagPageInfo
     QString name;
     QString title;
     QString filename;
-    QStrList docAnchors;
+    TagAnchorInfoList docAnchors;
 };
 
+/*! Container for directory specific info that can be read from a tagfile */
+class TagDirInfo
+{
+  public:
+    QString name;
+    QString filename;
+    QString path;
+    QStringList subdirList;
+    QStringList fileList;
+    TagAnchorInfoList docAnchors;
+};
 
 /*! Tag file parser. 
  *  Reads an XML-structured tagfile and builds up the structure in
@@ -159,6 +188,7 @@ class TagFileParser : public QXmlDefaultHandler
                  InPage,
                  InMember,
                  InPackage,
+                 InDir,
                  InTempArgList
                };
     class StartElementHandler
@@ -263,6 +293,11 @@ class TagFileParser : public QXmlDefaultHandler
         m_curPackage = new TagPackageInfo;
         m_state = InPackage;
       }
+      else if (kind=="dir")
+      {
+        m_curDir = new TagDirInfo;
+        m_state = InDir;
+      }
       else
       {
         err("Error: Unknown compound attribute `%s' found!\n",kind.data());
@@ -286,6 +321,8 @@ class TagFileParser : public QXmlDefaultHandler
                           m_curGroup=0; break; 
         case InPage:      m_tagFilePages.append(m_curPage); 
                           m_curPage=0; break; 
+        case InDir:       m_tagFileDirs.append(m_curDir);
+                          m_curDir=0; break;
         case InPackage:   m_tagFilePackages.append(m_curPackage); 
                           m_curPackage=0; break; 
         default:
@@ -296,8 +333,8 @@ class TagFileParser : public QXmlDefaultHandler
     {
       m_curMember = new TagMemberInfo;
       m_curMember->kind = attrib.value("kind");
-      QString protStr = attrib.value("protection");
-      QString virtStr = attrib.value("virtualness");
+      QString protStr   = attrib.value("protection");
+      QString virtStr   = attrib.value("virtualness");
       QString staticStr = attrib.value("static");
       if (protStr=="protected")
       {
@@ -343,13 +380,14 @@ class TagFileParser : public QXmlDefaultHandler
     {
       switch(m_state)
       {
-        case InClass:     m_curClass->docAnchors.append(m_curString); break;
-        case InFile:      m_curFile->docAnchors.append(m_curString); break;
-        case InNamespace: m_curNamespace->docAnchors.append(m_curString); break;
-        case InGroup:     m_curGroup->docAnchors.append(m_curString); break;
-        case InPage:      m_curPage->docAnchors.append(m_curString); break;
-        case InMember:    m_curMember->docAnchors.append(m_curString); break;
-        case InPackage:   m_curPackage->docAnchors.append(m_curString); break;
+        case InClass:     m_curClass->docAnchors.append(new TagAnchorInfo(m_fileName,m_curString)); break;
+        case InFile:      m_curFile->docAnchors.append(new TagAnchorInfo(m_fileName,m_curString)); break;
+        case InNamespace: m_curNamespace->docAnchors.append(new TagAnchorInfo(m_fileName,m_curString)); break;
+        case InGroup:     m_curGroup->docAnchors.append(new TagAnchorInfo(m_fileName,m_curString)); break;
+        case InPage:      m_curPage->docAnchors.append(new TagAnchorInfo(m_fileName,m_curString)); break;
+        case InMember:    m_curMember->docAnchors.append(new TagAnchorInfo(m_fileName,m_curString)); break;
+        case InPackage:   m_curPackage->docAnchors.append(new TagAnchorInfo(m_fileName,m_curString)); break;
+        case InDir:       m_curDir->docAnchors.append(new TagAnchorInfo(m_fileName,m_curString)); break;
         default:   err("Error: Unexpected tag `member' found\n"); break; 
       }
     }
@@ -378,6 +416,7 @@ class TagFileParser : public QXmlDefaultHandler
       switch(m_state)
       {
         case InGroup:      m_curGroup->fileList.append(m_curString); break;
+        case InDir:        m_curDir->fileList.append(m_curString); break;
         default:   err("Error: Unexpected tag `file' found\n"); break; 
       }
     }
@@ -389,10 +428,23 @@ class TagFileParser : public QXmlDefaultHandler
         default:   err("Error: Unexpected tag `page' found\n"); break; 
       }
     }
+    void endDir()
+    {
+      switch(m_state)
+      {
+        case InDir:      m_curDir->subdirList.append(m_curString); break;
+        default:   err("Error: Unexpected tag `page' found\n"); break; 
+      }
+    }
     void startStringValue(const QXmlAttributes& )
     {
       m_curString = "";
     }
+    void startDocAnchor(const QXmlAttributes& attrib )
+    {
+      m_fileName = attrib.value("file");
+      m_curString = "";
+    }
     void endType()
     {
       if (m_state==InMember)
@@ -413,6 +465,7 @@ class TagFileParser : public QXmlDefaultHandler
         case InNamespace: m_curNamespace->name = m_curString; break;
         case InGroup:     m_curGroup->name     = m_curString; break;
         case InPage:      m_curPage->name      = m_curString; break;
+        case InDir:       m_curDir->name       = m_curString; break;
         case InMember:    m_curMember->name    = m_curString; break;
         case InPackage:   m_curPackage->name   = m_curString; break;
         default: err("Error: Unexpected tag `name' found\n"); break; 
@@ -470,6 +523,7 @@ class TagFileParser : public QXmlDefaultHandler
         m_curIncludes->id = attrib.value("id");
         m_curIncludes->name = attrib.value("name");
         m_curIncludes->isLocal = attrib.value("local")=="yes" ? TRUE : FALSE;
+        m_curIncludes->isImported = attrib.value("imported")=="yes" ? TRUE : FALSE;
         m_curFile->includes.append(m_curIncludes);
       }
       else
@@ -508,6 +562,7 @@ class TagFileParser : public QXmlDefaultHandler
         case InGroup:     m_curGroup->filename     = m_curString;    break;
         case InPage:      m_curPage->filename      = m_curString;    break;
         case InPackage:   m_curPackage->filename   = m_curString;    break;
+        case InDir:       m_curDir->filename       = m_curString;    break;
         default: err("Error: Unexpected tag `filename' found\n"); break; 
       }
     }
@@ -516,6 +571,7 @@ class TagFileParser : public QXmlDefaultHandler
       switch (m_state)
       {
         case InFile:      m_curFile->path          = m_curString;    break;
+        case InDir:       m_curDir->path           = m_curString;    break;
         default: err("Error: Unexpected tag `path' found\n");     break; 
       }
     }
@@ -578,6 +634,7 @@ class TagFileParser : public QXmlDefaultHandler
       m_curGroup=0;
       m_curPage=0;
       m_curPackage=0;
+      m_curDir=0;
 
       m_stateStack.setAutoDelete(TRUE);
       m_tagFileClasses.setAutoDelete(TRUE);
@@ -586,6 +643,7 @@ class TagFileParser : public QXmlDefaultHandler
       m_tagFileGroups.setAutoDelete(TRUE);
       m_tagFilePages.setAutoDelete(TRUE);
       m_tagFilePackages.setAutoDelete(TRUE);
+      m_tagFileDirs.setAutoDelete(TRUE);
 
       m_startElementHandlers.insert("compound",    new StartElementHandler(this,&TagFileParser::startCompound));
       m_startElementHandlers.insert("member",      new StartElementHandler(this,&TagFileParser::startMember));
@@ -601,8 +659,9 @@ class TagFileParser : public QXmlDefaultHandler
       m_startElementHandlers.insert("class",       new StartElementHandler(this,&TagFileParser::startStringValue));
       m_startElementHandlers.insert("namespace",   new StartElementHandler(this,&TagFileParser::startStringValue));
       m_startElementHandlers.insert("file",        new StartElementHandler(this,&TagFileParser::startStringValue));
+      m_startElementHandlers.insert("dir",         new StartElementHandler(this,&TagFileParser::startStringValue));
       m_startElementHandlers.insert("page",        new StartElementHandler(this,&TagFileParser::startStringValue));
-      m_startElementHandlers.insert("docanchor",   new StartElementHandler(this,&TagFileParser::startStringValue));
+      m_startElementHandlers.insert("docanchor",   new StartElementHandler(this,&TagFileParser::startDocAnchor));
       m_startElementHandlers.insert("tagfile",     new StartElementHandler(this,&TagFileParser::startIgnoreElement));
       m_startElementHandlers.insert("templarg",    new StartElementHandler(this,&TagFileParser::startStringValue));
       m_startElementHandlers.insert("type",        new StartElementHandler(this,&TagFileParser::startStringValue));
@@ -621,6 +680,7 @@ class TagFileParser : public QXmlDefaultHandler
       m_endElementHandlers.insert("class"   ,    new EndElementHandler(this,&TagFileParser::endClass));
       m_endElementHandlers.insert("namespace",   new EndElementHandler(this,&TagFileParser::endNamespace));
       m_endElementHandlers.insert("file",        new EndElementHandler(this,&TagFileParser::endFile));
+      m_endElementHandlers.insert("dir",         new EndElementHandler(this,&TagFileParser::endDir));
       m_endElementHandlers.insert("page",        new EndElementHandler(this,&TagFileParser::endPage));
       m_endElementHandlers.insert("docanchor",   new EndElementHandler(this,&TagFileParser::endDocAnchor));
       m_endElementHandlers.insert("tagfile",     new EndElementHandler(this,&TagFileParser::endIgnoreElement));
@@ -669,13 +729,14 @@ class TagFileParser : public QXmlDefaultHandler
     
   private:
     void buildMemberList(Entry *ce,QList<TagMemberInfo> &members);
-    void addDocAnchors(Entry *e,QStrList &l);
+    void addDocAnchors(Entry *e,const TagAnchorInfoList &l);
     QList<TagClassInfo>        m_tagFileClasses;
     QList<TagFileInfo>         m_tagFileFiles;
     QList<TagNamespaceInfo>    m_tagFileNamespaces;
     QList<TagGroupInfo>        m_tagFileGroups;
     QList<TagPageInfo>         m_tagFilePages;
     QList<TagPackageInfo>      m_tagFilePackages;
+    QList<TagDirInfo>          m_tagFileDirs;
     QDict<StartElementHandler> m_startElementHandlers;
     QDict<EndElementHandler>   m_endElementHandlers;
     TagClassInfo              *m_curClass;
@@ -684,10 +745,12 @@ class TagFileParser : public QXmlDefaultHandler
     TagPackageInfo            *m_curPackage;
     TagGroupInfo              *m_curGroup;
     TagPageInfo               *m_curPage;
+    TagDirInfo                *m_curDir;
     TagMemberInfo             *m_curMember;
     TagIncludeInfo            *m_curIncludes;
     QCString                   m_curString;
     QString                    m_tagName;
+    QString                    m_fileName;
     State                      m_state;
     QStack<State>              m_stateStack;
 };
@@ -870,26 +933,46 @@ void TagFileParser::dump()
     msg("  title `%s'\n",pd->title.data());
     msg("  filename `%s'\n",pd->filename.data());
   }
+  //============== DIRS
+  QListIterator<TagDirInfo> ldi(m_tagFileDirs);
+  TagDirInfo *dd;
+  for (;(dd=ldi.current());++ldi)
+  {
+    msg("dir `%s'\n",dd->name.data());
+    msg("  path `%s'\n",dd->path.data());
+    QStringList::Iterator it;
+    for ( it = dd->fileList.begin(); 
+        it != dd->fileList.end(); ++it ) 
+    {
+      msg( "  file: %s \n", (*it).latin1() );
+    }
+    for ( it = dd->subdirList.begin(); 
+        it != dd->subdirList.end(); ++it ) 
+    {
+      msg( "  subdir: %s \n", (*it).latin1() );
+    }
+  }
 }
 
-void TagFileParser::addDocAnchors(Entry *e,QStrList &l)
+void TagFileParser::addDocAnchors(Entry *e,const TagAnchorInfoList &l)
 {
-  char *s=l.first();
-  while (s)
+  QListIterator<TagAnchorInfo> tli(l);
+  TagAnchorInfo *ta;
+  for (tli.toFirst();(ta=tli.current());++tli)
   {
-    QCString *anchorName = new QCString(s);
-    if (Doxygen::sectionDict.find(*anchorName)==0)
+    if (Doxygen::sectionDict.find(ta->label)==0)
     {
-      SectionInfo *si=new SectionInfo(e->fileName,*anchorName,*anchorName,
+      //printf("New sectionInfo file=%s anchor=%s\n",
+      //    ta->fileName.data(),ta->label.data());
+      SectionInfo *si=new SectionInfo(ta->fileName,ta->label,ta->label,
           SectionInfo::Anchor,m_tagName);
-      Doxygen::sectionDict.insert(*anchorName,si);
+      Doxygen::sectionDict.insert(ta->label,si);
       e->anchors->append(si);
     }
     else
     {
-      err("Duplicate anchor %s found\n",anchorName->data());
+      err("Duplicate anchor %s found\n",ta->label.data());
     }
-    s=l.next();
   }
 }
 
@@ -1215,7 +1298,7 @@ void TagFileParser::addIncludes()
                 //        ifd->getOutputFileBase().data(),ii->id.data());
                 if (ifd->getOutputFileBase()==QCString(ii->id))
                 {
-                  fd->addIncludeDependency(ifd,ii->text,ii->isLocal);
+                  fd->addIncludeDependency(ifd,ii->text,ii->isLocal,ii->isImported);
                 }
               }
             }
