@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (C) 1997-2002 by Dimitri van Heesch.
+ * Copyright (C) 1997-2004 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -11,23 +11,30 @@
  * input used in their production; they are not affected by this license.
  *
  * Brazilian Portuguese version by
- *   Fabio "FJTC" Jun Takada Chino <chino@icmc.sc.usp.br>
- *      http://www.icmc.sc.usp.br/~chino
- *   Version: 1.2.18 (2002/07/30)
+ *   Fabio "FJTC" Jun Takada Chino <jun-chino at uol.com.br>
+ *   Version: 1.3.8 (2004/06/30)
  *
  * History:
- *   1.2.18 (2002/07/30):
- *      - Updated to Doxygen 1.2.18
- *   1.2.17 (2002/07/10):
- *      - Updated to Doxygen 1.2.17.
- *   1.2.13.2 (2002/05/10):
- *      - Latex Babel package language name fixed.
- *      - "Estrura" bug identified and fixed (Thanks to Jorge Ramos).
+ * 	 1.3.9
+ *		- Updated to Doxygen 1.3.9
+ * 	 1.3.8
+ *		- Updated to Doxygen 1.3.8
+ *   1.3.3:
+ *      - Updated to Doxygen 1.3.3
+ *   1.3.2:
+ *      - Updated to Doxygen 1.3.2
+ *   1.3:
+ *      - Updated to Doxygen 1.3.x.
+ *   1.2.19:
+ *      - Updated to Doxygen 1.2.19
+ *      - Translation Review (Thanks to Jorge Ramos and others)
+ *      - Small fixes in C output.
+ *      - Latex generation support fixed (invalid package name).
  */
 #ifndef TRANSLATOR_BR_H
 #define TRANSLATOR_BR_H
 
-class TranslatorBrazilian: public Translator
+class TranslatorBrazilian : public Translator
 {
   public:
 
@@ -52,7 +59,7 @@ class TranslatorBrazilian: public Translator
      */
     virtual QCString latexLanguageSupportCommand()
     {
-      return "Brazilian";
+      return "";
     }
 
     /*! return the language charset. This will be used for the HTML output */
@@ -114,7 +121,7 @@ class TranslatorBrazilian: public Translator
 
     /*! this is the first part of a sentence that is followed by a class name */
     virtual QCString trThisIsTheListOfAllMembers()
-    { return "Esta  a lista de todos os membros da "; }
+    { return "Esta  a lista de todos os membros de "; }
 
     /*! this is the remainder of the sentence after the class name */
     virtual QCString trIncludingInheritedMembers()
@@ -140,7 +147,7 @@ class TranslatorBrazilian: public Translator
 
     /*! put after an undocumented member in the list of all members */
     virtual QCString trDefinedIn()
-    { return "definida em"; }
+    { return "definido(a) em"; }
 
     // quick reference sections
 
@@ -148,7 +155,7 @@ class TranslatorBrazilian: public Translator
      *  compounds or files (see the \\group command).
      */
     virtual QCString trModules()
-    { return "Modulos"; }
+    { return "Mdulos"; }
 
     /*! This is put above each page as a link to the class hierarchy */
     virtual QCString trClassHierarchy()
@@ -159,7 +166,7 @@ class TranslatorBrazilian: public Translator
     {
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
-        return "Estrutura de Dados";
+        return "Estruturas de Dados";
       }
       else
       {
@@ -215,14 +222,14 @@ class TranslatorBrazilian: public Translator
 
     /*! This is an introduction to the class hierarchy. */
     virtual QCString trClassHierarchyDescription()
-    { return "Esta lista de hierarquia est parcialmente ordenada em ordem alfabtica:"; }
+    { return "Esta lista de hierarquias est parcialmente ordenada (ordem alfabtica):"; }
 
     /*! This is an introduction to the list with all files. */
     virtual QCString trFileListDescription(bool extractAll)
     {
-      QCString result="Aqui est a lista de todos os arquivos ";
+      QCString result="Esta  a lista de todos os arquivos ";
       if (!extractAll) result+="documentados ";
-      result+="com suas respectivas descries:";
+      result+="e suas respectivas descries:";
       return result;
     }
 
@@ -243,13 +250,47 @@ class TranslatorBrazilian: public Translator
     /*! This is an introduction to the page with all class members. */
     virtual QCString trCompoundMembersDescription(bool extractAll)
     {
-      QCString result="Esta  lista de todos os membros das classes ";
-      if (!extractAll) result+="documentados ";
-      result+="com links para ";
-      if (extractAll)
-        result+="a documentao de suas respectivas classes:";
+      QCString result="Esta  a lista de ";
+      
+      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      {
+        result+="todas as estruturas e campos de unies ";
+        if (!extractAll)
+        {
+          result+="documentas";
+        }
+      }
       else
-        result+="suas respectivas classes:";
+      {
+        result+="todos os membros de classes ";
+        if (!extractAll)
+        {
+          result+="documentos";
+        }
+      }
+      result+=" com referncias para ";
+      if (!extractAll)
+      {
+        if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+        {
+          result+="a documentao da estrutura/unio de cada campo:";
+        }
+        else
+        {
+          result+="a documentao da classe de cada membro:";
+        }
+      }
+      else
+      {
+        if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+        {
+          result+="a estrutura/unio a que pertencem:";
+        }
+        else
+        {
+          result+="a classe a que pertencem:";
+        }
+      }
       return result;
     }
 
@@ -259,7 +300,7 @@ class TranslatorBrazilian: public Translator
       QCString result="Esta  a lista de ";
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
-        result+="tadas as funes, variveis, definies, enumeraes e definies de tipos ";
+        result+="todas as funes, variveis, definies, enumeraes e definies de tipos ";
         if (!extractAll) result+="documentadas ";
       }
       else
@@ -267,9 +308,7 @@ class TranslatorBrazilian: public Translator
         result+="todos os membros dos arquivos ";
         if (!extractAll) result+="documentados ";
       }
-
-
-      result+="com links para ";
+      result+="com referncias para ";
       if (extractAll)
         result+="seus respectivos arquivos:";
       else
@@ -283,15 +322,15 @@ class TranslatorBrazilian: public Translator
 
     /*! This is an introduction to the page with the list of all examples */
     virtual QCString trExamplesDescription()
-    { return "Esta  a lista de todos os exemplos:"; }
+    { return "Esta  a lista com todos os exemplos:"; }
 
     /*! This is an introduction to the page with the list of related pages */
     virtual QCString trRelatedPagesDescription()
-    { return "Esta  a lista de toda a documentao relacionadas:"; }
+    { return "Esta  a lista com toda a documentao relacionadas:"; }
 
     /*! This is an introduction to the page with the list of class/file groups */
     virtual QCString trModulesDescription()
-    { return "Esta  a lista de todos os mdulos:"; }
+    { return "Esta  a lista com todos os mdulos:"; }
 
     /*! This sentences is used in the annotated class/file lists if no brief
      * description is given.
@@ -304,7 +343,7 @@ class TranslatorBrazilian: public Translator
 
     /*! This is used in HTML as the title of index.html. */
     virtual QCString trDocumentation()
-    { return "Documentao"; }
+    { return "\nDocumentao"; }
 
     /*! This is used in LaTeX as the title of the chapter with the
      * index of all groups.
@@ -349,7 +388,16 @@ class TranslatorBrazilian: public Translator
      *  the documentation of all classes, structs and unions.
      */
     virtual QCString trClassDocumentation()
-    { return "Classes"; }
+    {
+      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      {
+        return "Estruturas";
+      }
+      else
+      {
+        return "Classes";
+      }
+    }
 
     /*! This is used in LaTeX as the title of the chapter containing
      *  the documentation of all files.
@@ -413,7 +461,7 @@ class TranslatorBrazilian: public Translator
      *  list of (global) variables
      */
     virtual QCString trEnumerationValues()
-    { return "Valores Enumerados"; }
+    { return "Valores enumerados"; }
 
     /*! This is used in the documentation of a file before the list of
      *  documentation blocks for defines
@@ -509,7 +557,7 @@ class TranslatorBrazilian: public Translator
 
     /*! this text is generated when the \\bug command is used. */
     virtual QCString trBugsAndLimitations()
-    { return "Bugs e limitaes"; }
+    { return "Problemas e Limitaes"; }
 
     /*! this text is generated when the \\version command is used. */
     virtual QCString trVersion()
@@ -550,7 +598,7 @@ class TranslatorBrazilian: public Translator
     /*! used as an introduction to the namespace list */
     virtual QCString trNamespaceListDescription(bool extractAll)
     {
-      QCString result="Aqui esta a lista de todos os Namespaces ";
+      QCString result="Esta  a lista de todos os Namespaces ";
       if (!extractAll) result+="documentados ";
       result+="com suas respectivas descries:";
       return result;
@@ -582,7 +630,6 @@ class TranslatorBrazilian: public Translator
                                     bool isTemplate)
     {
       QCString result="Referncia da";
-
       if (isTemplate) result+=" Template de";
       switch(compType)
       {
@@ -590,6 +637,8 @@ class TranslatorBrazilian: public Translator
         case ClassDef::Struct:     result+=" Estrutura "; break;
         case ClassDef::Union:      result+=" Unio "; break;
         case ClassDef::Interface:  result+=" Interface "; break;
+        case ClassDef::Protocol:   result+=" Protocol "; break; // translate me!
+        case ClassDef::Category:   result+=" Category "; break; // translate me!
         case ClassDef::Exception:  result+=" Exceo "; break;
       }
       result+=(QCString)clName;
@@ -612,13 +661,12 @@ class TranslatorBrazilian: public Translator
       return result;
     }
 
-    /* these are for the member sections of a class, struct or union */
     virtual QCString trPublicMembers()
     { return "Mtodos Pblicos"; }
     virtual QCString trPublicSlots()
     { return "Slots Pblicos"; }
     virtual QCString trSignals()
-    { return "Signals"; }
+    { return "Sinais"; }
     virtual QCString trStaticPublicMembers()
     { return "Mtodos Pblicos Estticos"; }
     virtual QCString trProtectedMembers()
@@ -680,7 +728,7 @@ class TranslatorBrazilian: public Translator
      */
     virtual QCString trReimplementedFromList(int numEntries)
     {
-      return "Reimplementado de "+trWriteList(numEntries)+".";
+      return "Reimplementao de "+trWriteList(numEntries)+".";
     }
 
     /*! used in member documentation blocks to produce a list of
@@ -688,7 +736,7 @@ class TranslatorBrazilian: public Translator
      */
     virtual QCString trReimplementedInList(int numEntries)
     {
-      return "Reimplementado em "+trWriteList(numEntries)+".";
+      return "Reimplementado por "+trWriteList(numEntries)+".";
     }
 
     /*! This is put above each page as a link to all members of namespaces. */
@@ -698,9 +746,9 @@ class TranslatorBrazilian: public Translator
     /*! This is an introduction to the page with all namespace members */
     virtual QCString trNamespaceMemberDescription(bool extractAll)
     {
-      QCString result="Aqui est a lista de todos os membros do Namespace ";
+      QCString result="Esta  a lista com todos os membros do Namespace ";
       if (!extractAll) result+="documentados ";
-      result+="com links para ";
+      result+="com referncias para ";
       if (extractAll)
         result+="a documentao de seus respectivos Namespaces:";
       else
@@ -711,7 +759,7 @@ class TranslatorBrazilian: public Translator
      *  index of all namespaces.
      */
     virtual QCString trNamespaceIndex()
-    { return "ndice de Namespaces"; }
+    { return "Namespaces"; }
 
     /*! This is used in LaTeX as the title of the chapter containing
      *  the documentation of all namespaces.
@@ -747,6 +795,8 @@ class TranslatorBrazilian: public Translator
         case ClassDef::Struct:     result+="estrutura "; break;
         case ClassDef::Union:      result+="unio "; break;
         case ClassDef::Interface:  result+="interface "; break;
+        case ClassDef::Protocol:   result+="protocol "; break; // translate me!
+        case ClassDef::Category:   result+="category "; break; // translate me!
         case ClassDef::Exception:  result+="exceo "; break;
       }
       result+=" foi gerada a partir ";
@@ -851,7 +901,7 @@ class TranslatorBrazilian: public Translator
     /*! Text for the \\invariant command */
     virtual QCString trInvariant()
     {
-      return "Invarivel";
+      return "Invariante";
     }
     /*! Text shown before a multi-line variable/enum initialization */
     virtual QCString trInitialValue()
@@ -877,7 +927,7 @@ class TranslatorBrazilian: public Translator
     }
     virtual QCString trPageIndex()
     {
-      return "ndice de Pgina";
+      return "ndice da Pgina";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -886,7 +936,7 @@ class TranslatorBrazilian: public Translator
 
     virtual QCString trNote()
     {
-      return "Nota";
+      return "Observao";
     }
     virtual QCString trPublicTypes()
     {
@@ -905,7 +955,7 @@ class TranslatorBrazilian: public Translator
     }
     virtual QCString trStaticPublicAttribs()
     {
-      return "Atributos Pblicos Estticos";
+      return "Atributos Estticos Pblicos";
     }
     virtual QCString trProtectedTypes()
     {
@@ -917,7 +967,7 @@ class TranslatorBrazilian: public Translator
     }
     virtual QCString trStaticProtectedAttribs()
     {
-      return "Atributos Protegidos Estticos";
+      return "Atributos Estticos Protegidos";
     }
     virtual QCString trPrivateTypes()
     {
@@ -939,12 +989,12 @@ class TranslatorBrazilian: public Translator
     /*! Used as a marker that is put before a todo item */
     virtual QCString trTodo()
     {
-      return "Tarefas Futuras";
+      return "Futuras Atividades";
     }
     /*! Used as the header of the todo list */
     virtual QCString trTodoList()
     {
-      return "Lista de Tarefas Futuras";
+      return "Lista de Futuras Atividades";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -965,8 +1015,7 @@ class TranslatorBrazilian: public Translator
     }
     virtual QCString trInclByDepGraph()
     {
-      return "Este grafo mostra quais arquivos esto direta ou indiretamente "
-             "relacionados com este arquivo:";
+      return "Este grafo mostra quais arquivos esto direta ou indiretamente relacionados com este arquivo:";
     }
     virtual QCString trSince()
     {
@@ -1120,7 +1169,7 @@ class TranslatorBrazilian: public Translator
     /*! The description of the package index page */
     virtual QCString trPackageListDescription()
     {
-      return "Aqui est a lista de pacotes com suas respectivas descries (se disponveis):";
+      return "Esta  a lista com os pacotes e suas respectivas descries (se disponveis):";
     }
     /*! The link name in the Quick links header for each page */
     virtual QCString trPackages()
@@ -1145,12 +1194,12 @@ class TranslatorBrazilian: public Translator
     /*! Used as a marker that is put before a \\bug item */
     virtual QCString trBug()
     {
-      return "Bug";
+      return "Problema";
     }
     /*! Used as the header of the bug list */
     virtual QCString trBugList()
     {
-      return "Lista de Bug";
+      return "Lista de Problemas";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1335,7 +1384,7 @@ class TranslatorBrazilian: public Translator
      */
     virtual QCString trImplementedInList(int numEntries)
     {
-      return "Implementado em "+trWriteList(numEntries)+".";
+      return "Implementado por "+trWriteList(numEntries)+".";
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1362,5 +1411,191 @@ class TranslatorBrazilian: public Translator
       return "Lista de Descontinuados(as)";
     }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.2.18
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used as a header for declaration section of the events found in
+     * a C# program
+     */
+    virtual QCString trEvents()
+    {
+      return "Eventos";
+    }
+    /*! Header used for the documentation section of a class' events. */
+    virtual QCString trEventDocumentation()
+    {
+      return "Eventos";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used as a heading for a list of Java class types with package scope.
+     */
+    virtual QCString trPackageTypes()
+    {
+      return "Tipos do Pacote";
+    }
+
+    /*! Used as a heading for a list of Java class functions with package
+     * scope.
+     */
+    virtual QCString trPackageMembers()
+    {
+      return "Funes do Pacote";
+    }
+
+    /*! Used as a heading for a list of static Java class functions with
+     *  package scope.
+     */
+    virtual QCString trStaticPackageMembers()
+    {
+      return "Funes Estticas do Pacote";
+    }
+
+    /*! Used as a heading for a list of Java class variables with package
+     * scope.
+     */
+    virtual QCString trPackageAttribs()
+    {
+      return "Atributos do Pacote";
+    }
+
+    /*! Used as a heading for a list of static Java class variables with
+     * package scope.
+     */
+    virtual QCString trStaticPackageAttribs()
+    {
+      return "Atributos Estticos do Pacote";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used in the quick index of a class/file/namespace member list page
+     *  to link to the unfiltered list of all members.
+     */
+    virtual QCString trAll()
+    {
+      return "Todos";
+    }
+    /*! Put in front of the call graph for a function. */
+    virtual QCString trCallGraph()
+    {
+      return "Este  o grafo de chamadas para esta funo:";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.3
+//////////////////////////////////////////////////////////////////////////
+
+    /*! When the search engine is enabled this text is put in the header
+     *  of each page before the field where one can enter the text to search
+     *  for.
+     */
+    virtual QCString trSearchForIndex()
+    {
+      return "Procurar por";
+    }
+    /*! This string is used as the title for the page listing the search
+     *  results.
+     */
+    virtual QCString trSearchResultsTitle()
+    {
+      return "Resultado da Busca";
+    }
+    /*! This string is put just before listing the search results. The
+     *  text can be different depending on the number of documents found.
+     *  Inside the text you can put the special marker $num to insert
+     *  the number representing the actual number of search results.
+     *  The @a numDocuments parameter can be either 0, 1 or 2, where the
+     *  value 2 represents 2 or more matches. HTML markup is allowed inside
+     *  the returned string.
+     */
+    virtual QCString trSearchResults(int numDocuments)
+    {
+      if (numDocuments==0)
+      {
+        return "Nenhum documento foi encontrado.";
+      }
+      else if (numDocuments==1)
+      {
+        return "Apenas <b>1</b> documento foi encontrado.";
+      }
+      else
+      {
+        return "<b>$num</b> documentos encontrados. "
+               "Os melhores resultados vem primeiro.";
+      }
+    }
+    /*! This string is put before the list of matched words, for each search
+     *  result. What follows is the list of words that matched the query.
+     */
+    virtual QCString trSearchMatches()
+    {
+      return "Resultados:";
+    }
+    
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.8
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used in HTML as the title of page with source code for file filename
+     */
+    virtual QCString trSourceFile(QCString& filename)
+    {
+      return  "Cdigo-Fonte de " + filename;
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.9
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used as the name of the chapter containing the directory
+     *  hierarchy.
+     */
+    virtual QCString trDirIndex()
+    { return "Hierarquia de Diretrios"; }
+
+    /*! This is used as the name of the chapter containing the documentation
+     *  of the directories.
+     */
+    virtual QCString trDirDocumentation()
+    { return "Documentao do Directrio"; }
+
+    /*! This is used as the title of the directory index and also in the
+     *  Quick links of a HTML page, to link to the directory hierarchy.
+     */
+    virtual QCString trDirectories()
+    { return "Diretrios"; }
+
+    /*! This returns a sentences that introduces the directory hierarchy. 
+     *  and the fact that it is sorted alphabetically per level
+     */
+    virtual QCString trDirDescription()
+    { return "Esta Hierarquia de Diretrios est parcialmente ordenada (ordem alfabtica)"; }
+
+    /*! This returns the title of a directory page. The name of the
+     *  directory is passed via \a dirName.
+     */
+    virtual QCString trDirReference(const char *dirName)
+    {
+        QCString result = "Referncia do diretrio ";
+     	result += dirName;
+     	return result;
+    }
+
+    /*! This returns the word directory with or without starting capital
+     *  (\a first_capital) and in sigular or plural form (\a singular).
+     */
+    virtual QCString trDir(bool first_capital, bool singular)
+    { 
+      QCString result((first_capital ? "Diretrio" : "diretrio"));
+      if (!singular) result+="s";
+      return result; 
+    }
 };
 #endif
