@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * $Id: translator_cn.h,v 1.3 2001/03/19 19:27:41 root Exp $
+ * 
  *
  * Copyright (C) 1997-2004 by Dimitri van Heesch.
  *
@@ -24,7 +24,7 @@
 */
 #define CN_SPC
 
-class TranslatorChinese : public TranslatorAdapter_1_2_13
+class TranslatorChinese : public Translator
 {
   public:
 		/*! Used for identification of the language. The identification
@@ -36,24 +36,24 @@ class TranslatorChinese : public TranslatorAdapter_1_2_13
     virtual QCString idLanguage()
     { return "chinese"; }
 
-		/*! Used to get the LaTeX command(s) for the language support. 
-		 * This method should return string with commands that switch
-		 * LaTeX to the desired language.  For example 
-		 * <pre>"\\usepackage[german]{babel}\n"
-		 * </pre>
-		 * or
-		 * <pre>"\\usepackage{polski}\n"
-		 * "\\usepackage[latin2]{inputenc}\n"
-		 * "\\usepackage[T1]{fontenc}\n"
-		 * </pre>
-		 * 
-		 * The English LaTeX does not use such commands.  Because of this
-		 * the empty string is returned in this implementation.
-		 */
-		virtual QCString latexLanguageSupportCommand()
-		{
+    /*! Used to get the LaTeX command(s) for the language support. 
+     * This method should return string with commands that switch
+     * LaTeX to the desired language.  For example 
+     * <pre>"\\usepackage[german]{babel}\n"
+     * </pre>
+     * or
+     * <pre>"\\usepackage{polski}\n"
+     * "\\usepackage[latin2]{inputenc}\n"
+     * "\\usepackage[T1]{fontenc}\n"
+     * </pre>
+     * 
+     * The English LaTeX does not use such commands.  Because of this
+     * the empty string is returned in this implementation.
+     */
+    virtual QCString latexLanguageSupportCommand()
+    {
       return "";
-		}
+    }
 
 
 		/*! return the language charset. This will be used for the HTML output */
@@ -495,8 +495,8 @@ class TranslatorChinese : public TranslatorAdapter_1_2_13
         case ClassDef::Struct: result+="ṹ"; break;
         case ClassDef::Union:  result+=""; break;
         case ClassDef::Interface:  result+="ӿ"; break;
-        case ClassDef::Protocol:   result+="protocol"; break; // translate me!
-        case ClassDef::Category:   result+="category"; break; // translate me!
+        case ClassDef::Protocol:   result+="Э"; break; // translate me!
+        case ClassDef::Category:   result+=""; break; // translate me!
         case ClassDef::Exception:  result+="쳣"; break;
       }
       result+="ο";
@@ -661,8 +661,8 @@ class TranslatorChinese : public TranslatorAdapter_1_2_13
         case ClassDef::Struct:     result+="ṹ"; break;
         case ClassDef::Union:      result+=""; break;
         case ClassDef::Interface:  result+="ӿ"; break;
-        case ClassDef::Protocol:   result+="protocol"; break; // translate me!
-        case ClassDef::Category:   result+="category"; break; // translate me!
+        case ClassDef::Protocol:   result+="Э"; break; // translate me!
+        case ClassDef::Category:   result+=""; break; // translate me!
         case ClassDef::Exception:  result+="쳣"; break;
       }
       result+="ĵļɣ";
@@ -1282,6 +1282,270 @@ class TranslatorChinese : public TranslatorAdapter_1_2_13
     {
       return "ο";
     }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.2.13
+//////////////////////////////////////////////////////////////////////////
+
+    /*! used in member documentation blocks to produce a list of 
+     *  members that are implemented by this one.
+     */
+    virtual QCString trImplementedFromList(int numEntries)
+    {
+      /* return "Implements "+trWriteList(numEntries)+"."; */
+      return "ʵ"CN_SPC+trWriteList(numEntries)+"";
+    }
+
+    /*! used in member documentation blocks to produce a list of
+     *  all members that implement this abstract member.
+     */
+    virtual QCString trImplementedInList(int numEntries)
+    {
+      /* return "Implemented in "+trWriteList(numEntries)+"."; */
+      return ""CN_SPC+trWriteList(numEntries)+CN_SPC"ڱʵ֡";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.2.16
+//////////////////////////////////////////////////////////////////////////
+
+    /*! used in RTF documentation as a heading for the Table
+     *  of Contents.
+     */
+    virtual QCString trRTFTableOfContents()
+    {
+      /* return "Table of Contents"; */
+      return "Ŀ¼";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.2.17
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used as the header of the list of item that have been 
+     *  flagged deprecated 
+     */
+    virtual QCString trDeprecatedList()
+    {
+/*    return "Deprecated List";  */
+      return "ʱб";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.2.18
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used as a header for declaration section of the events found in 
+     * a C# program
+     */
+    virtual QCString trEvents()
+    {
+      /*      return "Events"; */
+      return "¼";
+    }
+    /*! Header used for the documentation section of a class' events. */
+    virtual QCString trEventDocumentation()
+    {
+      /* return "Event Documentation"; */
+      return "¼ĵ";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used as a heading for a list of Java class types with package scope.
+     */
+    virtual QCString trPackageTypes()
+    { 
+      /* return "Package Types"; */
+      return "ģ";
+    }
+    /*! Used as a heading for a list of Java class functions with package 
+     * scope. 
+     */
+    virtual QCString trPackageMembers()
+    { 
+      /* return "Package Functions"; */
+      return "ģ麯";
+    }
+    /*! Used as a heading for a list of static Java class functions with 
+     *  package scope.
+     */
+    virtual QCString trStaticPackageMembers()
+    { 
+      /* return "Static Package Functions"; */
+      return "̬ģ麯";
+    }
+    /*! Used as a heading for a list of Java class variables with package 
+     * scope.
+     */
+    virtual QCString trPackageAttribs()
+    { 
+      /* return "Package Attributes"; */
+      return "ģ";
+    }
+    /*! Used as a heading for a list of static Java class variables with 
+     * package scope.
+     */
+    virtual QCString trStaticPackageAttribs()
+    { 
+      /* return "Static Package Attributes"; */
+      return "̬ģ";
+    }
+    
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used in the quick index of a class/file/namespace member list page 
+     *  to link to the unfiltered list of all members.
+     */
+    virtual QCString trAll()
+    {
+      /* return "All"; */
+      return "ȫ";
+    }
+    /*! Put in front of the call graph for a function. */
+    virtual QCString trCallGraph()
+    {
+      /* return "Here is the call graph for this function:"; */
+      return "ͼ:";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.3
+//////////////////////////////////////////////////////////////////////////
+
+    /*! When the search engine is enabled this text is put in the header 
+     *  of each page before the field where one can enter the text to search 
+     *  for. 
+     */
+    virtual QCString trSearchForIndex()
+    {
+      /* return "Search for"; */
+      return "";
+    }
+    /*! This string is used as the title for the page listing the search
+     *  results.
+     */
+    virtual QCString trSearchResultsTitle()
+    {
+      /* return "Search Results"; */
+      return "";
+    }
+    /*! This string is put just before listing the search results. The
+     *  text can be different depending on the number of documents found.
+     *  Inside the text you can put the special marker $num to insert
+     *  the number representing the actual number of search results.
+     *  The @a numDocuments parameter can be either 0, 1 or 2, where the 
+     *  value 2 represents 2 or more matches. HTML markup is allowed inside
+     *  the returned string.
+     */
+    virtual QCString trSearchResults(int numDocuments)
+    {
+      if (numDocuments==0)
+      {
+        /* return "Sorry, no documents matching your query."; */
+        return "ԲҲĲѯĵ";
+      }
+      else if (numDocuments==1)
+      {
+        /* return "Found <b>1</b> document matching your query."; */
+        return "ҵ<b>1</b>ƪĲѯĵ";
+      }
+      else 
+      {
+        /* return "Found <b>$num</b> documents matching your query. "
+               "Showing best matches first."; */
+        return "ҵ<b>$num</b>ƪĲѯĵ"
+               "ʾǺϵĵ";
+      }
+    }
+    /*! This string is put before the list of matched words, for each search 
+     *  result. What follows is the list of words that matched the query.
+     */
+    virtual QCString trSearchMatches()
+    {
+      /* return "Matches:"; */
+      return "ϵĽ:";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.8
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used in HTML as the title of page with source code for file filename
+     */
+    virtual QCString trSourceFile(QCString& filename)
+    {
+      /* return filename + " Source File"; */
+      return filename + CN_SPC"Դļ";
+    }
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.9
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used as the name of the chapter containing the directory
+     *  hierarchy.
+     */
+    virtual QCString trDirIndex()
+    /*     { return "Directory Hierarchy"; } */
+    {
+      return "$(BL\\¼$(DC((B";
+    }
+
+    /*! This is used as the name of the chapter containing the documentation
+     *  of the directories.
+     */
+    virtual QCString trDirDocumentation()
+    /*     { return "Directory Documentation"; } */
+    {
+      return "$(BL\\¼J8[c(B";
+    }
+
+    /*! This is used as the title of the directory index and also in the
+     *  Quick links of a HTML page, to link to the directory hierarchy.
+     */
+    virtual QCString trDirectories()
+    /*     { return "Directories"; } */
+    {
+      return "$(BL\\¼(B";
+    }
+
+    /*! This returns a sentences that introduces the directory hierarchy. 
+     *  and the fact that it is sorted alphabetically per level
+     */
+    virtual QCString trDirDescription()
+/*     { return "This directory hierarchy is sorted roughly, " */
+/*              "but not completely, alphabetically:"; */
+/*     } */
+    {
+      return "$(BL\\¼$(DC($(BBgCWE*GSNs!$VuL$40A40D;zJl˳=x(B";
+    }
+
+    /*! This returns the title of a directory page. The name of the
+     *  directory is passed via \a dirName.
+     */
+    virtual QCString trDirReference(const char *dirName)
+    /*     { QCString result=dirName; result+=" Directory Reference"; return result; } */
+    {
+      QCString result=dirName;
+      result+=CN_SPC"$(BL\\¼;29M(B"; 
+      return result;
+    }
+
+    /*! This returns the word directory with or without starting capital
+     *  (\a first_capital) and in sigular or plural form (\a singular).
+     */
+    virtual QCString trDir(bool, bool)
+    { 
+      /*       QCString result((first_capital ? "Director" : "director")); */
+      /*       if (singular) result+="y"; else result+="ies"; */
+      /*       return result;  */
+      return "$(BL\\¼(B";
+    }
+    
 };
 
 #endif
