@@ -14,7 +14,7 @@
  * input used in their production; they are not affected by this license.
  *
 */
-// translation by Boris Bralo <boris.bralo@zg.tel.hr>
+// translation by Boris Bralo <boris.bralo@zg.htnet.hr>
 // Updates:
 // --------
 // 2000/08/20 
@@ -52,6 +52,12 @@
 //
 // 2003/04/29
 // - Added strings for 1.3.0
+//
+// 2004/06/21
+// - Added strings for 1.3.8
+//
+// 2004/09/15
+// - Added strings for 1.3.9
 
 #ifndef TRANSLATOR_HR_H
 #define TRANSLATOR_HR_H
@@ -1212,6 +1218,62 @@ class TranslatorCroatian : public Translator
 		return decode("Pronaeno:");
 	}
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.8
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used in HTML as the title of page with source code for file filename
+     */
+    virtual QCString trSourceFile(QCString& filename)
+    {
+      return "Izvorni kod datoteke " + filename;
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.9
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used as the name of the chapter containing the directory
+     *  hierarchy.
+     */
+    virtual QCString trDirIndex()
+    { return "Stablo direktorija"; }
+
+    /*! This is used as the name of the chapter containing the documentation
+     *  of the directories.
+     */
+    virtual QCString trDirDocumentation()
+    { return "Dokumentacija direktorija"; }
+
+    /*! This is used as the title of the directory index and also in the
+     *  Quick links of a HTML page, to link to the directory hierarchy.
+     */
+    virtual QCString trDirectories()
+    { return "Direktoriji"; }
+
+    /*! This returns a sentences that introduces the directory hierarchy. 
+     *  and the fact that it is sorted alphabetically per level
+     */
+    virtual QCString trDirDescription()
+    { return "Stablo direktorija sortirano abecednim redom:"; }
+
+    /*! This returns the title of a directory page. The name of the
+     *  directory is passed via \a dirName.
+     */
+    virtual QCString trDirReference(const char *dirName)
+    { QCString result= "Opis direktorija "; result += dirName; return result; }
+
+    /*! This returns the word directory with or without starting capital
+     *  (\a first_capital) and in sigular or plural form (\a singular).
+     */
+    virtual QCString trDir(bool first_capital, bool singular)
+    { 
+      QCString result((first_capital ? "Direktorij" : "direktorij"));
+      if (!singular) result+="i"; 
+      return result; 
+    }
 };
 
 #endif
+
+
