@@ -29,9 +29,6 @@
 #ifndef TRANSLATOR_HU_H
 #define TRANSLATOR_HU_H
 
-#include "translator.h"
-#include "../qtools/qdatetime.h"
-
 class TranslatorHungarian : public Translator
 {
   private:
@@ -1518,6 +1515,63 @@ class TranslatorHungarian : public Translator
       return "Tallatok:";
     }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.8
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used in HTML as the title of page with source code for file filename
+     */
+    virtual QCString trSourceFile(QCString& filename)
+    {
+      return filename + " Forrsfjl";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.9
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used as the name of the chapter containing the directory
+     *  hierarchy.
+     */
+    virtual QCString trDirIndex()
+    { return "Knyvtrhierarchia"; }
+
+    /*! This is used as the name of the chapter containing the documentation
+     *  of the directories.
+     */
+    virtual QCString trDirDocumentation()
+    { return "Knyvtrak dokumentcija"; }
+
+    /*! This is used as the title of the directory index and also in the
+     *  Quick links of a HTML page, to link to the directory hierarchy.
+     */
+    virtual QCString trDirectories()
+    { return "Knyvtrak"; }
+
+    /*! This returns a sentences that introduces the directory hierarchy. 
+     *  and the fact that it is sorted alphabetically per level
+     */
+    virtual QCString trDirDescription()
+    { return "Majdnem (de nem teljesen) betrendbe szedett "
+             "knyvtrhierarchia:";
+    }
+
+    /*! This returns the title of a directory page. The name of the
+     *  directory is passed via \a dirName.
+     */
+    virtual QCString trDirReference(const char *dirName)
+    { QCString result=dirName; result+=" knyvtrreferencia"; return result; }
+
+    /*! This returns the word directory with or without starting capital
+     *  (\a first_capital) and in sigular or plural form (\a singular).
+     */
+    virtual QCString trDir(bool first_capital, bool /*singular*/)
+    { 
+      QCString result((first_capital ? "Knyvtr" : "knyvtr"));
+      //if (singular) result+="y"; else result+="ies";
+      return result; 
+    }
+
 };
 
 #endif
