@@ -29,7 +29,7 @@
 #ifndef TRANSLATOR_JP_H
 #define TRANSLATOR_JP_H
 
-class TranslatorJapanese : public TranslatorAdapter_1_3_3
+class TranslatorJapanese : public TranslatorAdapter_1_3_9
 {
  private:
   /*! The decode() can change euc into sjis */
@@ -600,13 +600,13 @@ class TranslatorJapanese : public TranslatorAdapter_1_3_3
         case ClassDef::Class:      result+=decode("饹 "); break;
         case ClassDef::Struct:     result+=decode("¤ "); break;
         case ClassDef::Union:      result+=decode(" "); break;
-        case ClassDef::Interface:  result+=decode("󥿥ե"); break;
-        case ClassDef::Protocol:   result+=decode("Protocol"); break; // translate me!
-        case ClassDef::Category:   result+=decode("Category"); break; // translate me!
-        case ClassDef::Exception:  result+=decode("㳰"); break; //TODO:fixme
+        case ClassDef::Interface:  result+=decode("󥿥ե "); break;
+        case ClassDef::Protocol:   result+=decode("ץȥ "); break;
+        case ClassDef::Category:   result+=decode("ƥ "); break;
+        case ClassDef::Exception:  result+=decode("㳰 "); break;
       }
-      if (isTemplate) result+=decode(" ƥץ졼");
-		result+=(QCString)clName;
+      if (isTemplate) result+=decode("ƥץ졼 ");
+      result+=(QCString)clName;
       return result;
     }
 
@@ -759,9 +759,9 @@ class TranslatorJapanese : public TranslatorAdapter_1_3_3
         case ClassDef::Struct:     result+=decode("¤"); break;
         case ClassDef::Union:      result+=decode(""); break;
         case ClassDef::Interface:  result+=decode("󥿥ե"); break;
-        case ClassDef::Protocol:   result+=decode("Protocol"); break; // translate me!
-        case ClassDef::Category:   result+=decode("Category"); break; // translate me!
-        case ClassDef::Exception:  result+=decode("㳰"); break; //TODO:fixme
+        case ClassDef::Protocol:   result+=decode("ץȥ"); break;
+        case ClassDef::Category:   result+=decode("ƥ"); break;
+        case ClassDef::Exception:  result+=decode("㳰"); break;
       }
       result+=decode("ϼΥե뤫ޤ:");
       return result;
@@ -1341,7 +1341,7 @@ class TranslatorJapanese : public TranslatorAdapter_1_3_3
      */
     virtual QCString trImplementedFromList(int numEntries)
     {
-      return trWriteList(numEntries)+decode("˼Ƥޤ")+".";
+      return trWriteList(numEntries)+decode("Ƥޤ")+".";
     }
 
     /*! used in member documentation blocks to produce a list of
@@ -1349,7 +1349,7 @@ class TranslatorJapanese : public TranslatorAdapter_1_3_3
      */
     virtual QCString trImplementedInList(int numEntries)
     {
-      return trWriteList(numEntries)+decode("Ƥޤ")+".";
+      return trWriteList(numEntries)+decode("ǼƤޤ")+".";
     }
 //////////////////////////////////////////////////////////////////////////
 // new since 1.2.16
@@ -1447,5 +1447,67 @@ class TranslatorJapanese : public TranslatorAdapter_1_3_3
     {
       return decode("ؿθƤӽФ:");
     }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.3
+//////////////////////////////////////////////////////////////////////////
+
+    /*! When the search engine is enabled this text is put in the header 
+     *  of each page before the field where one can enter the text to search 
+     *  for. 
+     */
+    virtual QCString trSearchForIndex()
+    {
+      return decode("");
+    }
+    /*! This string is used as the title for the page listing the search
+     *  results.
+     */
+    virtual QCString trSearchResultsTitle()
+    {
+      return decode("");
+    }
+    /*! This string is put just before listing the search results. The
+     *  text can be different depending on the number of documents found.
+     *  Inside the text you can put the special marker $num to insert
+     *  the number representing the actual number of search results.
+     *  The @a numDocuments parameter can be either 0, 1 or 2, where the 
+     *  value 2 represents 2 or more matches. HTML markup is allowed inside
+     *  the returned string.
+     */
+    virtual QCString trSearchResults(int numDocuments)
+    {
+      if (numDocuments==0)
+      {
+        return decode("Ϥ줿˥ޥåɥȤޤǤ.");
+      }
+      else if (numDocuments==1)
+      {
+        return decode("Ϥ줿˥ޥåɥȤ <b>1</b> ߤĤޤ.");
+      }
+      else 
+      {
+        return decode("Ϥ줿˥ޥåɥȤ <b>$num</b> ߤĤޤ. "
+                      "ǤפƤΤɽޤ.");
+      }
+    }
+    /*! This string is put before the list of matched words, for each search 
+     *  result. What follows is the list of words that matched the query.
+     */
+    virtual QCString trSearchMatches()
+    {
+      return decode("ޥåñ:");
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.8
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used in HTML as the title of page with source code for file filename
+     */
+    virtual QCString trSourceFile(QCString& filename)
+    {
+      return filename + decode(" ե");
+    }
 };
 #endif
