@@ -1,12 +1,12 @@
 /******************************************************************************
  *
- *
+ * 
  *
  * Copyright (C) 1997-2004 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
- * documentation under the terms of the GNU General Public License is hereby
- * granted. No representations are made about the suitability of this software
+ * documentation under the terms of the GNU General Public License is hereby 
+ * granted. No representations are made about the suitability of this software 
  * for any purpose. It is provided "as is" without express or implied warranty.
  * See the GNU General Public License for more details.
  *
@@ -15,35 +15,83 @@
  *
  */
 
+#ifndef TRANSLATOR_KR_H
+#define TRANSLATOR_KR_H
+
+/*! 
+ When defining a translator class for the new language, follow
+ the description in the documentation.  One of the steps says
+ that you should copy the translator_en.h (this) file to your
+ translator_xx.h new file.  Your new language should use the
+ Translator class as the base class.  This means that you need to
+ implement exactly the same (pure virtual) methods as the
+ TranslatorEnglish does.  Because of this, it is a good idea to
+ start with the copy of TranslatorEnglish and replace the strings
+ one by one.
+
+ It is not necessary to include "translator.h" or
+ "translator_adapter.h" here.  The files are included in the
+ language.cpp correctly.  Not including any of the mentioned
+ files frees the maintainer from thinking about whether the
+ first, the second, or both files should be included or not, and
+ why.  This holds namely for localized translators because their
+ base class is changed occasionaly to adapter classes when the
+ Translator class changes the interface, or back to the
+ Translator class (by the local maintainer) when the localized
+ translator is made up-to-date again.
+*/
+
 /*
   ʱ ۾:  ryk
                 TODO ּ  11/22/01, doxygen  1.2.11  ֽ  ϴ.
   ֱ : Astromaker(http://ngps.net/)
                gpgiki(http://www.gpgstudy.com/gpgiki/)
-*/
+ */
+ 
+//
+//	Update:
+//
+// 2004.12.22 (SooYoung Jung: jung5000@gmail.com)
+//	- LaTex and RTF were not generated correctly.
+// 	  Corrected trRTFansicp and trRTFCharSet.
+// 	  It was wrong.
+// 	- Adapting 1.3.9 and added "new since 1.3.9"
+//	- ؼ ߸ κ ҳ ־ .. 
+//
+ 
 
-
-#ifndef TRANSLATOR_KR_H
-#define TRANSLATOR_KR_H
-
-class TranslatorKorean : public Translator
+class TranslatorKorean : public TranslatorAdapter_1_3_9
 {
+ private:
+  /*! The decode() can change euc into sjis */
+  inline QCString decode(const QCString & sInput)
+  {
+    if (Config_getBool("USE_WINDOWS_ENCODING"))
+    {
+      return JapaneseEucToSjis(sInput);
+    }
+    else
+    {
+      return sInput;
+    }
+  }
+  	
   public:
 
     // --- Language control methods -------------------
-
-    /*! Used for identification of the language. The identification
-     * should not be translated. It should be replaced by the name
+    
+    /*! Used for identification of the language. The identification 
+     * should not be translated. It should be replaced by the name 
      * of the language in English using lower-case characters only
-     * (e.g. "czech", "japanese", "russian", etc.). It should be equal to
+     * (e.g. "czech", "japanese", "russian", etc.). It should be equal to 
      * the identification used in language.cpp.
      */
     virtual QCString idLanguage()
     { return "korean"; }
-
-    /*! Used to get the LaTeX command(s) for the language support.
+    
+    /*! Used to get the LaTeX command(s) for the language support. 
      *  This method should return string with commands that switch
-     *  LaTeX to the desired language.  For example
+     *  LaTeX to the desired language.  For example 
      *  <pre>"\\usepackage[german]{babel}\n"
      *  </pre>
      *  or
@@ -51,7 +99,7 @@ class TranslatorKorean : public Translator
      *  "\\usepackage[latin2]{inputenc}\n"
      *  "\\usepackage[T1]{fontenc}\n"
      *  </pre>
-     *
+     * 
      * The English LaTeX does not use such commands.  Because of this
      * the empty string is returned in this implementation.
      */
@@ -97,7 +145,7 @@ class TranslatorKorean : public Translator
 
     /*! header that is put before the list of member attributes. */
     virtual QCString trMemberDataDocumentation()
-    {
+    { 
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
           return "  ȭ";
@@ -152,7 +200,7 @@ class TranslatorKorean : public Translator
 
     // quick reference sections
 
-    /*! This is put above each page as a link to the list of all groups of
+    /*! This is put above each page as a link to the list of all groups of 
      *  compounds or files (see the \\group command).
      */
     virtual QCString trModules()
@@ -175,7 +223,7 @@ class TranslatorKorean : public Translator
             return "ձ(Ŭ, ü, ü)";
         }
     }
-
+    
     /*! This is put above each page as a link to the list of documented files */
     virtual QCString trFileList()
     { return " "; } //" ", " Ʈ"
@@ -267,6 +315,7 @@ class TranslatorKorean : public Translator
       {
           result+="ũ  Ŭ  ";
       }
+
       if (extractAll)
           result+="   Ŭ ȭ ϴ.";
       else
@@ -316,19 +365,19 @@ class TranslatorKorean : public Translator
     virtual QCString trDocumentation()
     { return "ȭ"; }
 
-    /*! This is used in LaTeX as the title of the chapter with the
+    /*! This is used in LaTeX as the title of the chapter with the 
      * index of all groups.
      */
     virtual QCString trModuleIndex()
     { return " "; }
 
-    /*! This is used in LaTeX as the title of the chapter with the
+    /*! This is used in LaTeX as the title of the chapter with the 
      * class hierarchy.
      */
     virtual QCString trHierarchicalIndex()
     { return "зü "; }
 
-    /*! This is used in LaTeX as the title of the chapter with the
+    /*! This is used in LaTeX as the title of the chapter with the 
      * annotated compound index.
      */
     virtual QCString trCompoundIndex()
@@ -380,37 +429,37 @@ class TranslatorKorean : public Translator
     virtual QCString trDefines()
     { return "ũ, #define"; }
 
-    /*! This is used in the documentation of a file as a header before the
+    /*! This is used in the documentation of a file as a header before the 
      *  list of function prototypes
      */
     virtual QCString trFuncProtos()
     { return "Լ "; }
 
-    /*! This is used in the documentation of a file as a header before the
+    /*! This is used in the documentation of a file as a header before the 
      *  list of typedefs
      */
     virtual QCString trTypedefs()
     { return "Ÿ "; }
 
-    /*! This is used in the documentation of a file as a header before the
+    /*! This is used in the documentation of a file as a header before the 
      *  list of enumerations
      */
     virtual QCString trEnumerations()
     { return ""; }
 
-    /*! This is used in the documentation of a file as a header before the
+    /*! This is used in the documentation of a file as a header before the 
      *  list of (global) functions
      */
     virtual QCString trFunctions()
     { return "Լ"; }
 
-    /*! This is used in the documentation of a file as a header before the
+    /*! This is used in the documentation of a file as a header before the 
      *  list of (global) variables
      */
     virtual QCString trVariables()
     { return ""; }
 
-    /*! This is used in the documentation of a file as a header before the
+    /*! This is used in the documentation of a file as a header before the 
      *  list of (global) variables
      */
     virtual QCString trEnumerationValues()
@@ -422,50 +471,59 @@ class TranslatorKorean : public Translator
     virtual QCString trDefineDocumentation()
     { return "#define ȭ"; }
 
-    /*! This is used in the documentation of a file/namespace before the list
+    /*! This is used in the documentation of a file/namespace before the list 
      *  of documentation blocks for function prototypes
      */
     virtual QCString trFunctionPrototypeDocumentation()
     { return "Լ  ȭ"; }
 
-    /*! This is used in the documentation of a file/namespace before the list
+    /*! This is used in the documentation of a file/namespace before the list 
      *  of documentation blocks for typedefs
      */
     virtual QCString trTypedefDocumentation()
     { return "Ÿ  ȭ"; }
 
-    /*! This is used in the documentation of a file/namespace before the list
+    /*! This is used in the documentation of a file/namespace before the list 
      *  of documentation blocks for enumeration types
      */
     virtual QCString trEnumerationTypeDocumentation()
     { return " Ÿ ȭ"; }
 
-    /*! This is used in the documentation of a file/namespace before the list
+    /*! This is used in the documentation of a file/namespace before the list 
      *  of documentation blocks for enumeration values
      */
     virtual QCString trEnumerationValueDocumentation()
     { return "  ȭ"; }
 
-    /*! This is used in the documentation of a file/namespace before the list
+    /*! This is used in the documentation of a file/namespace before the list 
      *  of documentation blocks for functions
      */
     virtual QCString trFunctionDocumentation()
     { return "Լ ȭ"; }
 
-    /*! This is used in the documentation of a file/namespace before the list
+    /*! This is used in the documentation of a file/namespace before the list 
      *  of documentation blocks for variables
      */
     virtual QCString trVariableDocumentation()
     { return " ȭ"; }
 
-    /*! This is used in the documentation of a file/namespace/group before
+    /*! This is used in the documentation of a file/namespace/group before 
      *  the list of links to documented compounds
      */
     virtual QCString trCompounds()
-    { return "ձ"; }
+    { 
+      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      {
+        return "Data Structures"; 
+      }
+      else
+      {
+        return "Classes"; 
+      }
+    }
 
-    /*! This is used in the standard footer of each page and indicates when
-     *  the page was generated
+    /*! This is used in the standard footer of each page and indicates when 
+     *  the page was generated 
      */
     virtual QCString trGeneratedAt(const char *date,const char *projName)
     {
@@ -486,7 +544,7 @@ class TranslatorKorean : public Translator
     {
       return (QCString)clName+"   ǥ";
     }
-
+    
     /*! this text is generated when the \\internal command is used. */
     virtual QCString trForInternalUseOnly()
     { return " 븸 "; }
@@ -534,7 +592,7 @@ class TranslatorKorean : public Translator
 //////////////////////////////////////////////////////////////////////////
 // new since 0.49-990307
 //////////////////////////////////////////////////////////////////////////
-
+    
     /*! used as the title of page containing all the index of all namespaces. */
     virtual QCString trNamespaceList()
     { return "namespace "; }
@@ -552,14 +610,14 @@ class TranslatorKorean : public Translator
      *  friends of a class
      */
     virtual QCString trFriends()
-    { return "friend"; }
-
+    { return "Friends"; }
+    
 //////////////////////////////////////////////////////////////////////////
 // new since 0.49-990405
 //////////////////////////////////////////////////////////////////////////
-
+    
     /*! used in the class documentation as a header before the list of all
-     * related classes
+     * related classes 
      */
     virtual QCString trRelatedFunctionDocumentation()
     { return "friend, ׸ õ Լ ȭ"; }
@@ -585,6 +643,7 @@ class TranslatorKorean : public Translator
         case ClassDef::Category:   result+=" category"; break; // translate me!
         case ClassDef::Exception:  result+=" "; break;
       }
+      if (isTemplate) result+=" ø";
       result+=" ";
       return result;
     }
@@ -634,23 +693,23 @@ class TranslatorKorean : public Translator
       QCString result;
       int i;
       // the inherits list contain `numEntries' classes
-      for (i=0;i<numEntries;i++)
+      for (i=0;i<numEntries;i++) 
       {
         // use generateMarker to generate placeholders for the class links!
-        result+=generateMarker(i); // generate marker for entry i in the list
+        result+=generateMarker(i); // generate marker for entry i in the list 
                                    // (order is left to right)
-
+        
         if (i!=numEntries-1)  // not the last entry, so we need a separator
         {
-          if (i<numEntries-2) // not the fore last entry
+          if (i<numEntries-2) // not the fore last entry 
             result+=", ";
           else                // the fore last entry
             result+=",  ";
         }
       }
-      return result;
+      return result; 
     }
-
+    
     /*! used in class documentation to produce a list of base classes,
      *  if class diagrams are disabled.
      */
@@ -667,7 +726,7 @@ class TranslatorKorean : public Translator
       return trWriteList(numEntries)+"  ӵǾϴ.";
     }
 
-    /*! used in member documentation blocks to produce a list of
+    /*! used in member documentation blocks to produce a list of 
      *  members that are hidden by this one.
      */
     virtual QCString trReimplementedFromList(int numEntries)
@@ -700,7 +759,7 @@ class TranslatorKorean : public Translator
       result+="ũ ֽϴ.";
       return result;
     }
-    /*! This is used in LaTeX as the title of the chapter with the
+    /*! This is used in LaTeX as the title of the chapter with the 
      *  index of all namespaces.
      */
     virtual QCString trNamespaceIndex()
@@ -720,7 +779,7 @@ class TranslatorKorean : public Translator
      *  namespaces in a file.
      */
     virtual QCString trNamespaces()
-    { return "namespace"; }
+    { return "Namespaces"; }
 
 //////////////////////////////////////////////////////////////////////////
 // new since 0.49-990728
@@ -769,7 +828,7 @@ class TranslatorKorean : public Translator
     virtual QCString trMainPage()
     { return " "; }
 
-    /*! This is used in references to page that are put in the LaTeX
+    /*! This is used in references to page that are put in the LaTeX 
      *  documentation. It should be an abbreviation of the word page.
      */
     virtual QCString trPageAbbreviation()
@@ -875,7 +934,7 @@ class TranslatorKorean : public Translator
 //////////////////////////////////////////////////////////////////////////
 // new since 1.1.0
 //////////////////////////////////////////////////////////////////////////
-
+    
     virtual QCString trNote()
     {
         return "Ʈ";
@@ -965,7 +1024,7 @@ class TranslatorKorean : public Translator
     {
         return "Since"; // TODO: Need to be translated. -ryk11/22/01.
     }
-
+    
 //////////////////////////////////////////////////////////////////////////
 // new since 1.1.5
 //////////////////////////////////////////////////////////////////////////
@@ -975,7 +1034,7 @@ class TranslatorKorean : public Translator
     {
         return "";
     }
-    /*! page explaining how the dot graph's should be interpreted
+    /*! page explaining how the dot graph's should be interpreted 
      *  The %A in the text below are to prevent link to classes called "A".
      */
     virtual QCString trLegendDocs()
@@ -1063,11 +1122,11 @@ class TranslatorKorean : public Translator
     {
         return "";
     }
-
+    
 //////////////////////////////////////////////////////////////////////////
 // new since 1.2.0
 //////////////////////////////////////////////////////////////////////////
-
+    
     /*! Used as a marker that is put before a test item */
     virtual QCString trTest()
     {
@@ -1156,11 +1215,11 @@ class TranslatorKorean : public Translator
     {
         return ":"; // TODO: Need to be translated. -ryk11/22/01.
     }
-
+    
 //////////////////////////////////////////////////////////////////////////
 // new since 1.2.5
 //////////////////////////////////////////////////////////////////////////
-
+    
     /*! Used as a marker that is put before a \\bug item */
     virtual QCString trBug()
     {
@@ -1176,9 +1235,9 @@ class TranslatorKorean : public Translator
 // new since 1.2.6
 //////////////////////////////////////////////////////////////////////////
 
-    /*! Used as ansicpg for RTF file
-     *
-     * The following table shows the correlation of Charset name, Charset Value and
+    /*! Used as ansicpg for RTF file 
+     * 
+     * The following table shows the correlation of Charset name, Charset Value and 
      * <pre>
      * Codepage number:
      * Charset Name       Charset Value(hex)  Codepage number
@@ -1199,20 +1258,20 @@ class TranslatorKorean : public Translator
      * GB2313_CHARSET          134 (x86)             936
      * CHINESEBIG5_CHARSET     136 (x88)             950
      * </pre>
-     *
+     * 
      */
     virtual QCString trRTFansicp()
     {
-        return "1252";
+      return "949";
     }
+    
 
-
-    /*! Used as ansicpg for RTF fcharset
+    /*! Used as ansicpg for RTF fcharset 
      *  \see trRTFansicp() for a table of possible values.
      */
     virtual QCString trRTFCharSet()
     {
-      return "0";
+      return "129";
     }
 
     /*! Used as header RTF general index */
@@ -1220,9 +1279,9 @@ class TranslatorKorean : public Translator
     {
         return "ε"; // TODO: Need to be translated. -ryk11/22/01.
     }
-
+   
     /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names
+     *  be followed by a single name or by a list of names 
      *  of the category.
      */
     virtual QCString trClass(bool first_capital, bool singular)
@@ -1233,7 +1292,7 @@ class TranslatorKorean : public Translator
     }
 
     /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names
+     *  be followed by a single name or by a list of names 
      *  of the category.
      */
     virtual QCString trFile(bool first_capital, bool singular)
@@ -1244,18 +1303,18 @@ class TranslatorKorean : public Translator
     }
 
     /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names
+     *  be followed by a single name or by a list of names 
      *  of the category.
      */
     virtual QCString trNamespace(bool first_capital, bool singular)
-    {
+    { 
       QCString result((first_capital ? "Namespace" : "namespace"));
       if (!singular)  result+="s";
       return result;  // TODO: Need to be translated. -ryk11/22/01.
     }
 
     /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names
+     *  be followed by a single name or by a list of names 
      *  of the category.
      */
     virtual QCString trGroup(bool first_capital, bool singular)
@@ -1266,7 +1325,7 @@ class TranslatorKorean : public Translator
     }
 
     /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names
+     *  be followed by a single name or by a list of names 
      *  of the category.
      */
     virtual QCString trPage(bool first_capital, bool singular)
@@ -1277,7 +1336,7 @@ class TranslatorKorean : public Translator
     }
 
     /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names
+     *  be followed by a single name or by a list of names 
      *  of the category.
      */
     virtual QCString trMember(bool first_capital, bool singular)
@@ -1286,9 +1345,9 @@ class TranslatorKorean : public Translator
       if (!singular)  result+="";
       return result;  // TODO: Need to be translated. -ryk11/22/01.
     }
-
+   
     /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names
+     *  be followed by a single name or by a list of names 
      *  of the category.
      */
     virtual QCString trField(bool first_capital, bool singular)
@@ -1299,11 +1358,11 @@ class TranslatorKorean : public Translator
     }
 
     /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names
+     *  be followed by a single name or by a list of names 
      *  of the category.
      */
     virtual QCString trGlobal(bool first_capital, bool singular)
-    {
+    { 
       QCString result((first_capital ? "Global" : "global"));
       if (!singular)  result+="s";
       return result;  // TODO: Need to be translated. -ryk11/22/01.
@@ -1337,7 +1396,7 @@ class TranslatorKorean : public Translator
 // new since 1.2.13
 //////////////////////////////////////////////////////////////////////////
 
-    /*! used in member documentation blocks to produce a list of
+    /*! used in member documentation blocks to produce a list of 
      *  members that are implemented by this one.
      */
     virtual QCString trImplementedFromList(int numEntries)
@@ -1371,8 +1430,8 @@ class TranslatorKorean : public Translator
 // new since 1.2.17
 //////////////////////////////////////////////////////////////////////////
 
-    /*! Used as the header of the list of item that have been
-     *  flagged deprecated
+    /*! Used as the header of the list of item that have been 
+     *  flagged deprecated 
      */
     virtual QCString trDeprecatedList()
     {
@@ -1383,7 +1442,7 @@ class TranslatorKorean : public Translator
 // new since 1.2.18
 //////////////////////////////////////////////////////////////////////////
 
-    /*! Used as a header for declaration section of the events found in
+    /*! Used as a header for declaration section of the events found in 
      * a C# program
      */
     virtual QCString trEvents()
@@ -1401,50 +1460,50 @@ class TranslatorKorean : public Translator
 //////////////////////////////////////////////////////////////////////////
 
     /*! Used as a heading for a list of Java class types with package scope.
-    */
+     */
     virtual QCString trPackageTypes()
     {
         return "Ű ŸԵ"; //"Package Types";
     }
-    /*! Used as a heading for a list of Java class functions with package
-    * scope.
-    */
+    /*! Used as a heading for a list of Java class functions with package 
+     * scope. 
+     */
     virtual QCString trPackageMembers()
     {
         return "Ű Լ"; //"Package Functions";
     }
-    /*! Used as a heading for a list of static Java class functions with
-    *  package scope.
-    */
+    /*! Used as a heading for a list of static Java class functions with 
+     *  package scope.
+     */
     virtual QCString trStaticPackageMembers()
     {
         return " Ű Լ"; //"Static Package Functions";
     }
-    /*! Used as a heading for a list of Java class variables with package
-    * scope.
-    */
+    /*! Used as a heading for a list of Java class variables with package 
+     * scope.
+     */
     virtual QCString trPackageAttribs()
     {
         return "Ű Ӽ"; //"Package Attributes";
     }
-    /*! Used as a heading for a list of static Java class variables with
-    * package scope.
-    */
+    /*! Used as a heading for a list of static Java class variables with 
+     * package scope.
+     */
     virtual QCString trStaticPackageAttribs()
     {
         return " Ű Ӽ"; //"Static Package Attributes";
     }
-
+    
 //////////////////////////////////////////////////////////////////////////
 // new since 1.3.1
 //////////////////////////////////////////////////////////////////////////
 
-    /*! Used in the quick index of a class/file/namespace member list page
-    *  to link to the unfiltered list of all members.
-    */
+    /*! Used in the quick index of a class/file/namespace member list page 
+     *  to link to the unfiltered list of all members.
+     */
     virtual QCString trAll()
     {
-        return "All";
+        return "";
     }
     /*! Put in front of the call graph for a function. */
     virtual QCString trCallGraph()
@@ -1452,33 +1511,34 @@ class TranslatorKorean : public Translator
         return "  Լ  ȣ ׷Դϴ:";
         //"Here is the call graph for this function:";
     }
+
 //////////////////////////////////////////////////////////////////////////
 // new since 1.3.3
 //////////////////////////////////////////////////////////////////////////
 
-    /*! When the search engine is enabled this text is put in the header
-    *  of each page before the field where one can enter the text to search
-    *  for.
-    */
+    /*! When the search engine is enabled this text is put in the header 
+     *  of each page before the field where one can enter the text to search 
+     *  for. 
+     */
     virtual QCString trSearchForIndex()
     {
         return "˻: "; //"Search for";
     }
     /*! This string is used as the title for the page listing the search
-    *  results.
-    */
+     *  results.
+     */
     virtual QCString trSearchResultsTitle()
     {
         return "˻ ";//"Search Results";
     }
     /*! This string is put just before listing the search results. The
-    *  text can be different depending on the number of documents found.
-    *  Inside the text you can put the special marker $num to insert
-    *  the number representing the actual number of search results.
-    *  The @a numDocuments parameter can be either 0, 1 or 2, where the
-    *  value 2 represents 2 or more matches. HTML markup is allowed inside
-    *  the returned string.
-    */
+     *  text can be different depending on the number of documents found.
+     *  Inside the text you can put the special marker $num to insert
+     *  the number representing the actual number of search results.
+     *  The @a numDocuments parameter can be either 0, 1 or 2, where the 
+     *  value 2 represents 2 or more matches. HTML markup is allowed inside
+     *  the returned string.
+     */
     virtual QCString trSearchResults(int numDocuments)
     {
         if (numDocuments==0)
@@ -1499,13 +1559,74 @@ class TranslatorKorean : public Translator
                 "ó    ġϴ Դϴ.";
         }
     }
-    /*! This string is put before the list of matched words, for each search
-    *  result. What follows is the list of words that matched the query.
-    */
+    /*! This string is put before the list of matched words, for each search 
+     *  result. What follows is the list of words that matched the query.
+     */
     virtual QCString trSearchMatches()
     {
-        return "Matches:";
+      return ":";
     }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.8
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used in HTML as the title of page with source code for file filename
+     */
+    virtual QCString trSourceFile(QCString& filename)
+    {
+      return filename + " ҽ ";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.9
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used as the name of the chapter containing the directory
+     *  hierarchy.
+     */
+    virtual QCString trDirIndex()
+    { return "丮 "; }
+
+    /*! This is used as the name of the chapter containing the documentation
+     *  of the directories.
+     */
+    virtual QCString trDirDocumentation()
+    { return "丮 "; }
+
+    /*! This is used as the title of the directory index and also in the
+     *  Quick links of a HTML page, to link to the directory hierarchy.
+     */
+    virtual QCString trDirectories()
+    { return "丮"; }
+
+    /*! This returns a sentences that introduces the directory hierarchy. 
+     *  and the fact that it is sorted alphabetically per level
+     */
+    virtual QCString trDirDescription()
+    { return " 丮  ĺ  ĵǾֽϴ. ( )";
+             
+             
+    }
+
+    /*! This returns the title of a directory page. The name of the
+     *  directory is passed via \a dirName.
+     */
+    virtual QCString trDirReference(const char *dirName)
+    { QCString result=dirName; result+=" 丮 "; return result; }
+
+    /*! This returns the word directory with or without starting capital
+     *  (\a first_capital) and in sigular or plural form (\a singular).
+     */
+    virtual QCString trDir(bool /*first_capital*/, bool /*singular*/)
+    { 
+      // QCString result((first_capital ? "Director" : "director"));
+      // if (singular) result+="y"; else result+="ies";
+      
+      // return result; 
+      return "";
+    }
+
 };
 
 #endif
