@@ -2,7 +2,7 @@
  *
  * $Id: translator_pt.h,v 1.2 2001/03/19 19:27:42 root Exp $
  *
- * Copyright (C) 1997-2002 by Dimitri van Heesch.
+ * Copyright (C) 1997-2004 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -19,6 +19,8 @@
  *
  * VERSION HISTORY
  * ---------------
+ * 007 09 june 2003
+ *   ! Updated for doxygen v1.3.1
  * 006 30 july 2002
  *   ! Updated for doxygen v1.2.17
  * 005 10 july 2002
@@ -38,7 +40,7 @@
 #ifndef TRANSLATOR_PT_H
 #define TRANSLATOR_PT_H
 
-class TranslatorPortuguese : public Translator
+class TranslatorPortuguese : public TranslatorAdapter_1_3_3
 {
   public:
 
@@ -127,7 +129,7 @@ class TranslatorPortuguese : public Translator
 
     /*! this is the first part of a sentence that is followed by a class name */
     QCString trThisIsTheListOfAllMembers()
-    { return "Esta  a lista completa dos membros de "; }
+    { return "Lista completa de todos os membros de "; }
 
     /*! this is the remainder of the sentence after the class name */
     QCString trIncludingInheritedMembers()
@@ -158,7 +160,7 @@ class TranslatorPortuguese : public Translator
     // quick reference sections
 
     /*! This is put above each page as a link to the list of all groups of
-     *  compounds or files (see the \group command).
+     *  compounds or files (see the \\group command).
      */
     QCString trModules()
     { return "Mdulos"; }
@@ -268,8 +270,8 @@ class TranslatorPortuguese : public Translator
       {
         result+=" documentadas";
       }
-      result+=" com links para ";
-      if (extractAll) 
+      result+=" com referncia para ";
+      if (!extractAll) 
       {
         if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
         {
@@ -297,20 +299,20 @@ class TranslatorPortuguese : public Translator
     /*! This is an introduction to the page with all file members. */
     QCString trFileMembersDescription(bool extractAll)
     {
-      QCString result="Lista de todas as ";
+      QCString result="Lista de ";
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
-        result+="funes, variveis, definies, enumeraes e definies de tipo ";
+        result+="todas as funes, variveis, definies, enumeraes e definies de tipo ";
         if (!extractAll) result+="documentadas ";
       }
       else
       {
-        result+="ficheiros membro";
+        result+="todos os ficheiros membro ";
         if (!extractAll) result+="documentados ";
       }
-      result+="com links para ";
+      result+="com referncia para ";
       if (extractAll) 
-        result+="os ficheiro a que pertecem:";
+        result+="o ficheiro a que pertecem:";
       else 
         result+="a respectiva documentao:";
       return result;
@@ -416,7 +418,7 @@ class TranslatorPortuguese : public Translator
      *  list of defines
      */
     QCString trDefines()
-    { return "Definio de macros"; }
+    { return "Macros"; }
 
     /*! This is used in the documentation of a file as a header before the
      *  list of function prototypes
@@ -628,6 +630,8 @@ class TranslatorPortuguese : public Translator
         case ClassDef::Struct:     result+=" estrutura "; break;
         case ClassDef::Union:      result+=" unio "; break;
         case ClassDef::Interface:  result+="ao interface "; break;
+        case ClassDef::Protocol:   result+="protocol "; break; // translate me!
+        case ClassDef::Category:   result+="category "; break; // translate me!
         case ClassDef::Exception:  result+=" excepo "; break;
       }
       if (isTemplate) result+="Template ";
@@ -740,7 +744,7 @@ class TranslatorPortuguese : public Translator
       QCString result="Lista ";
       if (extractAll) result+="de todos os ";
       else result+="de toda a documentao dos ";
-      result+="membros do namespace com links para ";
+      result+="membros do namespace com referncia para ";
       if (extractAll)
         result+="a documentao de cada membro:";
       else
@@ -788,6 +792,8 @@ class TranslatorPortuguese : public Translator
         case ClassDef::Struct:     result+="esta estrutura"; break;
         case ClassDef::Union:      result+="esta unio"; break;
         case ClassDef::Interface:  result+="este interface"; break;
+        case ClassDef::Protocol:   result+="protocol"; break; // translate me!
+        case ClassDef::Category:   result+="category"; break; // translate me!
         case ClassDef::Exception:  result+="esta excepo"; break;
       }
       result+=" foi gerada a partir ";
@@ -1396,6 +1402,79 @@ class TranslatorPortuguese : public Translator
       return "Lista de Deprecados";
     }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.2.18
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used as a header for declaration section of the events found in 
+     * a C# program
+     */
+    virtual QCString trEvents()
+    {
+      return "Eventos";
+    }
+    /*! Header used for the documentation section of a class' events. */
+    virtual QCString trEventDocumentation()
+    {
+      return "Documentao dos eventos";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used as a heading for a list of Java class types with package scope.
+     */
+    virtual QCString trPackageTypes()
+    { 
+      return "Tipos do Pacote";
+    }
+    /*! Used as a heading for a list of Java class functions with package 
+     * scope. 
+     */
+    virtual QCString trPackageMembers()
+    { 
+      return "Funes do Pacote";
+    }
+    /*! Used as a heading for a list of static Java class functions with 
+     *  package scope.
+     */
+    virtual QCString trStaticPackageMembers()
+    { 
+      return "Funes Estticas do Pacote";
+    }
+    /*! Used as a heading for a list of Java class variables with package 
+     * scope.
+     */
+    virtual QCString trPackageAttribs()
+    { 
+      return "Atributos do Pacote";
+    }
+    /*! Used as a heading for a list of static Java class variables with 
+     * package scope.
+     */
+    virtual QCString trStaticPackageAttribs()
+    { 
+      return "Atributos Estticos do Pacote";
+    }
+    
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used in the quick index of a class/file/namespace member list page 
+     *  to link to the unfiltered list of all members.
+     */
+    virtual QCString trAll()
+    {
+      return "Tudo";
+    }
+    /*! Put in front of the call graph for a function. */
+    virtual QCString trCallGraph()
+    {
+      return "Grafo de chamadas desta funo:";
+    }
+
 };
 
 #endif
