@@ -18,7 +18,7 @@
  *
  * Nickolay Semyonov
  * Andrey V. Stolyarov released Feb 14, 2001
- * Alexandr V. Chelpanov <cav@cryptopro.ru> released Sep 16, 2003
+ * Alexandr V. Chelpanov <cav@cryptopro.ru> released Sep 25, 2004
  *
  *     list  documentation .
  *
@@ -42,7 +42,8 @@
  *
  *   ??  .
  *
- * : Vitaly A. Repin <vitaly@radio.hop.stu.neva.ru>
+ * : Vitaly A. Repin <vitaly@radio.hop.stu.neva.ru>,
+ *      <bbman@mail.ru>
  */
 
 #ifndef TRANSLATOR_RU_H
@@ -236,7 +237,7 @@ class TranslatorRussian : public Translator
     /*??*/
     virtual QCString trFileMembers()
     {
-      return decode( " " );
+      return decode( "   " );
     }
 
     /*! This is put above each page as a link to all related pages. */
@@ -638,7 +639,7 @@ class TranslatorRussian : public Translator
      * related classes 
      */
     virtual QCString trRelatedFunctionDocumentation()
-    { return decode("      "
+    { return decode("     , "
         "  "); }
     
 //////////////////////////////////////////////////////////////////////////
@@ -1128,10 +1129,10 @@ class TranslatorRussian : public Translator
         "</ul>\n"
         "   :\n"
         "<ul>\n"
-        "<li>        "
+        "<li>-        "
         "  .\n"
-        "<li>     .\n"
-        "<li>     .\n"
+        "<li>-     .\n"
+        "<li>-     .\n"
         "<li>  ,    "
         "     ."
         "   , "
@@ -1545,13 +1546,12 @@ class TranslatorRussian : public Translator
       }
       else if( numDocuments == 1 )
       {
-        return decode( " <b>$num</b> " ) + as_documents( numDocuments )
-          + ".";
+        return decode( " 1 ." );
       }
       else 
       {
-        return decode( " <b>$num</b> " ) + as_documents( numDocuments )
-          + decode( ".    ." );
+        return decode( "() <b>$num</b> (). "
+          "   ." );
       }
     }
     /*! This string is put before the list of matched words, for each search 
@@ -1562,12 +1562,59 @@ class TranslatorRussian : public Translator
       return decode( ":" );
     }
 
-private:
-    QCString as_documents( int num )
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.8
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used in HTML as the title of page with source code for file filename
+     */
+    virtual QCString trSourceFile(QCString& filename)
     {
-      if( num % 10 == 1 ) return "";
-      if( (num % 10) >= 2 && (num % 10) <= 4 ) return decode( "" );
-      return decode( "" );
+      return decode( "  " + filename );
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.9
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used as the name of the chapter containing the directory
+     *  hierarchy.
+     */
+    virtual QCString trDirIndex()
+    { return decode( " " ); }
+
+    /*! This is used as the name of the chapter containing the documentation
+     *  of the directories.
+     */
+    virtual QCString trDirDocumentation()
+    { return decode( "" ); }
+
+    /*! This is used as the title of the directory index and also in the
+     *  Quick links of a HTML page, to link to the directory hierarchy.
+     */
+    virtual QCString trDirectories()
+    { return decode( "  " ); }
+
+    /*! This returns a sentences that introduces the directory hierarchy. 
+     *  and the fact that it is sorted alphabetically per level
+     */
+    virtual QCString trDirDescription()
+    { return decode( " " ); }
+
+    /*! This returns the title of a directory page. The name of the
+     *  directory is passed via \a dirName.
+     */
+    virtual QCString trDirReference(const char *dirName)
+    { QCString result=QCString("  ")+ dirName; return decode( result ); }
+
+    /*! This returns the word directory with or without starting capital
+     *  (\a first_capital) and in sigular or plural form (\a singular).
+     */
+    virtual QCString trDir(bool first_capital, bool singular)
+    { 
+      QCString result((first_capital ? "" : ""));
+      if (singular) result+=""; else result+="";
+      return decode( result ); 
     }
 };
 
