@@ -2,7 +2,7 @@
  *
  * $Id: translator_si.h,v 1.1 2000/07/22 17:04:41 root Exp $
  *
- * Copyright (C) 1997-2000 by Dimitri van Heesch.
+ * Copyright (C) 1997-2004 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -274,6 +274,8 @@ class TranslatorSlovene : public TranslatorAdapter_1_2_16
         case ClassDef::Struct: result+=" Struktura "; break;
         case ClassDef::Union:  result+=" Mnoica "; break;
         case ClassDef::Interface:  result+=" IDL vmesnik "; break;
+        case ClassDef::Protocol:   result+=" protocol "; break; // translate me!
+        case ClassDef::Category:   result+=" category "; break; // translate me!
         case ClassDef::Exception:  result+=" IDL prekinitev "; break;
       }
 	  result += (QCString)clName;
@@ -420,6 +422,8 @@ class TranslatorSlovene : public TranslatorAdapter_1_2_16
         case ClassDef::Struct:     result+="strukture"; break;
         case ClassDef::Union:      result+="unije"; break;
         case ClassDef::Interface:  result+="vmesnika (interface)"; break;
+        case ClassDef::Protocol:   result+="protocol"; break; // translate me!
+        case ClassDef::Category:   result+="category"; break; // translate me!
         case ClassDef::Exception:  result+="prekinitve (exception)"; break;
       }
       result+=" je zgrajen na podlagi naslednj";
