@@ -104,6 +104,7 @@ bool getDefs(const QCString &scopeName,
                     bool checkCV=FALSE
                    );
 
+QCString getFileFilter(const char* name);
 
 bool resolveRef(/* in */  const char *scName,
                 /* in */  const char *name,
@@ -132,6 +133,10 @@ bool matchArguments(ArgumentList *,ArgumentList *,
                            const char *cl=0,const char *ns=0,bool checkCV=TRUE,
                            NamespaceSDict *usingNamespaces=0,
                            SDict<Definition> *usingClasses=0);
+bool matchArguments2(Definition *srcScope,FileDef *srcFileScope,ArgumentList *srcAl,
+                     Definition *dstScope,FileDef *dstFileScope,ArgumentList *dstAl,
+                     bool checkCV
+                    );
 void mergeArguments(ArgumentList *,ArgumentList *,bool forceNameOverwrite=FALSE);
 QCString substituteClassNames(const QCString &s);
 QCString substitute(const char *s,const char *src,const char *dst);
@@ -189,7 +194,8 @@ QCString substituteTemplateArgumentsInString(
 ArgumentList *copyArgumentList(const ArgumentList *src);
 QList<ArgumentList> *copyArgumentLists(const QList<ArgumentList> *srcLists);
 QCString stripTemplateSpecifiersFromScope(const QCString &fullName,
-                                          bool parentOnly=TRUE);
+                                          bool parentOnly=TRUE,
+                                          QCString *lastScopeStripped=0);
 QCString resolveTypeDef(Definition *d,const QCString &name,
                         Definition **typedefContext=0);
 QCString mergeScopes(const QCString &leftScope,const QCString &rightScope);
