@@ -125,25 +125,25 @@ void XmlDocVisitor::visit(DocStyleChange *s)
   switch (s->style())
   {
     case DocStyleChange::Bold:
-      if (s->enable()) m_t << "<bold>";      else m_t << "</bold> ";
+      if (s->enable()) m_t << "<bold>";      else m_t << "</bold>";
       break;
     case DocStyleChange::Italic:
-      if (s->enable()) m_t << "<emphasis>";     else m_t << "</emphasis> ";
+      if (s->enable()) m_t << "<emphasis>";     else m_t << "</emphasis>";
       break;
     case DocStyleChange::Code:
-      if (s->enable()) m_t << "<computeroutput>";   else m_t << "</computeroutput> ";
+      if (s->enable()) m_t << "<computeroutput>";   else m_t << "</computeroutput>";
       break;
     case DocStyleChange::Subscript:
-      if (s->enable()) m_t << "<subscript>";    else m_t << "</subscript> ";
+      if (s->enable()) m_t << "<subscript>";    else m_t << "</subscript>";
       break;
     case DocStyleChange::Superscript:
-      if (s->enable()) m_t << "<superscript>";    else m_t << "</superscript> ";
+      if (s->enable()) m_t << "<superscript>";    else m_t << "</superscript>";
       break;
     case DocStyleChange::Center:
-      if (s->enable()) m_t << "<center>"; else m_t << "</center> ";
+      if (s->enable()) m_t << "<center>"; else m_t << "</center>";
       break;
     case DocStyleChange::Small:
-      if (s->enable()) m_t << "<small>";  else m_t << "</small> ";
+      if (s->enable()) m_t << "<small>";  else m_t << "</small>";
       break;
     case DocStyleChange::Preformatted:
       if (s->enable()) 
@@ -153,7 +153,7 @@ void XmlDocVisitor::visit(DocStyleChange *s)
       }
       else 
       {
-        m_t << "</preformatted> ";
+        m_t << "</preformatted>";
         m_insidePre=FALSE;
       }
       break;
@@ -711,17 +711,17 @@ void XmlDocVisitor::visitPost(DocSecRefList *)
   m_t << "</toclist>" << endl;
 }
 
-void XmlDocVisitor::visitPre(DocLanguage *l)
-{
-  if (m_hide) return;
-  m_t << "<language langid=\"" << l->id() << "\">";
-}
-
-void XmlDocVisitor::visitPost(DocLanguage *) 
-{
-  if (m_hide) return;
-  m_t << "</language>" << endl;
-}
+//void XmlDocVisitor::visitPre(DocLanguage *l)
+//{
+//  if (m_hide) return;
+//  m_t << "<language langid=\"" << l->id() << "\">";
+//}
+//
+//void XmlDocVisitor::visitPost(DocLanguage *) 
+//{
+//  if (m_hide) return;
+//  m_t << "</language>" << endl;
+//}
 
 void XmlDocVisitor::visitPre(DocParamSect *s)
 {
@@ -750,6 +750,8 @@ void XmlDocVisitor::visitPost(DocParamSect *)
 void XmlDocVisitor::visitPre(DocParamList *pl)
 {
   if (m_hide) return;
+  m_t << "<parameteritem>" << endl;
+  m_t << "<parameternamelist>" << endl;
   QStrListIterator li(pl->parameters());
   const char *s;
   for (li.toFirst();(s=li.current());++li)
@@ -776,13 +778,15 @@ void XmlDocVisitor::visitPre(DocParamList *pl)
     filter(s);
     m_t << "</parametername>" << endl;
   }
+  m_t << "</parameternamelist>" << endl;
   m_t << "<parameterdescription>" << endl;
 }
 
 void XmlDocVisitor::visitPost(DocParamList *)
 {
   if (m_hide) return;
-  m_t << "</parameterdescription>";
+  m_t << "</parameterdescription>" << endl;
+  m_t << "</parameteritem>" << endl;
 }
 
 void XmlDocVisitor::visitPre(DocXRefItem *x)
